languages = [
    {
        "name": "Ghotuo",
        "iso3": "aaa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alumu-Tesu",
        "iso3": "aab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ari",
        "iso3": "aac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amal",
        "iso3": "aad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arbëreshë Albanian",
        "iso3": "aae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aranadan",
        "iso3": "aaf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambrak",
        "iso3": "aag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abu' Arapesh",
        "iso3": "aah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arifama-Miniafia",
        "iso3": "aai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ankave",
        "iso3": "aak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Afade",
        "iso3": "aal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anambé",
        "iso3": "aan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Algerian Saharan Arabic",
        "iso3": "aao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pará Arára",
        "iso3": "aap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Abnaki",
        "iso3": "aaq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Afar",
        "iso3": "aar",
        "iso2b": "aar",
        "iso2t": "aar",
        "iso1": "aa",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aasáx",
        "iso3": "aas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arvanitika Albanian",
        "iso3": "aat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abau",
        "iso3": "aau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Solong",
        "iso3": "aaw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandobo Atas",
        "iso3": "aax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amarasi",
        "iso3": "aaz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abé",
        "iso3": "aba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bankon",
        "iso3": "abb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambala Ayta",
        "iso3": "abc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manide",
        "iso3": "abd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Abnaki",
        "iso3": "abe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abai Sungai",
        "iso3": "abf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abaga",
        "iso3": "abg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tajiki Arabic",
        "iso3": "abh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abidji",
        "iso3": "abi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aka-Bea",
        "iso3": "abj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Abkhazian",
        "iso3": "abk",
        "iso2b": "abk",
        "iso2t": "abk",
        "iso1": "ab",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lampung Nyo",
        "iso3": "abl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abanyom",
        "iso3": "abm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abua",
        "iso3": "abn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abon",
        "iso3": "abo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abellen Ayta",
        "iso3": "abp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abaza",
        "iso3": "abq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abron",
        "iso3": "abr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambonese Malay",
        "iso3": "abs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambulas",
        "iso3": "abt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abure",
        "iso3": "abu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baharna Arabic",
        "iso3": "abv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pal",
        "iso3": "abw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inabaknon",
        "iso3": "abx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aneme Wake",
        "iso3": "aby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abui",
        "iso3": "abz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Achagua",
        "iso3": "aca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Áncá",
        "iso3": "acb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gikyode",
        "iso3": "acd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Achinese",
        "iso3": "ace",
        "iso2b": "ace",
        "iso2t": "ace",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saint Lucian Creole French",
        "iso3": "acf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Acoli",
        "iso3": "ach",
        "iso2b": "ach",
        "iso2t": "ach",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aka-Cari",
        "iso3": "aci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Aka-Kora",
        "iso3": "ack",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Akar-Bale",
        "iso3": "acl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mesopotamian Arabic",
        "iso3": "acm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Achang",
        "iso3": "acn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Acipa",
        "iso3": "acp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ta'izzi-Adeni Arabic",
        "iso3": "acq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Achi",
        "iso3": "acr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Acroá",
        "iso3": "acs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Achterhoeks",
        "iso3": "act",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Achuar-Shiwiar",
        "iso3": "acu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Achumawi",
        "iso3": "acv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hijazi Arabic",
        "iso3": "acw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Omani Arabic",
        "iso3": "acx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cypriot Arabic",
        "iso3": "acy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Acheron",
        "iso3": "acz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adangme",
        "iso3": "ada",
        "iso2b": "ada",
        "iso2t": "ada",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atauran",
        "iso3": "adb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lidzonka",
        "iso3": "add",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adele",
        "iso3": "ade",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhofari Arabic",
        "iso3": "adf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andegerebinha",
        "iso3": "adg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adhola",
        "iso3": "adh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adi",
        "iso3": "adi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adioukrou",
        "iso3": "adj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Galo",
        "iso3": "adl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adang",
        "iso3": "adn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abu",
        "iso3": "ado",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adangbe",
        "iso3": "adq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adonara",
        "iso3": "adr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adamorobe Sign Language",
        "iso3": "ads",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adnyamathanha",
        "iso3": "adt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aduge",
        "iso3": "adu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amundava",
        "iso3": "adw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amdo Tibetan",
        "iso3": "adx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adyghe",
        "iso3": "ady",
        "iso2b": "ady",
        "iso2t": "ady",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adzera",
        "iso3": "adz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Areba",
        "iso3": "aea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tunisian Arabic",
        "iso3": "aeb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saidi Arabic",
        "iso3": "aec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Argentine Sign Language",
        "iso3": "aed",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northeast Pashai",
        "iso3": "aee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haeke",
        "iso3": "aek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambele",
        "iso3": "ael",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arem",
        "iso3": "aem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Armenian Sign Language",
        "iso3": "aen",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aer",
        "iso3": "aeq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Arrernte",
        "iso3": "aer",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alsea",
        "iso3": "aes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Akeu",
        "iso3": "aeu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambakich",
        "iso3": "aew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amele",
        "iso3": "aey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aeka",
        "iso3": "aez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gulf Arabic",
        "iso3": "afb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andai",
        "iso3": "afd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Putukwam",
        "iso3": "afe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Afghan Sign Language",
        "iso3": "afg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Afrihili",
        "iso3": "afh",
        "iso2b": "afh",
        "iso2t": "afh",
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Akrukay",
        "iso3": "afi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nanubae",
        "iso3": "afk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Defaka",
        "iso3": "afn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eloyi",
        "iso3": "afo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tapei",
        "iso3": "afp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Afrikaans",
        "iso3": "afr",
        "iso2b": "afr",
        "iso2t": "afr",
        "iso1": "af",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Afro-Seminole Creole",
        "iso3": "afs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Afitti",
        "iso3": "aft",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awutu",
        "iso3": "afu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Obokuitai",
        "iso3": "afz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aguano",
        "iso3": "aga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Legbo",
        "iso3": "agb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agatu",
        "iso3": "agc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agarabi",
        "iso3": "agd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angal",
        "iso3": "age",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arguni",
        "iso3": "agf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angor",
        "iso3": "agg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngelima",
        "iso3": "agh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agariya",
        "iso3": "agi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Argobba",
        "iso3": "agj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isarog Agta",
        "iso3": "agk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fembe",
        "iso3": "agl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angaataha",
        "iso3": "agm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agutaynen",
        "iso3": "agn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tainae",
        "iso3": "ago",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aghem",
        "iso3": "agq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aguaruna",
        "iso3": "agr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Esimbi",
        "iso3": "ags",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Cagayan Agta",
        "iso3": "agt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aguacateco",
        "iso3": "agu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Remontado Dumagat",
        "iso3": "agv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kahua",
        "iso3": "agw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aghul",
        "iso3": "agx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Alta",
        "iso3": "agy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mt. Iriga Agta",
        "iso3": "agz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ahanta",
        "iso3": "aha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Axamb",
        "iso3": "ahb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Qimant",
        "iso3": "ahg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aghu",
        "iso3": "ahh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiagbamrin Aizi",
        "iso3": "ahi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akha",
        "iso3": "ahk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Igo",
        "iso3": "ahl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mobumrin Aizi",
        "iso3": "ahm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Àhàn",
        "iso3": "ahn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ahom",
        "iso3": "aho",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Aproumu Aizi",
        "iso3": "ahp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ahirani",
        "iso3": "ahr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ashe",
        "iso3": "ahs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ahtena",
        "iso3": "aht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arosi",
        "iso3": "aia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ainu (China)",
        "iso3": "aib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ainbai",
        "iso3": "aic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alngith",
        "iso3": "aid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Amara",
        "iso3": "aie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agi",
        "iso3": "aif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Antigua and Barbuda Creole English",
        "iso3": "aig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ai-Cham",
        "iso3": "aih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Assyrian Neo-Aramaic",
        "iso3": "aii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lishanid Noshan",
        "iso3": "aij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ake",
        "iso3": "aik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aimele",
        "iso3": "ail",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aimol",
        "iso3": "aim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ainu (Japan)",
        "iso3": "ain",
        "iso2b": "ain",
        "iso2t": "ain",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aiton",
        "iso3": "aio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burumakok",
        "iso3": "aip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aimaq",
        "iso3": "aiq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Airoran",
        "iso3": "air",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arikem",
        "iso3": "ait",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Aari",
        "iso3": "aiw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aighon",
        "iso3": "aix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ali",
        "iso3": "aiy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aja (South Sudan)",
        "iso3": "aja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aja (Benin)",
        "iso3": "ajg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ajië",
        "iso3": "aji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andajin",
        "iso3": "ajn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Algerian Jewish Sign Language",
        "iso3": "ajs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Moroccan Arabic",
        "iso3": "aju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ajawa",
        "iso3": "ajw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Amri Karbi",
        "iso3": "ajz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akan",
        "iso3": "aka",
        "iso2b": "aka",
        "iso2t": "aka",
        "iso1": "ak",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Batak Angkola",
        "iso3": "akb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpur",
        "iso3": "akc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukpet-Ehom",
        "iso3": "akd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akawaio",
        "iso3": "ake",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akpa",
        "iso3": "akf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anakalangu",
        "iso3": "akg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angal Heneng",
        "iso3": "akh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aiome",
        "iso3": "aki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aka-Jeru",
        "iso3": "akj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Akkadian",
        "iso3": "akk",
        "iso2b": "akk",
        "iso2t": "akk",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Aklanon",
        "iso3": "akl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aka-Bo",
        "iso3": "akm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Akurio",
        "iso3": "ako",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siwu",
        "iso3": "akp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ak",
        "iso3": "akq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Araki",
        "iso3": "akr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akaselem",
        "iso3": "aks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akolet",
        "iso3": "akt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akum",
        "iso3": "aku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akhvakh",
        "iso3": "akv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akwa",
        "iso3": "akw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aka-Kede",
        "iso3": "akx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Aka-Kol",
        "iso3": "aky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Alabama",
        "iso3": "akz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alago",
        "iso3": "ala",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Qawasqar",
        "iso3": "alc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alladian",
        "iso3": "ald",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aleut",
        "iso3": "ale",
        "iso2b": "ale",
        "iso2t": "ale",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alege",
        "iso3": "alf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alawa",
        "iso3": "alh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amaimon",
        "iso3": "ali",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alangan",
        "iso3": "alj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alak",
        "iso3": "alk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Allar",
        "iso3": "all",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amblong",
        "iso3": "alm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gheg Albanian",
        "iso3": "aln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Larike-Wakasihu",
        "iso3": "alo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alune",
        "iso3": "alp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Algonquin",
        "iso3": "alq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alutor",
        "iso3": "alr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tosk Albanian",
        "iso3": "als",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Altai",
        "iso3": "alt",
        "iso2b": "alt",
        "iso2t": "alt",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "'Are'are",
        "iso3": "alu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alaba-K’abeena",
        "iso3": "alw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amol",
        "iso3": "alx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alyawarr",
        "iso3": "aly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alur",
        "iso3": "alz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amanayé",
        "iso3": "ama",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ambo",
        "iso3": "amb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amahuaca",
        "iso3": "amc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yanesha'",
        "iso3": "ame",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hamer-Banna",
        "iso3": "amf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amurdak",
        "iso3": "amg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amharic",
        "iso3": "amh",
        "iso2b": "amh",
        "iso2t": "amh",
        "iso1": "am",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amis",
        "iso3": "ami",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amdang",
        "iso3": "amj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambai",
        "iso3": "amk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "War-Jaintia",
        "iso3": "aml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ama (Papua New Guinea)",
        "iso3": "amm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amanab",
        "iso3": "amn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amo",
        "iso3": "amo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alamblak",
        "iso3": "amp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amahai",
        "iso3": "amq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amarakaeri",
        "iso3": "amr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Amami-Oshima",
        "iso3": "ams",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amto",
        "iso3": "amt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guerrero Amuzgo",
        "iso3": "amu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambelau",
        "iso3": "amv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Neo-Aramaic",
        "iso3": "amw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anmatyerre",
        "iso3": "amx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ami",
        "iso3": "amy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atampaya",
        "iso3": "amz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Andaqui",
        "iso3": "ana",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Andoa",
        "iso3": "anb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ngas",
        "iso3": "anc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ansus",
        "iso3": "and",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xârâcùù",
        "iso3": "ane",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Animere",
        "iso3": "anf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old English (ca. 450-1100)",
        "iso3": "ang",
        "iso2b": "ang",
        "iso2t": "ang",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Nend",
        "iso3": "anh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andi",
        "iso3": "ani",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anor",
        "iso3": "anj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Goemai",
        "iso3": "ank",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anu-Hkongso Chin",
        "iso3": "anl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anal",
        "iso3": "anm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Obolo",
        "iso3": "ann",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andoque",
        "iso3": "ano",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angika",
        "iso3": "anp",
        "iso2b": "anp",
        "iso2t": "anp",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jarawa (India)",
        "iso3": "anq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andh",
        "iso3": "anr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anserma",
        "iso3": "ans",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Antakarinya",
        "iso3": "ant",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anuak",
        "iso3": "anu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Denya",
        "iso3": "anv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anaang",
        "iso3": "anw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andra-Hus",
        "iso3": "anx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anyin",
        "iso3": "any",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anem",
        "iso3": "anz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angolar",
        "iso3": "aoa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abom",
        "iso3": "aob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pemon",
        "iso3": "aoc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andarum",
        "iso3": "aod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angal Enen",
        "iso3": "aoe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bragat",
        "iso3": "aof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angoram",
        "iso3": "aog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anindilyakwa",
        "iso3": "aoi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mufian",
        "iso3": "aoj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arhö",
        "iso3": "aok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alor",
        "iso3": "aol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ömie",
        "iso3": "aom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bumbita Arapesh",
        "iso3": "aon",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aore",
        "iso3": "aor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Taikat",
        "iso3": "aos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atong (India)",
        "iso3": "aot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "A'ou",
        "iso3": "aou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atorada",
        "iso3": "aox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uab Meto",
        "iso3": "aoz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sa'a",
        "iso3": "apb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Levantine Arabic",
        "iso3": "apc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sudanese Arabic",
        "iso3": "apd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bukiyip",
        "iso3": "ape",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pahanan Agta",
        "iso3": "apf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ampanang",
        "iso3": "apg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Athpariya",
        "iso3": "aph",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apiaká",
        "iso3": "api",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jicarilla Apache",
        "iso3": "apj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kiowa Apache",
        "iso3": "apk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lipan Apache",
        "iso3": "apl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mescalero-Chiricahua Apache",
        "iso3": "apm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apinayé",
        "iso3": "apn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambul",
        "iso3": "apo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apma",
        "iso3": "app",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "A-Pucikwar",
        "iso3": "apq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arop-Lokep",
        "iso3": "apr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arop-Sissano",
        "iso3": "aps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apatani",
        "iso3": "apt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apurinã",
        "iso3": "apu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alapmunte",
        "iso3": "apv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Western Apache",
        "iso3": "apw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aputai",
        "iso3": "apx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apalaí",
        "iso3": "apy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Safeyoka",
        "iso3": "apz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Archi",
        "iso3": "aqc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ampari Dogon",
        "iso3": "aqd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arigidi",
        "iso3": "aqg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aninka",
        "iso3": "aqk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atohwaim",
        "iso3": "aqm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Alta",
        "iso3": "aqn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atakapa",
        "iso3": "aqp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Arhâ",
        "iso3": "aqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angaité",
        "iso3": "aqt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akuntsu",
        "iso3": "aqz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arabic",
        "iso3": "ara",
        "iso2b": "ara",
        "iso2t": "ara",
        "iso1": "ar",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Standard Arabic",
        "iso3": "arb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Official Aramaic (700-300 BCE)",
        "iso3": "arc",
        "iso2b": "arc",
        "iso2t": "arc",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Arabana",
        "iso3": "ard",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Western Arrarnta",
        "iso3": "are",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aragonese",
        "iso3": "arg",
        "iso2b": "arg",
        "iso2t": "arg",
        "iso1": "an",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arhuaco",
        "iso3": "arh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arikara",
        "iso3": "ari",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arapaso",
        "iso3": "arj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Arikapú",
        "iso3": "ark",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arabela",
        "iso3": "arl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mapudungun",
        "iso3": "arn",
        "iso2b": "arn",
        "iso2t": "arn",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Araona",
        "iso3": "aro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arapaho",
        "iso3": "arp",
        "iso2b": "arp",
        "iso2t": "arp",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Algerian Arabic",
        "iso3": "arq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karo (Brazil)",
        "iso3": "arr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Najdi Arabic",
        "iso3": "ars",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aruá (Amazonas State)",
        "iso3": "aru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Arbore",
        "iso3": "arv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arawak",
        "iso3": "arw",
        "iso2b": "arw",
        "iso2t": "arw",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aruá (Rodonia State)",
        "iso3": "arx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moroccan Arabic",
        "iso3": "ary",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Egyptian Arabic",
        "iso3": "arz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asu (Tanzania)",
        "iso3": "asa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Assiniboine",
        "iso3": "asb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Casuarina Coast Asmat",
        "iso3": "asc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "American Sign Language",
        "iso3": "ase",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Auslan",
        "iso3": "asf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cishingini",
        "iso3": "asg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abishira",
        "iso3": "ash",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Buruwai",
        "iso3": "asi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sari",
        "iso3": "asj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ashkun",
        "iso3": "ask",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asilulu",
        "iso3": "asl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Assamese",
        "iso3": "asm",
        "iso2b": "asm",
        "iso2t": "asm",
        "iso1": "as",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xingú Asuriní",
        "iso3": "asn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dano",
        "iso3": "aso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Algerian Sign Language",
        "iso3": "asp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Austrian Sign Language",
        "iso3": "asq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asuri",
        "iso3": "asr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ipulo",
        "iso3": "ass",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asturian",
        "iso3": "ast",
        "iso2b": "ast",
        "iso2t": "ast",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tocantins Asurini",
        "iso3": "asu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asoa",
        "iso3": "asv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Australian Aborigines Sign Language",
        "iso3": "asw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muratayak",
        "iso3": "asx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaosakor Asmat",
        "iso3": "asy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "As",
        "iso3": "asz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pele-Ata",
        "iso3": "ata",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zaiwa",
        "iso3": "atb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atsahuaca",
        "iso3": "atc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ata Manobo",
        "iso3": "atd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atemble",
        "iso3": "ate",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ivbie North-Okpela-Arhe",
        "iso3": "atg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Attié",
        "iso3": "ati",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atikamekw",
        "iso3": "atj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ati",
        "iso3": "atk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mt. Iraya Agta",
        "iso3": "atl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ata",
        "iso3": "atm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ashtiani",
        "iso3": "atn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atong (Cameroon)",
        "iso3": "ato",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pudtol Atta",
        "iso3": "atp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aralle-Tabulahan",
        "iso3": "atq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waimiri-Atroari",
        "iso3": "atr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gros Ventre",
        "iso3": "ats",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pamplona Atta",
        "iso3": "att",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Reel",
        "iso3": "atu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Altai",
        "iso3": "atv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atsugewi",
        "iso3": "atw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arutani",
        "iso3": "atx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aneityum",
        "iso3": "aty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arta",
        "iso3": "atz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asumboa",
        "iso3": "aua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alugu",
        "iso3": "aub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waorani",
        "iso3": "auc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anuta",
        "iso3": "aud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aguna",
        "iso3": "aug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aushi",
        "iso3": "auh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anuki",
        "iso3": "aui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awjilah",
        "iso3": "auj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Heyo",
        "iso3": "auk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aulua",
        "iso3": "aul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asu (Nigeria)",
        "iso3": "aum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Molmo One",
        "iso3": "aun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Auyokawa",
        "iso3": "auo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Makayam",
        "iso3": "aup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anus",
        "iso3": "auq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aruek",
        "iso3": "aur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Austral",
        "iso3": "aut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Auye",
        "iso3": "auu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awyi",
        "iso3": "auw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aurá",
        "iso3": "aux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Awiyaana",
        "iso3": "auy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uzbeki Arabic",
        "iso3": "auz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Avaric",
        "iso3": "ava",
        "iso2b": "ava",
        "iso2t": "ava",
        "iso1": "av",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Avau",
        "iso3": "avb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alviri-Vidari",
        "iso3": "avd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Avestan",
        "iso3": "ave",
        "iso2b": "ave",
        "iso2t": "ave",
        "iso1": "ae",
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Avikam",
        "iso3": "avi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kotava",
        "iso3": "avk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Eastern Egyptian Bedawi Arabic",
        "iso3": "avl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angkamuthi",
        "iso3": "avm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Avatime",
        "iso3": "avn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agavotaguerra",
        "iso3": "avo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Aushiri",
        "iso3": "avs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Au",
        "iso3": "avt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Avokaya",
        "iso3": "avu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Avá-Canoeiro",
        "iso3": "avv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awadhi",
        "iso3": "awa",
        "iso2b": "awa",
        "iso2t": "awa",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awa (Papua New Guinea)",
        "iso3": "awb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cicipu",
        "iso3": "awc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awetí",
        "iso3": "awe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anguthimri",
        "iso3": "awg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Awbono",
        "iso3": "awh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aekyom",
        "iso3": "awi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awabakal",
        "iso3": "awk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Arawum",
        "iso3": "awm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awngi",
        "iso3": "awn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awak",
        "iso3": "awo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awera",
        "iso3": "awr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Awyu",
        "iso3": "aws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Araweté",
        "iso3": "awt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Awyu",
        "iso3": "awu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jair Awyu",
        "iso3": "awv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awun",
        "iso3": "aww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awara",
        "iso3": "awx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Edera Awyu",
        "iso3": "awy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abipon",
        "iso3": "axb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ayerrerenge",
        "iso3": "axe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mato Grosso Arára",
        "iso3": "axg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yaka (Central African Republic)",
        "iso3": "axk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Southern Aranda",
        "iso3": "axl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Middle Armenian",
        "iso3": "axm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Xârâgurè",
        "iso3": "axx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awar",
        "iso3": "aya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayizo Gbe",
        "iso3": "ayb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Aymara",
        "iso3": "ayc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayabadhu",
        "iso3": "ayd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ayere",
        "iso3": "aye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ginyanga",
        "iso3": "ayg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hadrami Arabic",
        "iso3": "ayh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Leyigha",
        "iso3": "ayi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akuku",
        "iso3": "ayk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Libyan Arabic",
        "iso3": "ayl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aymara",
        "iso3": "aym",
        "iso2b": "aym",
        "iso2t": "aym",
        "iso1": "ay",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Sanaani Arabic",
        "iso3": "ayn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayoreo",
        "iso3": "ayo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Mesopotamian Arabic",
        "iso3": "ayp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayi (Papua New Guinea)",
        "iso3": "ayq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Aymara",
        "iso3": "ayr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sorsogon Ayta",
        "iso3": "ays",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Magbukun Ayta",
        "iso3": "ayt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayu",
        "iso3": "ayu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mai Brat",
        "iso3": "ayz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Azha",
        "iso3": "aza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Azerbaijani",
        "iso3": "azb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Durango Nahuatl",
        "iso3": "azd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Azerbaijani",
        "iso3": "aze",
        "iso2b": "aze",
        "iso2t": "aze",
        "iso1": "az",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "San Pedro Amuzgos Amuzgo",
        "iso3": "azg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Azerbaijani",
        "iso3": "azj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ipalapa Amuzgo",
        "iso3": "azm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Durango Nahuatl",
        "iso3": "azn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awing",
        "iso3": "azo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Faire Atta",
        "iso3": "azt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Highland Puebla Nahuatl",
        "iso3": "azz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Babatana",
        "iso3": "baa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bainouk-Gunyuño",
        "iso3": "bab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Badui",
        "iso3": "bac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baré",
        "iso3": "bae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nubaca",
        "iso3": "baf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuki",
        "iso3": "bag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bahamas Creole English",
        "iso3": "bah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barakai",
        "iso3": "baj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bashkir",
        "iso3": "bak",
        "iso2b": "bak",
        "iso2t": "bak",
        "iso1": "ba",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baluchi",
        "iso3": "bal",
        "iso2b": "bal",
        "iso2t": "bal",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Bambara",
        "iso3": "bam",
        "iso2b": "bam",
        "iso2t": "bam",
        "iso1": "bm",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balinese",
        "iso3": "ban",
        "iso2b": "ban",
        "iso2t": "ban",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waimaha",
        "iso3": "bao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bantawa",
        "iso3": "bap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bavarian",
        "iso3": "bar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Basa (Cameroon)",
        "iso3": "bas",
        "iso2b": "bas",
        "iso2t": "bas",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bada (Nigeria)",
        "iso3": "bau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vengo",
        "iso3": "bav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bambili-Bambui",
        "iso3": "baw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bamun",
        "iso3": "bax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batuley",
        "iso3": "bay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baatonum",
        "iso3": "bba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barai",
        "iso3": "bbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batak Toba",
        "iso3": "bbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bau",
        "iso3": "bbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangba",
        "iso3": "bbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baibai",
        "iso3": "bbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barama",
        "iso3": "bbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bugan",
        "iso3": "bbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barombi",
        "iso3": "bbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghomálá'",
        "iso3": "bbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Babanki",
        "iso3": "bbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bats",
        "iso3": "bbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Babango",
        "iso3": "bbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uneapa",
        "iso3": "bbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Bobo Madaré",
        "iso3": "bbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Central Banda",
        "iso3": "bbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bamali",
        "iso3": "bbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Girawa",
        "iso3": "bbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bakpinka",
        "iso3": "bbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mburku",
        "iso3": "bbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kulung (Nigeria)",
        "iso3": "bbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karnai",
        "iso3": "bbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baba",
        "iso3": "bbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bubia",
        "iso3": "bbx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Befang",
        "iso3": "bby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Bai",
        "iso3": "bca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bainouk-Samik",
        "iso3": "bcb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Balochi",
        "iso3": "bcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Babar",
        "iso3": "bcd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bamenyam",
        "iso3": "bce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bamu",
        "iso3": "bcf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baga Pokur",
        "iso3": "bcg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bariai",
        "iso3": "bch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baoulé",
        "iso3": "bci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bardi",
        "iso3": "bcj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bunuba",
        "iso3": "bck",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Bikol",
        "iso3": "bcl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bannoni",
        "iso3": "bcm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bali (Nigeria)",
        "iso3": "bcn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaluli",
        "iso3": "bco",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bali (Democratic Republic of Congo)",
        "iso3": "bcp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bench",
        "iso3": "bcq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Babine",
        "iso3": "bcr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kohumono",
        "iso3": "bcs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bendi",
        "iso3": "bct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awad Bing",
        "iso3": "bcu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shoo-Minda-Nye",
        "iso3": "bcv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bana",
        "iso3": "bcw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bacama",
        "iso3": "bcy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bainouk-Gunyaamolo",
        "iso3": "bcz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bayot",
        "iso3": "bda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Basap",
        "iso3": "bdb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Emberá-Baudó",
        "iso3": "bdc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bunama",
        "iso3": "bdd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bade",
        "iso3": "bde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biage",
        "iso3": "bdf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bonggi",
        "iso3": "bdg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baka (South Sudan)",
        "iso3": "bdh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burun",
        "iso3": "bdi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bai (South Sudan)",
        "iso3": "bdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Budukh",
        "iso3": "bdk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Indonesian Bajau",
        "iso3": "bdl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buduma",
        "iso3": "bdm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baldemu",
        "iso3": "bdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Morom",
        "iso3": "bdo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bende",
        "iso3": "bdp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bahnar",
        "iso3": "bdq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Coast Bajau",
        "iso3": "bdr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burunge",
        "iso3": "bds",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bokoto",
        "iso3": "bdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oroko",
        "iso3": "bdu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bodo Parja",
        "iso3": "bdv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baham",
        "iso3": "bdw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Budong-Budong",
        "iso3": "bdx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bandjalang",
        "iso3": "bdy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Badeshi",
        "iso3": "bdz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beaver",
        "iso3": "bea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bebele",
        "iso3": "beb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iceve-Maci",
        "iso3": "bec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bedoanas",
        "iso3": "bed",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Byangsi",
        "iso3": "bee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Benabena",
        "iso3": "bef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Belait",
        "iso3": "beg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biali",
        "iso3": "beh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bekati'",
        "iso3": "bei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beja",
        "iso3": "bej",
        "iso2b": "bej",
        "iso2t": "bej",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bebeli",
        "iso3": "bek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Belarusian",
        "iso3": "bel",
        "iso2b": "bel",
        "iso2t": "bel",
        "iso1": "be",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bemba (Zambia)",
        "iso3": "bem",
        "iso2b": "bem",
        "iso2t": "bem",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bengali",
        "iso3": "ben",
        "iso2b": "ben",
        "iso2t": "ben",
        "iso1": "bn",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beami",
        "iso3": "beo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Besoa",
        "iso3": "bep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beembe",
        "iso3": "beq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Besme",
        "iso3": "bes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guiberoua Béte",
        "iso3": "bet",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Blagar",
        "iso3": "beu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daloa Bété",
        "iso3": "bev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Betawi",
        "iso3": "bew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jur Modo",
        "iso3": "bex",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beli (Papua New Guinea)",
        "iso3": "bey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bena (Tanzania)",
        "iso3": "bez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bari",
        "iso3": "bfa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pauri Bareli",
        "iso3": "bfb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panyi Bai",
        "iso3": "bfc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bafut",
        "iso3": "bfd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Betaf",
        "iso3": "bfe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bofi",
        "iso3": "bff",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Busang Kayan",
        "iso3": "bfg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Blafe",
        "iso3": "bfh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "British Sign Language",
        "iso3": "bfi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bafanji",
        "iso3": "bfj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ban Khor Sign Language",
        "iso3": "bfk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banda-Ndélé",
        "iso3": "bfl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mmen",
        "iso3": "bfm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bunak",
        "iso3": "bfn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malba Birifor",
        "iso3": "bfo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beba",
        "iso3": "bfp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Badaga",
        "iso3": "bfq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bazigar",
        "iso3": "bfr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Bai",
        "iso3": "bfs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balti",
        "iso3": "bft",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gahri",
        "iso3": "bfu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bondo",
        "iso3": "bfw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bantayanon",
        "iso3": "bfx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bagheli",
        "iso3": "bfy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mahasu Pahari",
        "iso3": "bfz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gwamhi-Wuri",
        "iso3": "bga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bobongko",
        "iso3": "bgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haryanvi",
        "iso3": "bgc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rathwi Bareli",
        "iso3": "bgd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bauria",
        "iso3": "bge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangandu",
        "iso3": "bgf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bugun",
        "iso3": "bgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Giangan",
        "iso3": "bgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangolan",
        "iso3": "bgj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bit",
        "iso3": "bgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bo (Laos)",
        "iso3": "bgl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Balochi",
        "iso3": "bgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baga Koga",
        "iso3": "bgo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Balochi",
        "iso3": "bgp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bagri",
        "iso3": "bgq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bawm Chin",
        "iso3": "bgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagabawa",
        "iso3": "bgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bughotu",
        "iso3": "bgt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbongno",
        "iso3": "bgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warkay-Bipim",
        "iso3": "bgv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhatri",
        "iso3": "bgw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balkan Gagauz Turkish",
        "iso3": "bgx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Benggoi",
        "iso3": "bgy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banggai",
        "iso3": "bgz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bharia",
        "iso3": "bha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhili",
        "iso3": "bhb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biga",
        "iso3": "bhc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhadrawahi",
        "iso3": "bhd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhaya",
        "iso3": "bhe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Odiai",
        "iso3": "bhf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Binandere",
        "iso3": "bhg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bukharic",
        "iso3": "bhh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhilali",
        "iso3": "bhi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bahing",
        "iso3": "bhj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bimin",
        "iso3": "bhl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bathari",
        "iso3": "bhm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bohtan Neo-Aramaic",
        "iso3": "bhn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhojpuri",
        "iso3": "bho",
        "iso2b": "bho",
        "iso2t": "bho",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bima",
        "iso3": "bhp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tukang Besi South",
        "iso3": "bhq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bara Malagasy",
        "iso3": "bhr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buwal",
        "iso3": "bhs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhattiyali",
        "iso3": "bht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhunjia",
        "iso3": "bhu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bahau",
        "iso3": "bhv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biak",
        "iso3": "bhw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhalay",
        "iso3": "bhx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhele",
        "iso3": "bhy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bada (Indonesia)",
        "iso3": "bhz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Badimaya",
        "iso3": "bia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bissa",
        "iso3": "bib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bidiyo",
        "iso3": "bid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bepour",
        "iso3": "bie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biafada",
        "iso3": "bif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biangai",
        "iso3": "big",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bikol",
        "iso3": "bik",
        "iso2b": "bik",
        "iso2t": "bik",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Bile",
        "iso3": "bil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bimoba",
        "iso3": "bim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bini",
        "iso3": "bin",
        "iso2b": "bin",
        "iso2t": "bin",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nai",
        "iso3": "bio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bila",
        "iso3": "bip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bipi",
        "iso3": "biq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bisorio",
        "iso3": "bir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bislama",
        "iso3": "bis",
        "iso2b": "bis",
        "iso2t": "bis",
        "iso1": "bi",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Berinomo",
        "iso3": "bit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biete",
        "iso3": "biu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Birifor",
        "iso3": "biv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kol (Cameroon)",
        "iso3": "biw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bijori",
        "iso3": "bix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Birhor",
        "iso3": "biy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baloi",
        "iso3": "biz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Budza",
        "iso3": "bja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banggarla",
        "iso3": "bjb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bariji",
        "iso3": "bjc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biao-Jiao Mien",
        "iso3": "bje",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barzani Jewish Neo-Aramaic",
        "iso3": "bjf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bidyogo",
        "iso3": "bjg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bahinemo",
        "iso3": "bjh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burji",
        "iso3": "bji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanauji",
        "iso3": "bjj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barok",
        "iso3": "bjk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bulu (Papua New Guinea)",
        "iso3": "bjl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bajelani",
        "iso3": "bjm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banjar",
        "iso3": "bjn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mid-Southern Banda",
        "iso3": "bjo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fanamaket",
        "iso3": "bjp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Binumarien",
        "iso3": "bjr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bajan",
        "iso3": "bjs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balanta-Ganja",
        "iso3": "bjt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Busuu",
        "iso3": "bju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bedjond",
        "iso3": "bjv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bakwé",
        "iso3": "bjw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banao Itneg",
        "iso3": "bjx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bayali",
        "iso3": "bjy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Baruga",
        "iso3": "bjz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kyak",
        "iso3": "bka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baka (Cameroon)",
        "iso3": "bkc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Binukid",
        "iso3": "bkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beeke",
        "iso3": "bkf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buraka",
        "iso3": "bkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bakoko",
        "iso3": "bkh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baki",
        "iso3": "bki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pande",
        "iso3": "bkj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brokskat",
        "iso3": "bkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Berik",
        "iso3": "bkl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kom (Cameroon)",
        "iso3": "bkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bukitan",
        "iso3": "bkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwa'",
        "iso3": "bko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boko (Democratic Republic of Congo)",
        "iso3": "bkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bakairí",
        "iso3": "bkq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bakumpai",
        "iso3": "bkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Sorsoganon",
        "iso3": "bks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boloki",
        "iso3": "bkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buhid",
        "iso3": "bku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bekwarra",
        "iso3": "bkv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bekwel",
        "iso3": "bkw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baikeno",
        "iso3": "bkx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bokyi",
        "iso3": "bky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bungku",
        "iso3": "bkz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siksika",
        "iso3": "bla",
        "iso2b": "bla",
        "iso2t": "bla",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bilua",
        "iso3": "blb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bella Coola",
        "iso3": "blc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolango",
        "iso3": "bld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balanta-Kentohe",
        "iso3": "ble",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buol",
        "iso3": "blf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuwaa",
        "iso3": "blh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolia",
        "iso3": "bli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolongan",
        "iso3": "blj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pa'o Karen",
        "iso3": "blk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biloxi",
        "iso3": "bll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Beli (South Sudan)",
        "iso3": "blm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Catanduanes Bikol",
        "iso3": "bln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anii",
        "iso3": "blo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Blablanga",
        "iso3": "blp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baluan-Pam",
        "iso3": "blq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Blang",
        "iso3": "blr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balaesang",
        "iso3": "bls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Dam",
        "iso3": "blt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kibala",
        "iso3": "blv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balangao",
        "iso3": "blw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mag-Indi Ayta",
        "iso3": "blx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Notre",
        "iso3": "bly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balantak",
        "iso3": "blz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lame",
        "iso3": "bma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bembe",
        "iso3": "bmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biem",
        "iso3": "bmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baga Manduri",
        "iso3": "bmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Limassa",
        "iso3": "bme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bom-Kim",
        "iso3": "bmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bamwe",
        "iso3": "bmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kein",
        "iso3": "bmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bagirmi",
        "iso3": "bmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bote-Majhi",
        "iso3": "bmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghayavi",
        "iso3": "bmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bomboli",
        "iso3": "bml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Betsimisaraka Malagasy",
        "iso3": "bmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bina (Papua New Guinea)",
        "iso3": "bmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bambalang",
        "iso3": "bmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bulgebi",
        "iso3": "bmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bomu",
        "iso3": "bmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muinane",
        "iso3": "bmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bilma Kanuri",
        "iso3": "bms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biao Mon",
        "iso3": "bmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Somba-Siawari",
        "iso3": "bmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bum",
        "iso3": "bmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bomwali",
        "iso3": "bmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baimak",
        "iso3": "bmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baramu",
        "iso3": "bmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bonerate",
        "iso3": "bna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bookan",
        "iso3": "bnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bontok",
        "iso3": "bnc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Banda (Indonesia)",
        "iso3": "bnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bintauna",
        "iso3": "bne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masiwang",
        "iso3": "bnf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Benga",
        "iso3": "bng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangi",
        "iso3": "bni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Tawbuid",
        "iso3": "bnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bierebo",
        "iso3": "bnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boon",
        "iso3": "bnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batanga",
        "iso3": "bnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bunun",
        "iso3": "bnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bantoanon",
        "iso3": "bno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bola",
        "iso3": "bnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bantik",
        "iso3": "bnq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Butmas-Tur",
        "iso3": "bnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bundeli",
        "iso3": "bns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bentong",
        "iso3": "bnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bonerif",
        "iso3": "bnv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bisis",
        "iso3": "bnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangubangu",
        "iso3": "bnx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bintulu",
        "iso3": "bny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beezen",
        "iso3": "bnz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bora",
        "iso3": "boa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aweer",
        "iso3": "bob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tibetan",
        "iso3": "bod",
        "iso2b": "tib",
        "iso2t": "bod",
        "iso1": "bo",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mundabli",
        "iso3": "boe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolon",
        "iso3": "bof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bamako Sign Language",
        "iso3": "bog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boma",
        "iso3": "boh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barbareño",
        "iso3": "boi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Anjam",
        "iso3": "boj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bonjo",
        "iso3": "bok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bole",
        "iso3": "bol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Berom",
        "iso3": "bom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bine",
        "iso3": "bon",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiemacèwè Bozo",
        "iso3": "boo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bonkiman",
        "iso3": "bop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bogaya",
        "iso3": "boq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Borôro",
        "iso3": "bor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bosnian",
        "iso3": "bos",
        "iso2b": "bos",
        "iso2t": "bos",
        "iso1": "bs",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bongo",
        "iso3": "bot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bondei",
        "iso3": "bou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuwuli",
        "iso3": "bov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rema",
        "iso3": "bow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Buamu",
        "iso3": "box",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bodo (Central African Republic)",
        "iso3": "boy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiéyaxo Bozo",
        "iso3": "boz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daakaka",
        "iso3": "bpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbuk",
        "iso3": "bpc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banda-Banda",
        "iso3": "bpd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bauni",
        "iso3": "bpe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bonggo",
        "iso3": "bpg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Botlikh",
        "iso3": "bph",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bagupi",
        "iso3": "bpi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Binji",
        "iso3": "bpj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orowe",
        "iso3": "bpk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Broome Pearling Lugger Pidgin",
        "iso3": "bpl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biyom",
        "iso3": "bpm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dzao Min",
        "iso3": "bpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anasi",
        "iso3": "bpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaure",
        "iso3": "bpp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banda Malay",
        "iso3": "bpq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koronadal Blaan",
        "iso3": "bpr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sarangani Blaan",
        "iso3": "bps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barrow Point",
        "iso3": "bpt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bongu",
        "iso3": "bpu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bian Marind",
        "iso3": "bpv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bo (Papua New Guinea)",
        "iso3": "bpw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Palya Bareli",
        "iso3": "bpx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bishnupriya",
        "iso3": "bpy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bilba",
        "iso3": "bpz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tchumbuli",
        "iso3": "bqa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bagusa",
        "iso3": "bqb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boko (Benin)",
        "iso3": "bqc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bung",
        "iso3": "bqd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baga Kaloum",
        "iso3": "bqf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bago-Kusuntu",
        "iso3": "bqg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baima",
        "iso3": "bqh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bakhtiari",
        "iso3": "bqi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bandial",
        "iso3": "bqj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banda-Mbrès",
        "iso3": "bqk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karian",
        "iso3": "bql",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wumboko",
        "iso3": "bqm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bulgarian Sign Language",
        "iso3": "bqn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balo",
        "iso3": "bqo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Busa",
        "iso3": "bqp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biritai",
        "iso3": "bqq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burusu",
        "iso3": "bqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bosngun",
        "iso3": "bqs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bamukumbit",
        "iso3": "bqt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boguru",
        "iso3": "bqu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koro Wachi",
        "iso3": "bqv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buru (Nigeria)",
        "iso3": "bqw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baangi",
        "iso3": "bqx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bengkala Sign Language",
        "iso3": "bqy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bakaka",
        "iso3": "bqz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Braj",
        "iso3": "bra",
        "iso2b": "bra",
        "iso2t": "bra",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brao",
        "iso3": "brb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Berbice Creole Dutch",
        "iso3": "brc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Baraamu",
        "iso3": "brd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Breton",
        "iso3": "bre",
        "iso2b": "bre",
        "iso2t": "bre",
        "iso1": "br",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bira",
        "iso3": "brf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baure",
        "iso3": "brg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brahui",
        "iso3": "brh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mokpwe",
        "iso3": "bri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bieria",
        "iso3": "brj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Birked",
        "iso3": "brk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Birwa",
        "iso3": "brl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barambu",
        "iso3": "brm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boruca",
        "iso3": "brn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brokkat",
        "iso3": "bro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barapasi",
        "iso3": "brp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Breri",
        "iso3": "brq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Birao",
        "iso3": "brr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baras",
        "iso3": "brs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bitare",
        "iso3": "brt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Bru",
        "iso3": "bru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Bru",
        "iso3": "brv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bellari",
        "iso3": "brw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bodo (India)",
        "iso3": "brx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burui",
        "iso3": "bry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bilbil",
        "iso3": "brz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abinomn",
        "iso3": "bsa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brunei Bisaya",
        "iso3": "bsb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bassari",
        "iso3": "bsc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wushi",
        "iso3": "bse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bauchi",
        "iso3": "bsf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bashkardi",
        "iso3": "bsg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kati",
        "iso3": "bsh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bassossi",
        "iso3": "bsi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangwinji",
        "iso3": "bsj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burushaski",
        "iso3": "bsk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Basa-Gumna",
        "iso3": "bsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Busami",
        "iso3": "bsm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barasana-Eduria",
        "iso3": "bsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buso",
        "iso3": "bso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baga Sitemu",
        "iso3": "bsp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bassa",
        "iso3": "bsq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bassa-Kontagora",
        "iso3": "bsr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akoose",
        "iso3": "bss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Basketo",
        "iso3": "bst",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bahonsuai",
        "iso3": "bsu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baga Sobané",
        "iso3": "bsv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Baiso",
        "iso3": "bsw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yangkam",
        "iso3": "bsx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sabah Bisaya",
        "iso3": "bsy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bata",
        "iso3": "bta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bati (Cameroon)",
        "iso3": "btc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batak Dairi",
        "iso3": "btd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gamo-Ningi",
        "iso3": "bte",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Birgit",
        "iso3": "btf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gagnoa Bété",
        "iso3": "btg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biatah Bidayuh",
        "iso3": "bth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burate",
        "iso3": "bti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bacanese Malay",
        "iso3": "btj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batak Mandailing",
        "iso3": "btm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ratagnon",
        "iso3": "btn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rinconada Bikol",
        "iso3": "bto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Budibud",
        "iso3": "btp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batek",
        "iso3": "btq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baetora",
        "iso3": "btr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batak Simalungun",
        "iso3": "bts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bete-Bendi",
        "iso3": "btt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batu",
        "iso3": "btu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bateri",
        "iso3": "btv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Butuanon",
        "iso3": "btw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batak Karo",
        "iso3": "btx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bobot",
        "iso3": "bty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batak Alas-Kluet",
        "iso3": "btz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buriat",
        "iso3": "bua",
        "iso2b": "bua",
        "iso2t": "bua",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Bua",
        "iso3": "bub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bushi",
        "iso3": "buc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ntcham",
        "iso3": "bud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beothuk",
        "iso3": "bue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bushoong",
        "iso3": "buf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buginese",
        "iso3": "bug",
        "iso2b": "bug",
        "iso2t": "bug",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Younuo Bunu",
        "iso3": "buh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bongili",
        "iso3": "bui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Basa-Gurmana",
        "iso3": "buj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bugawac",
        "iso3": "buk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bulgarian",
        "iso3": "bul",
        "iso2b": "bul",
        "iso2t": "bul",
        "iso1": "bg",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bulu (Cameroon)",
        "iso3": "bum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sherbro",
        "iso3": "bun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Terei",
        "iso3": "buo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Busoa",
        "iso3": "bup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brem",
        "iso3": "buq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bokobaru",
        "iso3": "bus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bungain",
        "iso3": "but",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Budu",
        "iso3": "buu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bun",
        "iso3": "buv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bubi",
        "iso3": "buw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boghom",
        "iso3": "bux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bullom So",
        "iso3": "buy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bukwen",
        "iso3": "buz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barein",
        "iso3": "bva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bube",
        "iso3": "bvb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baelelea",
        "iso3": "bvc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baeggu",
        "iso3": "bvd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Berau Malay",
        "iso3": "bve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boor",
        "iso3": "bvf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bonkeng",
        "iso3": "bvg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bure",
        "iso3": "bvh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Belanda Viri",
        "iso3": "bvi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baan",
        "iso3": "bvj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bukat",
        "iso3": "bvk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolivian Sign Language",
        "iso3": "bvl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bamunka",
        "iso3": "bvm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buna",
        "iso3": "bvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolgo",
        "iso3": "bvo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bumang",
        "iso3": "bvp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Birri",
        "iso3": "bvq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burarra",
        "iso3": "bvr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bati (Indonesia)",
        "iso3": "bvt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bukit Malay",
        "iso3": "bvu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baniva",
        "iso3": "bvv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Boga",
        "iso3": "bvw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dibole",
        "iso3": "bvx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baybayanon",
        "iso3": "bvy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bauzi",
        "iso3": "bvz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bwatoo",
        "iso3": "bwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namosi-Naitasiri-Serua",
        "iso3": "bwb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bwile",
        "iso3": "bwc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bwaidoka",
        "iso3": "bwd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bwe Karen",
        "iso3": "bwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boselewa",
        "iso3": "bwf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barwe",
        "iso3": "bwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bishuo",
        "iso3": "bwh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baniwa",
        "iso3": "bwi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Láá Láá Bwamu",
        "iso3": "bwj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bauwaki",
        "iso3": "bwk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bwela",
        "iso3": "bwl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biwat",
        "iso3": "bwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wunai Bunu",
        "iso3": "bwn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boro (Ethiopia)",
        "iso3": "bwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandobo Bawah",
        "iso3": "bwp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Bobo Madaré",
        "iso3": "bwq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bura-Pabir",
        "iso3": "bwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bomboma",
        "iso3": "bws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bafaw-Balong",
        "iso3": "bwt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buli (Ghana)",
        "iso3": "bwu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bwa",
        "iso3": "bww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bu-Nao Bunu",
        "iso3": "bwx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cwi Bwamu",
        "iso3": "bwy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bwisi",
        "iso3": "bwz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tairaha",
        "iso3": "bxa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Belanda Bor",
        "iso3": "bxb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Molengue",
        "iso3": "bxc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pela",
        "iso3": "bxd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Birale",
        "iso3": "bxe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bilur",
        "iso3": "bxf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangala",
        "iso3": "bxg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buhutu",
        "iso3": "bxh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pirlatapa",
        "iso3": "bxi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bayungu",
        "iso3": "bxj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bukusu",
        "iso3": "bxk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jalkunan",
        "iso3": "bxl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mongolia Buriat",
        "iso3": "bxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burduna",
        "iso3": "bxn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barikanchi",
        "iso3": "bxo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bebil",
        "iso3": "bxp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beele",
        "iso3": "bxq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Russia Buriat",
        "iso3": "bxr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Busam",
        "iso3": "bxs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "China Buriat",
        "iso3": "bxu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Berakou",
        "iso3": "bxv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bankagooma",
        "iso3": "bxw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Binahari",
        "iso3": "bxz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batak",
        "iso3": "bya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bikya",
        "iso3": "byb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ubaghara",
        "iso3": "byc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Benyadu'",
        "iso3": "byd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pouye",
        "iso3": "bye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bete",
        "iso3": "byf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baygo",
        "iso3": "byg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bhujel",
        "iso3": "byh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buyu",
        "iso3": "byi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bina (Nigeria)",
        "iso3": "byj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biao",
        "iso3": "byk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bayono",
        "iso3": "byl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bidjara",
        "iso3": "bym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bilin",
        "iso3": "byn",
        "iso2b": "byn",
        "iso2t": "byn",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biyo",
        "iso3": "byo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bumaji",
        "iso3": "byp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Basay",
        "iso3": "byq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Baruya",
        "iso3": "byr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burak",
        "iso3": "bys",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Berti",
        "iso3": "byt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Medumba",
        "iso3": "byv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Belhariya",
        "iso3": "byw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Qaqet",
        "iso3": "byx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banaro",
        "iso3": "byz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bandi",
        "iso3": "bza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andio",
        "iso3": "bzb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Betsimisaraka Malagasy",
        "iso3": "bzc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bribri",
        "iso3": "bzd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jenaama Bozo",
        "iso3": "bze",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boikin",
        "iso3": "bzf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Babuza",
        "iso3": "bzg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mapos Buang",
        "iso3": "bzh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bisu",
        "iso3": "bzi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Belize Kriol English",
        "iso3": "bzj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nicaragua Creole English",
        "iso3": "bzk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boano (Sulawesi)",
        "iso3": "bzl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolondo",
        "iso3": "bzm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Boano (Maluku)",
        "iso3": "bzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bozaba",
        "iso3": "bzo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kemberano",
        "iso3": "bzp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buli (Indonesia)",
        "iso3": "bzq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biri",
        "iso3": "bzr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Brazilian Sign Language",
        "iso3": "bzs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brithenig",
        "iso3": "bzt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Burmeso",
        "iso3": "bzu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naami",
        "iso3": "bzv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Basa (Nigeria)",
        "iso3": "bzw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kɛlɛngaxo Bozo",
        "iso3": "bzx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Obanliku",
        "iso3": "bzy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Evant",
        "iso3": "bzz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chortí",
        "iso3": "caa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Garifuna",
        "iso3": "cab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chuj",
        "iso3": "cac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Caddo",
        "iso3": "cad",
        "iso2b": "cad",
        "iso2t": "cad",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lehar",
        "iso3": "cae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Carrier",
        "iso3": "caf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nivaclé",
        "iso3": "cag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cahuarano",
        "iso3": "cah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chané",
        "iso3": "caj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kaqchikel",
        "iso3": "cak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Carolinian",
        "iso3": "cal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cemuhî",
        "iso3": "cam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chambri",
        "iso3": "can",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chácobo",
        "iso3": "cao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chipaya",
        "iso3": "cap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Car Nicobarese",
        "iso3": "caq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Galibi Carib",
        "iso3": "car",
        "iso2b": "car",
        "iso2t": "car",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsimané",
        "iso3": "cas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Catalan",
        "iso3": "cat",
        "iso2b": "cat",
        "iso2t": "cat",
        "iso1": "ca",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cavineña",
        "iso3": "cav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Callawalla",
        "iso3": "caw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chiquitano",
        "iso3": "cax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cayuga",
        "iso3": "cay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Canichana",
        "iso3": "caz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cabiyarí",
        "iso3": "cbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Carapana",
        "iso3": "cbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Carijona",
        "iso3": "cbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chimila",
        "iso3": "cbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chachi",
        "iso3": "cbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ede Cabe",
        "iso3": "cbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chavacano",
        "iso3": "cbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bualkhaw Chin",
        "iso3": "cbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyahkur",
        "iso3": "cbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Izora",
        "iso3": "cbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsucuba",
        "iso3": "cbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cashibo-Cacataibo",
        "iso3": "cbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cashinahua",
        "iso3": "cbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chayahuita",
        "iso3": "cbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Candoshi-Shapra",
        "iso3": "cbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cacua",
        "iso3": "cbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kinabalian",
        "iso3": "cbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Carabayo",
        "iso3": "cby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chamicuro",
        "iso3": "ccc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cafundo Creole",
        "iso3": "ccd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chopi",
        "iso3": "cce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samba Daka",
        "iso3": "ccg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atsam",
        "iso3": "cch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kasanga",
        "iso3": "ccj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cutchi-Swahili",
        "iso3": "ccl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malaccan Creole Malay",
        "iso3": "ccm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Comaltepec Chinantec",
        "iso3": "cco",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chakma",
        "iso3": "ccp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cacaopera",
        "iso3": "ccr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Choni",
        "iso3": "cda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chenchu",
        "iso3": "cde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chiru",
        "iso3": "cdf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chambeali",
        "iso3": "cdh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chodri",
        "iso3": "cdi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Churahi",
        "iso3": "cdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chepang",
        "iso3": "cdm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chaudangsi",
        "iso3": "cdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Min Dong Chinese",
        "iso3": "cdo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cinda-Regi-Tiyal",
        "iso3": "cdr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chadian Sign Language",
        "iso3": "cds",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chadong",
        "iso3": "cdy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koda",
        "iso3": "cdz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Chehalis",
        "iso3": "cea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cebuano",
        "iso3": "ceb",
        "iso2b": "ceb",
        "iso2t": "ceb",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chamacoco",
        "iso3": "ceg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Khumi Chin",
        "iso3": "cek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cen",
        "iso3": "cen",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Czech",
        "iso3": "ces",
        "iso2b": "cze",
        "iso2t": "ces",
        "iso1": "cs",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Centúúm",
        "iso3": "cet",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ekai Chin",
        "iso3": "cey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dijim-Bwilim",
        "iso3": "cfa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cara",
        "iso3": "cfd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Como Karim",
        "iso3": "cfg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Falam Chin",
        "iso3": "cfm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Changriwa",
        "iso3": "cga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kagayanen",
        "iso3": "cgc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chiga",
        "iso3": "cgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chocangacakha",
        "iso3": "cgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chamorro",
        "iso3": "cha",
        "iso2b": "cha",
        "iso2t": "cha",
        "iso1": "ch",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chibcha",
        "iso3": "chb",
        "iso2b": "chb",
        "iso2t": "chb",
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Catawba",
        "iso3": "chc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Highland Oaxaca Chontal",
        "iso3": "chd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chechen",
        "iso3": "che",
        "iso2b": "che",
        "iso2t": "che",
        "iso1": "ce",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabasco Chontal",
        "iso3": "chf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chagatai",
        "iso3": "chg",
        "iso2b": "chg",
        "iso2t": "chg",
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chinook",
        "iso3": "chh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ojitlán Chinantec",
        "iso3": "chj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chuukese",
        "iso3": "chk",
        "iso2b": "chk",
        "iso2t": "chk",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cahuilla",
        "iso3": "chl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mari (Russia)",
        "iso3": "chm",
        "iso2b": "chm",
        "iso2t": "chm",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Chinook jargon",
        "iso3": "chn",
        "iso2b": "chn",
        "iso2t": "chn",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Choctaw",
        "iso3": "cho",
        "iso2b": "cho",
        "iso2t": "cho",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chipewyan",
        "iso3": "chp",
        "iso2b": "chp",
        "iso2t": "chp",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quiotepec Chinantec",
        "iso3": "chq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cherokee",
        "iso3": "chr",
        "iso2b": "chr",
        "iso2t": "chr",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cholón",
        "iso3": "cht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Church Slavic",
        "iso3": "chu",
        "iso2b": "chu",
        "iso2t": "chu",
        "iso1": "cu",
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Chuvash",
        "iso3": "chv",
        "iso2b": "chv",
        "iso2t": "chv",
        "iso1": "cv",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chuwabu",
        "iso3": "chw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chantyal",
        "iso3": "chx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cheyenne",
        "iso3": "chy",
        "iso2b": "chy",
        "iso2t": "chy",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ozumacín Chinantec",
        "iso3": "chz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cia-Cia",
        "iso3": "cia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ci Gbe",
        "iso3": "cib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chickasaw",
        "iso3": "cic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chimariko",
        "iso3": "cid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cineni",
        "iso3": "cie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chinali",
        "iso3": "cih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chitkuli Kinnauri",
        "iso3": "cik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cimbrian",
        "iso3": "cim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cinta Larga",
        "iso3": "cin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chiapanec",
        "iso3": "cip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiri",
        "iso3": "cir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chippewa",
        "iso3": "ciw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chaima",
        "iso3": "ciy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Cham",
        "iso3": "cja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chru",
        "iso3": "cje",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Chehalis",
        "iso3": "cjh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chamalal",
        "iso3": "cji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chokwe",
        "iso3": "cjk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Cham",
        "iso3": "cjm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chenapian",
        "iso3": "cjn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ashéninka Pajonal",
        "iso3": "cjo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cabécar",
        "iso3": "cjp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shor",
        "iso3": "cjs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chuave",
        "iso3": "cjv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jinyu Chinese",
        "iso3": "cjy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Kurdish",
        "iso3": "ckb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chak",
        "iso3": "ckh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cibak",
        "iso3": "ckl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chakavian",
        "iso3": "ckm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaang Chin",
        "iso3": "ckn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anufo",
        "iso3": "cko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kajakse",
        "iso3": "ckq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kairak",
        "iso3": "ckr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tayo",
        "iso3": "cks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chukot",
        "iso3": "ckt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koasati",
        "iso3": "cku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kavalan",
        "iso3": "ckv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Caka",
        "iso3": "ckx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cakfem-Mushere",
        "iso3": "cky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cakchiquel-Quiché Mixed Language",
        "iso3": "ckz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ron",
        "iso3": "cla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chilcotin",
        "iso3": "clc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chaldean Neo-Aramaic",
        "iso3": "cld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lealao Chinantec",
        "iso3": "cle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chilisso",
        "iso3": "clh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chakali",
        "iso3": "cli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laitu Chin",
        "iso3": "clj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Idu-Mishmi",
        "iso3": "clk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chala",
        "iso3": "cll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Clallam",
        "iso3": "clm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lowland Oaxaca Chontal",
        "iso3": "clo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Classical Sanskrit",
        "iso3": "cls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Lautu Chin",
        "iso3": "clt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Caluyanun",
        "iso3": "clu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chulym",
        "iso3": "clw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Highland Chatino",
        "iso3": "cly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maa",
        "iso3": "cma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cerma",
        "iso3": "cme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Classical Mongolian",
        "iso3": "cmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Emberá-Chamí",
        "iso3": "cmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Campalagian",
        "iso3": "cml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Michigamea",
        "iso3": "cmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mandarin Chinese",
        "iso3": "cmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Mnong",
        "iso3": "cmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mro-Khimi Chin",
        "iso3": "cmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Messapic",
        "iso3": "cms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Camtho",
        "iso3": "cmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Changthang",
        "iso3": "cna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chinbon Chin",
        "iso3": "cnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Côông",
        "iso3": "cnc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Qiang",
        "iso3": "cng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hakha Chin",
        "iso3": "cnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asháninka",
        "iso3": "cni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khumi Chin",
        "iso3": "cnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lalana Chinantec",
        "iso3": "cnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Con",
        "iso3": "cno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Ping Chinese",
        "iso3": "cnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chung",
        "iso3": "cnq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Montenegrin",
        "iso3": "cnr",
        "iso2b": "cnr",
        "iso2t": "cnr",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Asmat",
        "iso3": "cns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tepetotutla Chinantec",
        "iso3": "cnt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chenoua",
        "iso3": "cnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngawn Chin",
        "iso3": "cnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Cornish",
        "iso3": "cnx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Cocos Islands Malay",
        "iso3": "coa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chicomuceltec",
        "iso3": "cob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cocopa",
        "iso3": "coc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cocama-Cocamilla",
        "iso3": "cod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koreguaje",
        "iso3": "coe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Colorado",
        "iso3": "cof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chong",
        "iso3": "cog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chonyi-Dzihana-Kauma",
        "iso3": "coh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cochimi",
        "iso3": "coj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Santa Teresa Cora",
        "iso3": "cok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Columbia-Wenatchi",
        "iso3": "col",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Comanche",
        "iso3": "com",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cofán",
        "iso3": "con",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Comox",
        "iso3": "coo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coptic",
        "iso3": "cop",
        "iso2b": "cop",
        "iso2t": "cop",
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Coquille",
        "iso3": "coq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cornish",
        "iso3": "cor",
        "iso2b": "cor",
        "iso2t": "cor",
        "iso1": "kw",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Corsican",
        "iso3": "cos",
        "iso2b": "cos",
        "iso2t": "cos",
        "iso1": "co",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Caquinte",
        "iso3": "cot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wamey",
        "iso3": "cou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cao Miao",
        "iso3": "cov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cowlitz",
        "iso3": "cow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nanti",
        "iso3": "cox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chochotec",
        "iso3": "coz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Palantla Chinantec",
        "iso3": "cpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ucayali-Yurúa Ashéninka",
        "iso3": "cpb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ajyíninka Apurucayali",
        "iso3": "cpc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cappadocian Greek",
        "iso3": "cpg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chinese Pidgin English",
        "iso3": "cpi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cherepon",
        "iso3": "cpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpeego",
        "iso3": "cpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Capiznon",
        "iso3": "cps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pichis Ashéninka",
        "iso3": "cpu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pu-Xian Chinese",
        "iso3": "cpx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Ucayali Ashéninka",
        "iso3": "cpy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chuanqiandian Cluster Miao",
        "iso3": "cqd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chara",
        "iso3": "cra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Island Carib",
        "iso3": "crb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lonwolwol",
        "iso3": "crc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coeur d'Alene",
        "iso3": "crd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cree",
        "iso3": "cre",
        "iso2b": "cre",
        "iso2t": "cre",
        "iso1": "cr",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Caramanta",
        "iso3": "crf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Michif",
        "iso3": "crg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Crimean Tatar",
        "iso3": "crh",
        "iso2b": "crh",
        "iso2t": "crh",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sãotomense",
        "iso3": "cri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern East Cree",
        "iso3": "crj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Plains Cree",
        "iso3": "crk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern East Cree",
        "iso3": "crl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moose Cree",
        "iso3": "crm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "El Nayar Cora",
        "iso3": "crn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Crow",
        "iso3": "cro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iyo'wujwa Chorote",
        "iso3": "crq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Carolina Algonquian",
        "iso3": "crr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Seselwa Creole French",
        "iso3": "crs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iyojwa'ja Chorote",
        "iso3": "crt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chaura",
        "iso3": "crv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chrau",
        "iso3": "crw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Carrier",
        "iso3": "crx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cori",
        "iso3": "cry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cruzeño",
        "iso3": "crz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chiltepec Chinantec",
        "iso3": "csa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kashubian",
        "iso3": "csb",
        "iso2b": "csb",
        "iso2t": "csb",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Catalan Sign Language",
        "iso3": "csc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chiangmai Sign Language",
        "iso3": "csd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Czech Sign Language",
        "iso3": "cse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cuba Sign Language",
        "iso3": "csf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chilean Sign Language",
        "iso3": "csg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asho Chin",
        "iso3": "csh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coast Miwok",
        "iso3": "csi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Songlai Chin",
        "iso3": "csj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jola-Kasa",
        "iso3": "csk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chinese Sign Language",
        "iso3": "csl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Sierra Miwok",
        "iso3": "csm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Colombian Sign Language",
        "iso3": "csn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sochiapam Chinantec",
        "iso3": "cso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Ping Chinese",
        "iso3": "csp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Croatia Sign Language",
        "iso3": "csq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Costa Rican Sign Language",
        "iso3": "csr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Ohlone",
        "iso3": "css",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Northern Ohlone",
        "iso3": "cst",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sumtu Chin",
        "iso3": "csv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swampy Cree",
        "iso3": "csw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cambodian Sign Language",
        "iso3": "csx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siyin Chin",
        "iso3": "csy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coos",
        "iso3": "csz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tataltepec Chatino",
        "iso3": "cta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chetco",
        "iso3": "ctc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tedim Chin",
        "iso3": "ctd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tepinapa Chinantec",
        "iso3": "cte",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chittagonian",
        "iso3": "ctg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thaiphum Chin",
        "iso3": "cth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tlacoatzintepec Chinantec",
        "iso3": "ctl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chitimacha",
        "iso3": "ctm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chhintange",
        "iso3": "ctn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Emberá-Catío",
        "iso3": "cto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Highland Chatino",
        "iso3": "ctp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Catanduanes Bikol",
        "iso3": "cts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wayanad Chetti",
        "iso3": "ctt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chol",
        "iso3": "ctu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moundadan Chetty",
        "iso3": "cty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zacatepec Chatino",
        "iso3": "ctz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cua",
        "iso3": "cua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cubeo",
        "iso3": "cub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Usila Chinantec",
        "iso3": "cuc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chuka",
        "iso3": "cuh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cuiba",
        "iso3": "cui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mashco Piro",
        "iso3": "cuj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Blas Kuna",
        "iso3": "cuk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Culina",
        "iso3": "cul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cumanagoto",
        "iso3": "cuo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cupeño",
        "iso3": "cup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cun",
        "iso3": "cuq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chhulung",
        "iso3": "cur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teutila Cuicatec",
        "iso3": "cut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Ya",
        "iso3": "cuu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cuvok",
        "iso3": "cuv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chukwa",
        "iso3": "cuw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tepeuxila Cuicatec",
        "iso3": "cux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cuitlatec",
        "iso3": "cuy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chug",
        "iso3": "cvg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Valle Nacional Chinantec",
        "iso3": "cvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabwa",
        "iso3": "cwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maindo",
        "iso3": "cwb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Woods Cree",
        "iso3": "cwd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwere",
        "iso3": "cwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chewong",
        "iso3": "cwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuwaataay",
        "iso3": "cwt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cha'ari",
        "iso3": "cxh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nopala Chatino",
        "iso3": "cya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cayubaba",
        "iso3": "cyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Welsh",
        "iso3": "cym",
        "iso2b": "wel",
        "iso2t": "cym",
        "iso1": "cy",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cuyonon",
        "iso3": "cyo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huizhou Chinese",
        "iso3": "czh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Knaanic",
        "iso3": "czk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Zenzontepec Chatino",
        "iso3": "czn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Min Zhong Chinese",
        "iso3": "czo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zotung Chin",
        "iso3": "czt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dangaléat",
        "iso3": "daa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dambi",
        "iso3": "dac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marik",
        "iso3": "dad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duupa",
        "iso3": "dae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dagbani",
        "iso3": "dag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gwahatike",
        "iso3": "dah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Day",
        "iso3": "dai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dar Fur Daju",
        "iso3": "daj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dakota",
        "iso3": "dak",
        "iso2b": "dak",
        "iso2t": "dak",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dahalo",
        "iso3": "dal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Damakawa",
        "iso3": "dam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Danish",
        "iso3": "dan",
        "iso2b": "dan",
        "iso2t": "dan",
        "iso1": "da",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daai Chin",
        "iso3": "dao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dandami Maria",
        "iso3": "daq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dargwa",
        "iso3": "dar",
        "iso2b": "dar",
        "iso2t": "dar",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daho-Doo",
        "iso3": "das",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dar Sila Daju",
        "iso3": "dau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taita",
        "iso3": "dav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Davawenyo",
        "iso3": "daw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dayi",
        "iso3": "dax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moi-Wadea",
        "iso3": "daz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangime",
        "iso3": "dba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Deno",
        "iso3": "dbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dadiya",
        "iso3": "dbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dabe",
        "iso3": "dbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Edopi",
        "iso3": "dbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dogul Dom Dogon",
        "iso3": "dbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doka",
        "iso3": "dbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ida'an",
        "iso3": "dbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dyirbal",
        "iso3": "dbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duguri",
        "iso3": "dbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duriankere",
        "iso3": "dbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dulbu",
        "iso3": "dbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duwai",
        "iso3": "dbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daba",
        "iso3": "dbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dabarre",
        "iso3": "dbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ben Tey Dogon",
        "iso3": "dbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bondum Dom Dogon",
        "iso3": "dbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dungu",
        "iso3": "dbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bankan Tey Dogon",
        "iso3": "dbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dibiyaso",
        "iso3": "dby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Deccan",
        "iso3": "dcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Negerhollands",
        "iso3": "dcr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dadi Dadi",
        "iso3": "dda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dongotono",
        "iso3": "ddd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doondo",
        "iso3": "dde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fataluku",
        "iso3": "ddg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Goodenough",
        "iso3": "ddi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jaru",
        "iso3": "ddj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dendi (Benin)",
        "iso3": "ddn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dido",
        "iso3": "ddo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhudhuroa",
        "iso3": "ddr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Donno So Dogon",
        "iso3": "dds",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dawera-Daweloor",
        "iso3": "ddw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dagik",
        "iso3": "dec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dedua",
        "iso3": "ded",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dewoin",
        "iso3": "dee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dezfuli",
        "iso3": "def",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Degema",
        "iso3": "deg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dehwari",
        "iso3": "deh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Demisa",
        "iso3": "dei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Delaware",
        "iso3": "del",
        "iso2b": "del",
        "iso2t": "del",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Dem",
        "iso3": "dem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Slave (Athapascan)",
        "iso3": "den",
        "iso2b": "den",
        "iso2t": "den",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Pidgin Delaware",
        "iso3": "dep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dendi (Central African Republic)",
        "iso3": "deq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Deori",
        "iso3": "der",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Desano",
        "iso3": "des",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "German",
        "iso3": "deu",
        "iso2b": "ger",
        "iso2t": "deu",
        "iso1": "de",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Domung",
        "iso3": "dev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dengese",
        "iso3": "dez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Dagaare",
        "iso3": "dga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bunoge Dogon",
        "iso3": "dgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Casiguran Dumagat Agta",
        "iso3": "dgc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dagaari Dioula",
        "iso3": "dgd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Degenan",
        "iso3": "dge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doga",
        "iso3": "dgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dghwede",
        "iso3": "dgh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Dagara",
        "iso3": "dgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dagba",
        "iso3": "dgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andaandi",
        "iso3": "dgl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dagoman",
        "iso3": "dgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dogri (individual language)",
        "iso3": "dgo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tlicho",
        "iso3": "dgr",
        "iso2b": "dgr",
        "iso2t": "dgr",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dogoso",
        "iso3": "dgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndra'ngith",
        "iso3": "dgt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Daungwurrung",
        "iso3": "dgw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Doghoro",
        "iso3": "dgx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daga",
        "iso3": "dgz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhundari",
        "iso3": "dhd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhangu-Djangu",
        "iso3": "dhg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhimal",
        "iso3": "dhi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhalandji",
        "iso3": "dhl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zemba",
        "iso3": "dhm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhanki",
        "iso3": "dhn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhodia",
        "iso3": "dho",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhargari",
        "iso3": "dhr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhaiso",
        "iso3": "dhs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhurga",
        "iso3": "dhu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dehu",
        "iso3": "dhv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhanwar (Nepal)",
        "iso3": "dhw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhungaloo",
        "iso3": "dhx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dia",
        "iso3": "dia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Central Dinka",
        "iso3": "dib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lakota Dida",
        "iso3": "dic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Didinga",
        "iso3": "did",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dieri",
        "iso3": "dif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Digo",
        "iso3": "dig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumiai",
        "iso3": "dih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dimbong",
        "iso3": "dii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dai",
        "iso3": "dij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Dinka",
        "iso3": "dik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dilling",
        "iso3": "dil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dime",
        "iso3": "dim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dinka",
        "iso3": "din",
        "iso2b": "din",
        "iso2t": "din",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Dibo",
        "iso3": "dio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northeastern Dinka",
        "iso3": "dip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dimli (individual language)",
        "iso3": "diq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dirim",
        "iso3": "dir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dimasa",
        "iso3": "dis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Diriku",
        "iso3": "diu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhivehi",
        "iso3": "div",
        "iso2b": "div",
        "iso2t": "div",
        "iso1": "dv",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwestern Dinka",
        "iso3": "diw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dixon Reef",
        "iso3": "dix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Diuwe",
        "iso3": "diy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ding",
        "iso3": "diz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Djadjawurrung",
        "iso3": "dja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Djinba",
        "iso3": "djb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dar Daju Daju",
        "iso3": "djc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Djamindjung",
        "iso3": "djd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zarma",
        "iso3": "dje",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Djangun",
        "iso3": "djf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Djinang",
        "iso3": "dji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Djeebbana",
        "iso3": "djj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Maroon Creole",
        "iso3": "djk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jamsay Dogon",
        "iso3": "djm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jawoyn",
        "iso3": "djn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jangkang",
        "iso3": "djo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Djambarrpuyngu",
        "iso3": "djr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kapriman",
        "iso3": "dju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Djawi",
        "iso3": "djw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dakpakha",
        "iso3": "dka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kadung",
        "iso3": "dkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dakka",
        "iso3": "dkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuijau",
        "iso3": "dkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeastern Dinka",
        "iso3": "dks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mazagway",
        "iso3": "dkx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dolgan",
        "iso3": "dlg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dahalik",
        "iso3": "dlk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dalmatian",
        "iso3": "dlm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Darlong",
        "iso3": "dln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duma",
        "iso3": "dma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mombo Dogon",
        "iso3": "dmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gavak",
        "iso3": "dmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Madhi Madhi",
        "iso3": "dmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dugwor",
        "iso3": "dme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Medefaidrin",
        "iso3": "dmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Upper Kinabatangan",
        "iso3": "dmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Domaaki",
        "iso3": "dmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dameli",
        "iso3": "dml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dama",
        "iso3": "dmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kemedzung",
        "iso3": "dmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Damar",
        "iso3": "dmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dampelas",
        "iso3": "dms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dubu",
        "iso3": "dmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dumpas",
        "iso3": "dmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mudburra",
        "iso3": "dmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dema",
        "iso3": "dmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Demta",
        "iso3": "dmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Grand Valley Dani",
        "iso3": "dna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daonda",
        "iso3": "dnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndendeule",
        "iso3": "dne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dungan",
        "iso3": "dng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Grand Valley Dani",
        "iso3": "dni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dan",
        "iso3": "dnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dengka",
        "iso3": "dnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dzùùngoo",
        "iso3": "dnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndrulo",
        "iso3": "dno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Danaru",
        "iso3": "dnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mid Grand Valley Dani",
        "iso3": "dnt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Danau",
        "iso3": "dnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Danu",
        "iso3": "dnv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Dani",
        "iso3": "dnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dení",
        "iso3": "dny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dom",
        "iso3": "doa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dobu",
        "iso3": "dob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Dong",
        "iso3": "doc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doe",
        "iso3": "doe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Domu",
        "iso3": "dof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dong",
        "iso3": "doh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dogri (macrolanguage)",
        "iso3": "doi",
        "iso2b": "doi",
        "iso2t": "doi",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Dondo",
        "iso3": "dok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doso",
        "iso3": "dol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toura (Papua New Guinea)",
        "iso3": "don",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dongo",
        "iso3": "doo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lukpa",
        "iso3": "dop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dominican Sign Language",
        "iso3": "doq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dori'o",
        "iso3": "dor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dogosé",
        "iso3": "dos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dass",
        "iso3": "dot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dombe",
        "iso3": "dov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doyayo",
        "iso3": "dow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bussa",
        "iso3": "dox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dompo",
        "iso3": "doy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dorze",
        "iso3": "doz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papar",
        "iso3": "dpp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dair",
        "iso3": "drb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minderico",
        "iso3": "drc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Darmiya",
        "iso3": "drd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dolpo",
        "iso3": "dre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rungus",
        "iso3": "drg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "C'Lela",
        "iso3": "dri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paakantyi",
        "iso3": "drl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Damar",
        "iso3": "drn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daro-Matu Melanau",
        "iso3": "dro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dura",
        "iso3": "drq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gedeo",
        "iso3": "drs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Drents",
        "iso3": "drt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rukai",
        "iso3": "dru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Darai",
        "iso3": "dry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Sorbian",
        "iso3": "dsb",
        "iso2b": "dsb",
        "iso2t": "dsb",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dutch Sign Language",
        "iso3": "dse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daasanach",
        "iso3": "dsh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Disa",
        "iso3": "dsi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dokshi",
        "iso3": "dsk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Danish Sign Language",
        "iso3": "dsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dusner",
        "iso3": "dsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Desiya",
        "iso3": "dso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tadaksahak",
        "iso3": "dsq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mardin Sign Language",
        "iso3": "dsz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daur",
        "iso3": "dta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Labuk-Kinabatangan Kadazan",
        "iso3": "dtb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ditidaht",
        "iso3": "dtd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adithinngithigh",
        "iso3": "dth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ana Tinga Dogon",
        "iso3": "dti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tene Kan Dogon",
        "iso3": "dtk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tomo Kan Dogon",
        "iso3": "dtm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daatsʼíin",
        "iso3": "dtn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tommo So Dogon",
        "iso3": "dto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kadazan Dusun",
        "iso3": "dtp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lotud",
        "iso3": "dtr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toro So Dogon",
        "iso3": "dts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toro Tegu Dogon",
        "iso3": "dtt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tebul Ure Dogon",
        "iso3": "dtu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dotyali",
        "iso3": "dty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duala",
        "iso3": "dua",
        "iso2b": "dua",
        "iso2t": "dua",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dubli",
        "iso3": "dub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duna",
        "iso3": "duc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umiray Dumaget Agta",
        "iso3": "due",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dumbea",
        "iso3": "duf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duruma",
        "iso3": "dug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dungra Bhil",
        "iso3": "duh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dumun",
        "iso3": "dui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uyajitaya",
        "iso3": "duk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alabat Island Agta",
        "iso3": "dul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Dutch (ca. 1050-1350)",
        "iso3": "dum",
        "iso2b": "dum",
        "iso2t": "dum",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Dusun Deyah",
        "iso3": "dun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dupaninan Agta",
        "iso3": "duo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duano",
        "iso3": "dup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dusun Malang",
        "iso3": "duq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dii",
        "iso3": "dur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dumi",
        "iso3": "dus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Drung",
        "iso3": "duu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duvle",
        "iso3": "duv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dusun Witu",
        "iso3": "duw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duungooma",
        "iso3": "dux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dicamay Agta",
        "iso3": "duy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Duli-Gey",
        "iso3": "duz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Duau",
        "iso3": "dva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Diri",
        "iso3": "dwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dawik Kui",
        "iso3": "dwk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dawro",
        "iso3": "dwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dutton World Speedwords",
        "iso3": "dws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Dhuwal",
        "iso3": "dwu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dawawa",
        "iso3": "dww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhuwaya",
        "iso3": "dwy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dewas Rai",
        "iso3": "dwz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dyan",
        "iso3": "dya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dyaberdyaber",
        "iso3": "dyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dyugun",
        "iso3": "dyd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Villa Viciosa Agta",
        "iso3": "dyg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Djimini Senoufo",
        "iso3": "dyi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yanda Dom Dogon",
        "iso3": "dym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dyangadi",
        "iso3": "dyn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jola-Fonyi",
        "iso3": "dyo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dyarim",
        "iso3": "dyr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dyula",
        "iso3": "dyu",
        "iso2b": "dyu",
        "iso2t": "dyu",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Djabugay",
        "iso3": "dyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tunzu",
        "iso3": "dza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daza",
        "iso3": "dzd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Djiwarli",
        "iso3": "dze",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dazaga",
        "iso3": "dzg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dzalakha",
        "iso3": "dzl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dzando",
        "iso3": "dzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dzongkha",
        "iso3": "dzo",
        "iso2b": "dzo",
        "iso2t": "dzo",
        "iso1": "dz",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karenggapa",
        "iso3": "eaa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Beginci",
        "iso3": "ebc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ebughu",
        "iso3": "ebg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Bontok",
        "iso3": "ebk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teke-Ebo",
        "iso3": "ebo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ebrié",
        "iso3": "ebr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Embu",
        "iso3": "ebu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eteocretan",
        "iso3": "ecr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ecuadorian Sign Language",
        "iso3": "ecs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eteocypriot",
        "iso3": "ecy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "E",
        "iso3": "eee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Efai",
        "iso3": "efa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Efe",
        "iso3": "efe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Efik",
        "iso3": "efi",
        "iso2b": "efi",
        "iso2t": "efi",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ega",
        "iso3": "ega",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Emilian",
        "iso3": "egl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Benamanga",
        "iso3": "egm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eggon",
        "iso3": "ego",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Egyptian (Ancient)",
        "iso3": "egy",
        "iso2b": "egy",
        "iso2t": "egy",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Miyakubo Sign Language",
        "iso3": "ehs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ehueun",
        "iso3": "ehu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eipomek",
        "iso3": "eip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eitiep",
        "iso3": "eit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Askopan",
        "iso3": "eiv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ejamat",
        "iso3": "eja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ekajuk",
        "iso3": "eka",
        "iso2b": "eka",
        "iso2t": "eka",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ekit",
        "iso3": "eke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ekari",
        "iso3": "ekg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eki",
        "iso3": "eki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Standard Estonian",
        "iso3": "ekk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kol (Bangladesh)",
        "iso3": "ekl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Elip",
        "iso3": "ekm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koti",
        "iso3": "eko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ekpeye",
        "iso3": "ekp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yace",
        "iso3": "ekr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Kayah",
        "iso3": "eky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Elepi",
        "iso3": "ele",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "El Hugeirat",
        "iso3": "elh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nding",
        "iso3": "eli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Elkei",
        "iso3": "elk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Modern Greek (1453-)",
        "iso3": "ell",
        "iso2b": "gre",
        "iso2t": "ell",
        "iso1": "el",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eleme",
        "iso3": "elm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "El Molo",
        "iso3": "elo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Elu",
        "iso3": "elu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Elamite",
        "iso3": "elx",
        "iso2b": "elx",
        "iso2t": "elx",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Emai-Iuleha-Ora",
        "iso3": "ema",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Embaloh",
        "iso3": "emb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Emerillon",
        "iso3": "eme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Meohang",
        "iso3": "emg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mussau-Emira",
        "iso3": "emi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Maninkakan",
        "iso3": "emk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamulique",
        "iso3": "emm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Eman",
        "iso3": "emn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Emberá",
        "iso3": "emp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Minyag",
        "iso3": "emq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pacific Gulf Yupik",
        "iso3": "ems",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Muria",
        "iso3": "emu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Emplawas",
        "iso3": "emw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Erromintxela",
        "iso3": "emx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Epigraphic Mayan",
        "iso3": "emy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mbessa",
        "iso3": "emz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apali",
        "iso3": "ena",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Markweeta",
        "iso3": "enb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "En",
        "iso3": "enc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ende",
        "iso3": "end",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Forest Enets",
        "iso3": "enf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "English",
        "iso3": "eng",
        "iso2b": "eng",
        "iso2t": "eng",
        "iso1": "en",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tundra Enets",
        "iso3": "enh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enlhet",
        "iso3": "enl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle English (1100-1500)",
        "iso3": "enm",
        "iso2b": "enm",
        "iso2t": "enm",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Engenni",
        "iso3": "enn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enggano",
        "iso3": "eno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enga",
        "iso3": "enq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Emumu",
        "iso3": "enr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enu",
        "iso3": "enu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enwan (Edo State)",
        "iso3": "env",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enwan (Akwa Ibom State)",
        "iso3": "enw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enxet",
        "iso3": "enx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beti (Côte d'Ivoire)",
        "iso3": "eot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Epie",
        "iso3": "epi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Esperanto",
        "iso3": "epo",
        "iso2b": "epo",
        "iso2t": "epo",
        "iso1": "eo",
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Eravallan",
        "iso3": "era",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sie",
        "iso3": "erg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eruwa",
        "iso3": "erh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ogea",
        "iso3": "eri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Efate",
        "iso3": "erk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Horpa",
        "iso3": "ero",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Erre",
        "iso3": "err",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ersu",
        "iso3": "ers",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eritai",
        "iso3": "ert",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Erokwanas",
        "iso3": "erw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ese Ejja",
        "iso3": "ese",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aheri Gondi",
        "iso3": "esg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eshtehardi",
        "iso3": "esh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Alaskan Inupiatun",
        "iso3": "esi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwest Alaska Inupiatun",
        "iso3": "esk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Egypt Sign Language",
        "iso3": "esl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Esuma",
        "iso3": "esm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Salvadoran Sign Language",
        "iso3": "esn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Estonian Sign Language",
        "iso3": "eso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Esselen",
        "iso3": "esq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Central Siberian Yupik",
        "iso3": "ess",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Estonian",
        "iso3": "est",
        "iso2b": "est",
        "iso2t": "est",
        "iso1": "et",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Central Yupik",
        "iso3": "esu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eskayan",
        "iso3": "esy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Etebi",
        "iso3": "etb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Etchemin",
        "iso3": "etc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ethiopian Sign Language",
        "iso3": "eth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eton (Vanuatu)",
        "iso3": "etn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eton (Cameroon)",
        "iso3": "eto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Edolo",
        "iso3": "etr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yekhee",
        "iso3": "ets",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Etruscan",
        "iso3": "ett",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ejagham",
        "iso3": "etu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eten",
        "iso3": "etx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Semimi",
        "iso3": "etz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eudeve",
        "iso3": "eud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Basque",
        "iso3": "eus",
        "iso2b": "baq",
        "iso2t": "eus",
        "iso1": "eu",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Even",
        "iso3": "eve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uvbie",
        "iso3": "evh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Evenki",
        "iso3": "evn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ewe",
        "iso3": "ewe",
        "iso2b": "ewe",
        "iso2t": "ewe",
        "iso1": "ee",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ewondo",
        "iso3": "ewo",
        "iso2b": "ewo",
        "iso2t": "ewo",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Extremaduran",
        "iso3": "ext",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eyak",
        "iso3": "eya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Keiyo",
        "iso3": "eyo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ezaa",
        "iso3": "eza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uzekwe",
        "iso3": "eze",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fasu",
        "iso3": "faa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fa d'Ambu",
        "iso3": "fab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wagi",
        "iso3": "fad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fagani",
        "iso3": "faf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Finongan",
        "iso3": "fag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baissa Fali",
        "iso3": "fah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Faiwol",
        "iso3": "fai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Faita",
        "iso3": "faj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fang (Cameroon)",
        "iso3": "fak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Fali",
        "iso3": "fal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fam",
        "iso3": "fam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fang (Equatorial Guinea)",
        "iso3": "fan",
        "iso2b": "fan",
        "iso2t": "fan",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Faroese",
        "iso3": "fao",
        "iso2b": "fao",
        "iso2t": "fao",
        "iso1": "fo",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paloor",
        "iso3": "fap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fataleka",
        "iso3": "far",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Persian",
        "iso3": "fas",
        "iso2b": "per",
        "iso2t": "fas",
        "iso1": "fa",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Fanti",
        "iso3": "fat",
        "iso2b": "fat",
        "iso2t": "fat",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fayu",
        "iso3": "fau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fala",
        "iso3": "fax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Fars",
        "iso3": "fay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwestern Fars",
        "iso3": "faz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Albay Bikol",
        "iso3": "fbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quebec Sign Language",
        "iso3": "fcs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Feroge",
        "iso3": "fer",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Foia Foia",
        "iso3": "ffi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maasina Fulfulde",
        "iso3": "ffm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fongoro",
        "iso3": "fgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nobiin",
        "iso3": "fia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fyer",
        "iso3": "fie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Faifi",
        "iso3": "fif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fijian",
        "iso3": "fij",
        "iso2b": "fij",
        "iso2t": "fij",
        "iso1": "fj",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Filipino",
        "iso3": "fil",
        "iso2b": "fil",
        "iso2t": "fil",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Finnish",
        "iso3": "fin",
        "iso2b": "fin",
        "iso2t": "fin",
        "iso1": "fi",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fipa",
        "iso3": "fip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Firan",
        "iso3": "fir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tornedalen Finnish",
        "iso3": "fit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fiwaga",
        "iso3": "fiw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kirya-Konzəl",
        "iso3": "fkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kven Finnish",
        "iso3": "fkv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalispel-Pend d'Oreille",
        "iso3": "fla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Foau",
        "iso3": "flh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fali",
        "iso3": "fli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Fali",
        "iso3": "fll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Flinders Island",
        "iso3": "fln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Fuliiru",
        "iso3": "flr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Flaaitaal",
        "iso3": "fly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fe'fe'",
        "iso3": "fmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Far Western Muria",
        "iso3": "fmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fanbak",
        "iso3": "fnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fanagalo",
        "iso3": "fng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fania",
        "iso3": "fni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Foodo",
        "iso3": "fod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Foi",
        "iso3": "foi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Foma",
        "iso3": "fom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fon",
        "iso3": "fon",
        "iso2b": "fon",
        "iso2t": "fon",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fore",
        "iso3": "for",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siraya",
        "iso3": "fos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Fernando Po Creole English",
        "iso3": "fpe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fas",
        "iso3": "fqs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "French",
        "iso3": "fra",
        "iso2b": "fre",
        "iso2t": "fra",
        "iso1": "fr",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cajun French",
        "iso3": "frc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fordata",
        "iso3": "frd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Frankish",
        "iso3": "frk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Middle French (ca. 1400-1600)",
        "iso3": "frm",
        "iso2b": "frm",
        "iso2t": "frm",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Old French (842-ca. 1400)",
        "iso3": "fro",
        "iso2b": "fro",
        "iso2t": "fro",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Arpitan",
        "iso3": "frp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Forak",
        "iso3": "frq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Frisian",
        "iso3": "frr",
        "iso2b": "frr",
        "iso2t": "frr",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Frisian",
        "iso3": "frs",
        "iso2b": "frs",
        "iso2t": "frs",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fortsenal",
        "iso3": "frt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Frisian",
        "iso3": "fry",
        "iso2b": "fry",
        "iso2t": "fry",
        "iso1": "fy",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Finnish Sign Language",
        "iso3": "fse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "French Sign Language",
        "iso3": "fsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Finland-Swedish Sign Language",
        "iso3": "fss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adamawa Fulfulde",
        "iso3": "fub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pulaar",
        "iso3": "fuc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Futuna",
        "iso3": "fud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Borgu Fulfulde",
        "iso3": "fue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pular",
        "iso3": "fuf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Niger Fulfulde",
        "iso3": "fuh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bagirmi Fulfulde",
        "iso3": "fui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ko",
        "iso3": "fuj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fulah",
        "iso3": "ful",
        "iso2b": "ful",
        "iso2t": "ful",
        "iso1": "ff",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Fum",
        "iso3": "fum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fulniô",
        "iso3": "fun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central-Eastern Niger Fulfulde",
        "iso3": "fuq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Friulian",
        "iso3": "fur",
        "iso2b": "fur",
        "iso2t": "fur",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Futuna-Aniwa",
        "iso3": "fut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Furu",
        "iso3": "fuu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nigerian Fulfulde",
        "iso3": "fuv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fuyug",
        "iso3": "fuy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fur",
        "iso3": "fvr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fwâi",
        "iso3": "fwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fwe",
        "iso3": "fwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ga",
        "iso3": "gaa",
        "iso2b": "gaa",
        "iso2t": "gaa",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gabri",
        "iso3": "gab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mixed Great Andamanese",
        "iso3": "gac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gaddang",
        "iso3": "gad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guarequena",
        "iso3": "gae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gende",
        "iso3": "gaf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gagauz",
        "iso3": "gag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alekano",
        "iso3": "gah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Borei",
        "iso3": "gai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gadsup",
        "iso3": "gaj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gamkonora",
        "iso3": "gak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Galolen",
        "iso3": "gal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kandawo",
        "iso3": "gam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gan Chinese",
        "iso3": "gan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gants",
        "iso3": "gao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gal",
        "iso3": "gap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gata'",
        "iso3": "gaq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Galeya",
        "iso3": "gar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adiwasi Garasia",
        "iso3": "gas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kenati",
        "iso3": "gat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mudhili Gadaba",
        "iso3": "gau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nobonob",
        "iso3": "gaw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Borana-Arsi-Guji Oromo",
        "iso3": "gax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gayo",
        "iso3": "gay",
        "iso2b": "gay",
        "iso2t": "gay",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Central Oromo",
        "iso3": "gaz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbaya (Central African Republic)",
        "iso3": "gba",
        "iso2b": "gba",
        "iso2t": "gba",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Kaytetye",
        "iso3": "gbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karajarri",
        "iso3": "gbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Niksek",
        "iso3": "gbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gaikundi",
        "iso3": "gbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbanziri",
        "iso3": "gbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Defi Gbe",
        "iso3": "gbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Galela",
        "iso3": "gbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bodo Gadaba",
        "iso3": "gbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gaddi",
        "iso3": "gbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gamit",
        "iso3": "gbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Garhwali",
        "iso3": "gbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mo'da",
        "iso3": "gbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Grebo",
        "iso3": "gbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbaya-Bossangoa",
        "iso3": "gbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbaya-Bozoum",
        "iso3": "gbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbagyi",
        "iso3": "gbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbesi Gbe",
        "iso3": "gbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gagadu",
        "iso3": "gbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbanu",
        "iso3": "gbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gabi-Gabi",
        "iso3": "gbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Xwla Gbe",
        "iso3": "gbx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbari",
        "iso3": "gby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zoroastrian Dari",
        "iso3": "gbz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mali",
        "iso3": "gcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ganggalida",
        "iso3": "gcd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Galice",
        "iso3": "gce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Guadeloupean Creole French",
        "iso3": "gcf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Grenadian Creole English",
        "iso3": "gcl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gaina",
        "iso3": "gcn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guianese Creole French",
        "iso3": "gcr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Colonia Tovar German",
        "iso3": "gct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gade Lohar",
        "iso3": "gda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pottangi Ollar Gadaba",
        "iso3": "gdb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gugu Badhun",
        "iso3": "gdc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gedaged",
        "iso3": "gdd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gude",
        "iso3": "gde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guduf-Gava",
        "iso3": "gdf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ga'dang",
        "iso3": "gdg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gadjerawang",
        "iso3": "gdh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gundi",
        "iso3": "gdi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gurdjar",
        "iso3": "gdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gadang",
        "iso3": "gdk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dirasha",
        "iso3": "gdl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laal",
        "iso3": "gdm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umanakaina",
        "iso3": "gdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghodoberi",
        "iso3": "gdo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mehri",
        "iso3": "gdq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wipi",
        "iso3": "gdr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghandruk Sign Language",
        "iso3": "gds",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kungardutyi",
        "iso3": "gdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gudu",
        "iso3": "gdu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Godwari",
        "iso3": "gdx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Geruma",
        "iso3": "gea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kire",
        "iso3": "geb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gboloo Grebo",
        "iso3": "gec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gade",
        "iso3": "ged",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gerai",
        "iso3": "gef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gengle",
        "iso3": "geg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hutterite German",
        "iso3": "geh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gebe",
        "iso3": "gei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gen",
        "iso3": "gej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ywom",
        "iso3": "gek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ut-Ma'in",
        "iso3": "gel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Geme",
        "iso3": "geq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Geser-Gorom",
        "iso3": "ges",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eviya",
        "iso3": "gev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gera",
        "iso3": "gew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Garre",
        "iso3": "gex",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enya",
        "iso3": "gey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Geez",
        "iso3": "gez",
        "iso2b": "gez",
        "iso2t": "gez",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Patpatar",
        "iso3": "gfk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gafat",
        "iso3": "gft",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gao",
        "iso3": "gga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbii",
        "iso3": "ggb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gugadj",
        "iso3": "ggd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gurr-goni",
        "iso3": "gge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gurgula",
        "iso3": "ggg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kungarakany",
        "iso3": "ggk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ganglau",
        "iso3": "ggl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gitua",
        "iso3": "ggt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gagu",
        "iso3": "ggu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gogodala",
        "iso3": "ggw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghadamès",
        "iso3": "gha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hiberno-Scottish Gaelic",
        "iso3": "ghc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Southern Ghale",
        "iso3": "ghe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Ghale",
        "iso3": "ghh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Geko Karen",
        "iso3": "ghk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghulfan",
        "iso3": "ghl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghanongga",
        "iso3": "ghn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghomara",
        "iso3": "gho",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghera",
        "iso3": "ghr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guhu-Samane",
        "iso3": "ghs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuke",
        "iso3": "ght",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kija",
        "iso3": "gia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gibanawa",
        "iso3": "gib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gail",
        "iso3": "gic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gidar",
        "iso3": "gid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gaɓogbo",
        "iso3": "gie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Goaria",
        "iso3": "gig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Githabul",
        "iso3": "gih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Girirra",
        "iso3": "gii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gilbertese",
        "iso3": "gil",
        "iso2b": "gil",
        "iso2t": "gil",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gimi (Eastern Highlands)",
        "iso3": "gim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hinukh",
        "iso3": "gin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gimi (West New Britain)",
        "iso3": "gip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Green Gelao",
        "iso3": "giq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Red Gelao",
        "iso3": "gir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Giziga",
        "iso3": "gis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gitxsan",
        "iso3": "git",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mulao",
        "iso3": "giu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "White Gelao",
        "iso3": "giw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gilima",
        "iso3": "gix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Giyug",
        "iso3": "giy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Giziga",
        "iso3": "giz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kachi Koli",
        "iso3": "gjk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gunditjmara",
        "iso3": "gjm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gonja",
        "iso3": "gjn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gurindji Kriol",
        "iso3": "gjr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gujari",
        "iso3": "gju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guya",
        "iso3": "gka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Magɨ (Madang Province)",
        "iso3": "gkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndai",
        "iso3": "gke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gokana",
        "iso3": "gkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kok-Nar",
        "iso3": "gko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Guinea Kpelle",
        "iso3": "gkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ǂUngkue",
        "iso3": "gku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Scottish Gaelic",
        "iso3": "gla",
        "iso2b": "gla",
        "iso2t": "gla",
        "iso1": "gd",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Belning",
        "iso3": "glb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bon Gula",
        "iso3": "glc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nanai",
        "iso3": "gld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Irish",
        "iso3": "gle",
        "iso2b": "gle",
        "iso2t": "gle",
        "iso1": "ga",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Galician",
        "iso3": "glg",
        "iso2b": "glg",
        "iso2t": "glg",
        "iso1": "gl",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwest Pashai",
        "iso3": "glh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gula Iro",
        "iso3": "glj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gilaki",
        "iso3": "glk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Garlali",
        "iso3": "gll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Galambu",
        "iso3": "glo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Glaro-Twabo",
        "iso3": "glr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gula (Chad)",
        "iso3": "glu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manx",
        "iso3": "glv",
        "iso2b": "glv",
        "iso2t": "glv",
        "iso1": "gv",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Glavda",
        "iso3": "glw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gule",
        "iso3": "gly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gambera",
        "iso3": "gma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gula'alaa",
        "iso3": "gmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mághdì",
        "iso3": "gmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Magɨyi",
        "iso3": "gmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle High German (ca. 1050-1500)",
        "iso3": "gmh",
        "iso2b": "gmh",
        "iso2t": "gmh",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Middle Low German",
        "iso3": "gml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Gbaya-Mbodomo",
        "iso3": "gmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gimnime",
        "iso3": "gmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mirning",
        "iso3": "gmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gumalu",
        "iso3": "gmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gamo",
        "iso3": "gmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Magoma",
        "iso3": "gmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mycenaean Greek",
        "iso3": "gmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mgbolizhia",
        "iso3": "gmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaansa",
        "iso3": "gna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gangte",
        "iso3": "gnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guanche",
        "iso3": "gnc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Zulgo-Gemzek",
        "iso3": "gnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ganang",
        "iso3": "gne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngangam",
        "iso3": "gng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lere",
        "iso3": "gnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gooniyandi",
        "iso3": "gni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngen",
        "iso3": "gnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ǁGana",
        "iso3": "gnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gangulu",
        "iso3": "gnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ginuman",
        "iso3": "gnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gumatj",
        "iso3": "gnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Gondi",
        "iso3": "gno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gana",
        "iso3": "gnq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gureng Gureng",
        "iso3": "gnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Guntai",
        "iso3": "gnt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gnau",
        "iso3": "gnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Bolivian Guaraní",
        "iso3": "gnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ganzi",
        "iso3": "gnz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guro",
        "iso3": "goa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Playero",
        "iso3": "gob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gorakor",
        "iso3": "goc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Godié",
        "iso3": "god",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gongduk",
        "iso3": "goe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gofa",
        "iso3": "gof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gogo",
        "iso3": "gog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old High German (ca. 750-1050)",
        "iso3": "goh",
        "iso2b": "goh",
        "iso2t": "goh",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Gobasi",
        "iso3": "goi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gowlan",
        "iso3": "goj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gowli",
        "iso3": "gok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gola",
        "iso3": "gol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Goan Konkani",
        "iso3": "gom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gondi",
        "iso3": "gon",
        "iso2b": "gon",
        "iso2t": "gon",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Gone Dau",
        "iso3": "goo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yeretuar",
        "iso3": "gop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gorap",
        "iso3": "goq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gorontalo",
        "iso3": "gor",
        "iso2b": "gor",
        "iso2t": "gor",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gronings",
        "iso3": "gos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gothic",
        "iso3": "got",
        "iso2b": "got",
        "iso2t": "got",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Gavar",
        "iso3": "gou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Goo",
        "iso3": "gov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gorowa",
        "iso3": "gow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gobu",
        "iso3": "gox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Goundo",
        "iso3": "goy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gozarkhani",
        "iso3": "goz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gupa-Abawa",
        "iso3": "gpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghanaian Pidgin English",
        "iso3": "gpe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taiap",
        "iso3": "gpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ga'anda",
        "iso3": "gqa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guiqiong",
        "iso3": "gqi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guana (Brazil)",
        "iso3": "gqn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gor",
        "iso3": "gqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Qau",
        "iso3": "gqu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rajput Garasia",
        "iso3": "gra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Grebo",
        "iso3": "grb",
        "iso2b": "grb",
        "iso2t": "grb",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Ancient Greek (to 1453)",
        "iso3": "grc",
        "iso2b": "grc",
        "iso2t": "grc",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Guruntum-Mbaaru",
        "iso3": "grd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Madi",
        "iso3": "grg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbiri-Niragu",
        "iso3": "grh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghari",
        "iso3": "gri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Grebo",
        "iso3": "grj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kota Marudu Talantang",
        "iso3": "grm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guarani",
        "iso3": "grn",
        "iso2b": "grn",
        "iso2t": "grn",
        "iso1": "gn",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Groma",
        "iso3": "gro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gorovu",
        "iso3": "grq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taznatit",
        "iso3": "grr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gresi",
        "iso3": "grs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Garo",
        "iso3": "grt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kistane",
        "iso3": "gru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Grebo",
        "iso3": "grv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gweda",
        "iso3": "grw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guriaso",
        "iso3": "grx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barclayville Grebo",
        "iso3": "gry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guramalum",
        "iso3": "grz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ghanaian Sign Language",
        "iso3": "gse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "German Sign Language",
        "iso3": "gsg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gusilay",
        "iso3": "gsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guatemalan Sign Language",
        "iso3": "gsm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nema",
        "iso3": "gsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwest Gbaya",
        "iso3": "gso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wasembo",
        "iso3": "gsp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Greek Sign Language",
        "iso3": "gss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swiss German",
        "iso3": "gsw",
        "iso2b": "gsw",
        "iso2t": "gsw",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guató",
        "iso3": "gta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aghu-Tharnggala",
        "iso3": "gtu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Shiki",
        "iso3": "gua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guajajára",
        "iso3": "gub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wayuu",
        "iso3": "guc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yocoboué Dida",
        "iso3": "gud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gurindji",
        "iso3": "gue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gupapuyngu",
        "iso3": "guf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paraguayan Guaraní",
        "iso3": "gug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guahibo",
        "iso3": "guh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Bolivian Guaraní",
        "iso3": "gui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gujarati",
        "iso3": "guj",
        "iso2b": "guj",
        "iso2t": "guj",
        "iso1": "gu",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gumuz",
        "iso3": "guk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sea Island Creole English",
        "iso3": "gul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guambiano",
        "iso3": "gum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbyá Guaraní",
        "iso3": "gun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guayabero",
        "iso3": "guo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gunwinggu",
        "iso3": "gup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aché",
        "iso3": "guq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Farefare",
        "iso3": "gur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guinean Sign Language",
        "iso3": "gus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maléku Jaíka",
        "iso3": "gut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yanomamö",
        "iso3": "guu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gun",
        "iso3": "guw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gourmanchéma",
        "iso3": "gux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gusii",
        "iso3": "guz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guana (Paraguay)",
        "iso3": "gva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guanano",
        "iso3": "gvc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duwet",
        "iso3": "gve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Golin",
        "iso3": "gvf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guajá",
        "iso3": "gvj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gulay",
        "iso3": "gvl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gurmana",
        "iso3": "gvm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuku-Yalanji",
        "iso3": "gvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gavião Do Jiparaná",
        "iso3": "gvo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pará Gavião",
        "iso3": "gvp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gurung",
        "iso3": "gvr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gumawana",
        "iso3": "gvs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guyani",
        "iso3": "gvy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mbato",
        "iso3": "gwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gwa",
        "iso3": "gwb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gawri",
        "iso3": "gwc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gawwada",
        "iso3": "gwd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gweno",
        "iso3": "gwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gowro",
        "iso3": "gwf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moo",
        "iso3": "gwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gwichʼin",
        "iso3": "gwi",
        "iso2b": "gwi",
        "iso2t": "gwi",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ǀGwi",
        "iso3": "gwj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awngthim",
        "iso3": "gwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gwandara",
        "iso3": "gwn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gwere",
        "iso3": "gwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gawar-Bati",
        "iso3": "gwt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guwamu",
        "iso3": "gwu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kwini",
        "iso3": "gww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gua",
        "iso3": "gwx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wè Southern",
        "iso3": "gxx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwest Gbaya",
        "iso3": "gya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Garus",
        "iso3": "gyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayardild",
        "iso3": "gyd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gyem",
        "iso3": "gye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gungabula",
        "iso3": "gyf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gbayi",
        "iso3": "gyg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gyele",
        "iso3": "gyi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gayil",
        "iso3": "gyl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngäbere",
        "iso3": "gym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guyanese Creole English",
        "iso3": "gyn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gyalsumdo",
        "iso3": "gyo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guarayu",
        "iso3": "gyr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gunya",
        "iso3": "gyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Geji",
        "iso3": "gyz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ganza",
        "iso3": "gza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gazi",
        "iso3": "gzi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gane",
        "iso3": "gzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Han",
        "iso3": "haa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hanoi Sign Language",
        "iso3": "hab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gurani",
        "iso3": "hac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hatam",
        "iso3": "had",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Oromo",
        "iso3": "hae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haiphong Sign Language",
        "iso3": "haf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hanga",
        "iso3": "hag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hahon",
        "iso3": "hah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haida",
        "iso3": "hai",
        "iso2b": "hai",
        "iso2t": "hai",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Hajong",
        "iso3": "haj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hakka Chinese",
        "iso3": "hak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Halang",
        "iso3": "hal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hewa",
        "iso3": "ham",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hangaza",
        "iso3": "han",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hakö",
        "iso3": "hao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hupla",
        "iso3": "hap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ha",
        "iso3": "haq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Harari",
        "iso3": "har",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haisla",
        "iso3": "has",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haitian",
        "iso3": "hat",
        "iso2b": "hat",
        "iso2t": "hat",
        "iso1": "ht",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hausa",
        "iso3": "hau",
        "iso2b": "hau",
        "iso2t": "hau",
        "iso1": "ha",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Havu",
        "iso3": "hav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hawaiian",
        "iso3": "haw",
        "iso2b": "haw",
        "iso2t": "haw",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Haida",
        "iso3": "hax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haya",
        "iso3": "hay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hazaragi",
        "iso3": "haz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hamba",
        "iso3": "hba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huba",
        "iso3": "hbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Heiban",
        "iso3": "hbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ancient Hebrew",
        "iso3": "hbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Serbo-Croatian",
        "iso3": "hbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": "sh",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Habu",
        "iso3": "hbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andaman Creole Hindi",
        "iso3": "hca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huichol",
        "iso3": "hch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Haida",
        "iso3": "hdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Honduras Sign Language",
        "iso3": "hds",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hadiyya",
        "iso3": "hdy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Qiandong Miao",
        "iso3": "hea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hebrew",
        "iso3": "heb",
        "iso2b": "heb",
        "iso2t": "heb",
        "iso1": "he",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Herdé",
        "iso3": "hed",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Helong",
        "iso3": "heg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hehe",
        "iso3": "heh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Heiltsuk",
        "iso3": "hei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hemba",
        "iso3": "hem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Herero",
        "iso3": "her",
        "iso2b": "her",
        "iso2t": "her",
        "iso1": "hz",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haiǁom",
        "iso3": "hgm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haigwai",
        "iso3": "hgw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hoia Hoia",
        "iso3": "hhi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kerak",
        "iso3": "hhr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hoyahoya",
        "iso3": "hhy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamang",
        "iso3": "hia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hibito",
        "iso3": "hib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Hidatsa",
        "iso3": "hid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fiji Hindi",
        "iso3": "hif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamwe",
        "iso3": "hig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pamosu",
        "iso3": "hih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hinduri",
        "iso3": "hii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hijuk",
        "iso3": "hij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seit-Kaitetu",
        "iso3": "hik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hiligaynon",
        "iso3": "hil",
        "iso2b": "hil",
        "iso2t": "hil",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hindi",
        "iso3": "hin",
        "iso2b": "hin",
        "iso2t": "hin",
        "iso1": "hi",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsoa",
        "iso3": "hio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Himarimã",
        "iso3": "hir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hittite",
        "iso3": "hit",
        "iso2b": "hit",
        "iso2t": "hit",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Hiw",
        "iso3": "hiw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hixkaryána",
        "iso3": "hix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haji",
        "iso3": "hji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kahe",
        "iso3": "hka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hunde",
        "iso3": "hke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khah",
        "iso3": "hkh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hunjara-Kaina Ke",
        "iso3": "hkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mel-Khaonh",
        "iso3": "hkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hong Kong Sign Language",
        "iso3": "hks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Halia",
        "iso3": "hla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Halbi",
        "iso3": "hlb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Halang Doan",
        "iso3": "hld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hlersu",
        "iso3": "hle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matu Chin",
        "iso3": "hlt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hieroglyphic Luwian",
        "iso3": "hlu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Southern Mashan Hmong",
        "iso3": "hma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Humburi Senni Songhay",
        "iso3": "hmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Huishui Hmong",
        "iso3": "hmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Large Flowery Miao",
        "iso3": "hmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Huishui Hmong",
        "iso3": "hme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hmong Don",
        "iso3": "hmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Guiyang Hmong",
        "iso3": "hmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Huishui Hmong",
        "iso3": "hmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Huishui Hmong",
        "iso3": "hmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ge",
        "iso3": "hmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maek",
        "iso3": "hmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Luopohe Hmong",
        "iso3": "hml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Mashan Hmong",
        "iso3": "hmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hmong",
        "iso3": "hmn",
        "iso2b": "hmn",
        "iso2t": "hmn",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Hiri Motu",
        "iso3": "hmo",
        "iso2b": "hmo",
        "iso2t": "hmo",
        "iso1": "ho",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Mashan Hmong",
        "iso3": "hmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Qiandong Miao",
        "iso3": "hmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hmar",
        "iso3": "hmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Qiandong Miao",
        "iso3": "hms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hamtai",
        "iso3": "hmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hamap",
        "iso3": "hmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hmong Dô",
        "iso3": "hmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Mashan Hmong",
        "iso3": "hmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Guiyang Hmong",
        "iso3": "hmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hmong Shua",
        "iso3": "hmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mina (Cameroon)",
        "iso3": "hna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Hindko",
        "iso3": "hnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chhattisgarhi",
        "iso3": "hne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hungu",
        "iso3": "hng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ǁAni",
        "iso3": "hnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hani",
        "iso3": "hni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hmong Njua",
        "iso3": "hnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hainanese",
        "iso3": "hnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hanunoo",
        "iso3": "hnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Hindko",
        "iso3": "hno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Caribbean Hindustani",
        "iso3": "hns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hung",
        "iso3": "hnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hoava",
        "iso3": "hoa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mari (Madang Province)",
        "iso3": "hob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ho",
        "iso3": "hoc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Holma",
        "iso3": "hod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Horom",
        "iso3": "hoe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hobyót",
        "iso3": "hoh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Holikachuk",
        "iso3": "hoi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hadothi",
        "iso3": "hoj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Holu",
        "iso3": "hol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Homa",
        "iso3": "hom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Holoholo",
        "iso3": "hoo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hopi",
        "iso3": "hop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Horo",
        "iso3": "hor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ho Chi Minh City Sign Language",
        "iso3": "hos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hote",
        "iso3": "hot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hovongan",
        "iso3": "hov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Honi",
        "iso3": "how",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Holiya",
        "iso3": "hoy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hozo",
        "iso3": "hoz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hpon",
        "iso3": "hpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Hawai'i Sign Language (HSL)",
        "iso3": "hps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hrangkhol",
        "iso3": "hra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Niwer Mil",
        "iso3": "hrc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hre",
        "iso3": "hre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haruku",
        "iso3": "hrk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Horned Miao",
        "iso3": "hrm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haroi",
        "iso3": "hro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nhirrpi",
        "iso3": "hrp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Hértevin",
        "iso3": "hrt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hruso",
        "iso3": "hru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Croatian",
        "iso3": "hrv",
        "iso2b": "hrv",
        "iso2t": "hrv",
        "iso1": "hr",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warwar Feni",
        "iso3": "hrw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hunsrik",
        "iso3": "hrx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Harzani",
        "iso3": "hrz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Sorbian",
        "iso3": "hsb",
        "iso2b": "hsb",
        "iso2t": "hsb",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hungarian Sign Language",
        "iso3": "hsh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hausa Sign Language",
        "iso3": "hsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xiang Chinese",
        "iso3": "hsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Harsusi",
        "iso3": "hss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hoti",
        "iso3": "hti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Minica Huitoto",
        "iso3": "hto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hadza",
        "iso3": "hts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hitu",
        "iso3": "htu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Hittite",
        "iso3": "htx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Huambisa",
        "iso3": "hub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ǂHua",
        "iso3": "huc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huaulu",
        "iso3": "hud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Francisco Del Mar Huave",
        "iso3": "hue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Humene",
        "iso3": "huf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huachipaeri",
        "iso3": "hug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huilliche",
        "iso3": "huh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huli",
        "iso3": "hui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Guiyang Hmong",
        "iso3": "huj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hulung",
        "iso3": "huk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Hula",
        "iso3": "hul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hungana",
        "iso3": "hum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hungarian",
        "iso3": "hun",
        "iso2b": "hun",
        "iso2t": "hun",
        "iso1": "hu",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hu",
        "iso3": "huo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hupa",
        "iso3": "hup",
        "iso2b": "hup",
        "iso2t": "hup",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsat",
        "iso3": "huq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Halkomelem",
        "iso3": "hur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huastec",
        "iso3": "hus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Humla",
        "iso3": "hut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Murui Huitoto",
        "iso3": "huu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Mateo Del Mar Huave",
        "iso3": "huv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hukumina",
        "iso3": "huw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nüpode Huitoto",
        "iso3": "hux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hulaulá",
        "iso3": "huy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hunzib",
        "iso3": "huz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haitian Vodoun Culture Language",
        "iso3": "hvc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Dionisio Del Mar Huave",
        "iso3": "hve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haveke",
        "iso3": "hvk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sabu",
        "iso3": "hvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santa María Del Mar Huave",
        "iso3": "hvv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wané",
        "iso3": "hwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hawai'i Creole English",
        "iso3": "hwc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hwana",
        "iso3": "hwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hya",
        "iso3": "hya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Armenian",
        "iso3": "hye",
        "iso2b": "arm",
        "iso2t": "hye",
        "iso1": "hy",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Armenian",
        "iso3": "hyw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iaai",
        "iso3": "iai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iatmul",
        "iso3": "ian",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Purari",
        "iso3": "iar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iban",
        "iso3": "iba",
        "iso2b": "iba",
        "iso2t": "iba",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibibio",
        "iso3": "ibb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iwaidja",
        "iso3": "ibd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akpes",
        "iso3": "ibe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibanag",
        "iso3": "ibg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bih",
        "iso3": "ibh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibaloi",
        "iso3": "ibl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agoi",
        "iso3": "ibm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibino",
        "iso3": "ibn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Igbo",
        "iso3": "ibo",
        "iso2b": "ibo",
        "iso2t": "ibo",
        "iso1": "ig",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibuoro",
        "iso3": "ibr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibu",
        "iso3": "ibu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibani",
        "iso3": "iby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ede Ica",
        "iso3": "ica",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Etkywan",
        "iso3": "ich",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Icelandic Sign Language",
        "iso3": "icl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Islander Creole English",
        "iso3": "icr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Idakho-Isukha-Tiriki",
        "iso3": "ida",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Indo-Portuguese",
        "iso3": "idb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Idon",
        "iso3": "idc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ede Idaca",
        "iso3": "idd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Idere",
        "iso3": "ide",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Idi",
        "iso3": "idi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ido",
        "iso3": "ido",
        "iso2b": "ido",
        "iso2t": "ido",
        "iso1": "io",
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Indri",
        "iso3": "idr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Idesa",
        "iso3": "ids",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Idaté",
        "iso3": "idt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Idoma",
        "iso3": "idu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amganad Ifugao",
        "iso3": "ifa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Batad Ifugao",
        "iso3": "ifb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ifè",
        "iso3": "ife",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ifo",
        "iso3": "iff",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tuwali Ifugao",
        "iso3": "ifk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teke-Fuumu",
        "iso3": "ifm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mayoyao Ifugao",
        "iso3": "ifu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keley-I Kallahan",
        "iso3": "ify",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ebira",
        "iso3": "igb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Igede",
        "iso3": "ige",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Igana",
        "iso3": "igg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Igala",
        "iso3": "igl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanggape",
        "iso3": "igm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ignaciano",
        "iso3": "ign",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isebe",
        "iso3": "igo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Interglossa",
        "iso3": "igs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Igwe",
        "iso3": "igw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iha Based Pidgin",
        "iso3": "ihb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ihievbe",
        "iso3": "ihi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iha",
        "iso3": "ihp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bidhawal",
        "iso3": "ihw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sichuan Yi",
        "iso3": "iii",
        "iso2b": "iii",
        "iso2t": "iii",
        "iso1": "ii",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thiin",
        "iso3": "iin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Izon",
        "iso3": "ijc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Biseni",
        "iso3": "ije",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ede Ije",
        "iso3": "ijj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalabari",
        "iso3": "ijn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeast Ijo",
        "iso3": "ijs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Canadian Inuktitut",
        "iso3": "ike",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikhin-Arokho",
        "iso3": "ikh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iko",
        "iso3": "iki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ika",
        "iso3": "ikk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikulu",
        "iso3": "ikl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Olulumo-Ikom",
        "iso3": "iko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikpeshi",
        "iso3": "ikp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikaranggal",
        "iso3": "ikr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Inuit Sign Language",
        "iso3": "iks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inuinnaqtun",
        "iso3": "ikt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inuktitut",
        "iso3": "iku",
        "iso2b": "iku",
        "iso2t": "iku",
        "iso1": "iu",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Iku-Gora-Ankwa",
        "iso3": "ikv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikwere",
        "iso3": "ikw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ik",
        "iso3": "ikx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikizu",
        "iso3": "ikz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ile Ape",
        "iso3": "ila",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ila",
        "iso3": "ilb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Interlingue",
        "iso3": "ile",
        "iso2b": "ile",
        "iso2t": "ile",
        "iso1": "ie",
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Garig-Ilgar",
        "iso3": "ilg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ili Turki",
        "iso3": "ili",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ilongot",
        "iso3": "ilk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iranun (Malaysia)",
        "iso3": "ilm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iloko",
        "iso3": "ilo",
        "iso2b": "ilo",
        "iso2t": "ilo",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iranun (Philippines)",
        "iso3": "ilp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "International Sign",
        "iso3": "ils",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ili'uun",
        "iso3": "ilu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ilue",
        "iso3": "ilv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mala Malasar",
        "iso3": "ima",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anamgura",
        "iso3": "imi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miluk",
        "iso3": "iml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Imonda",
        "iso3": "imn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Imbongu",
        "iso3": "imo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Imroing",
        "iso3": "imr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marsian",
        "iso3": "ims",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Imotong",
        "iso3": "imt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Milyan",
        "iso3": "imy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Interlingua (International Auxiliary Language Association)",
        "iso3": "ina",
        "iso2b": "ina",
        "iso2t": "ina",
        "iso1": "ia",
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Inga",
        "iso3": "inb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Indonesian",
        "iso3": "ind",
        "iso2b": "ind",
        "iso2t": "ind",
        "iso1": "id",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Degexit'an",
        "iso3": "ing",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ingush",
        "iso3": "inh",
        "iso2b": "inh",
        "iso2t": "inh",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jungle Inga",
        "iso3": "inj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Indonesian Sign Language",
        "iso3": "inl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minaean",
        "iso3": "inm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Isinai",
        "iso3": "inn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inoke-Yate",
        "iso3": "ino",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iñapari",
        "iso3": "inp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Indian Sign Language",
        "iso3": "ins",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Intha",
        "iso3": "int",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ineseño",
        "iso3": "inz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Inor",
        "iso3": "ior",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuma-Irumu",
        "iso3": "iou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iowa-Oto",
        "iso3": "iow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ipili",
        "iso3": "ipi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inupiaq",
        "iso3": "ipk",
        "iso2b": "ipk",
        "iso2t": "ipk",
        "iso1": "ik",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Ipiko",
        "iso3": "ipo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iquito",
        "iso3": "iqu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikwo",
        "iso3": "iqw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iresim",
        "iso3": "ire",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Irarutu",
        "iso3": "irh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rigwe",
        "iso3": "iri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iraqw",
        "iso3": "irk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Irántxe",
        "iso3": "irn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ir",
        "iso3": "irr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Irula",
        "iso3": "iru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamberau",
        "iso3": "irx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iraya",
        "iso3": "iry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isabi",
        "iso3": "isa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isconahua",
        "iso3": "isc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isnag",
        "iso3": "isd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Italian Sign Language",
        "iso3": "ise",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Irish Sign Language",
        "iso3": "isg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Esan",
        "iso3": "ish",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkem-Nkum",
        "iso3": "isi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ishkashimi",
        "iso3": "isk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Icelandic",
        "iso3": "isl",
        "iso2b": "ice",
        "iso2t": "isl",
        "iso1": "is",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masimasi",
        "iso3": "ism",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isanzu",
        "iso3": "isn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isoko",
        "iso3": "iso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Israeli Sign Language",
        "iso3": "isr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Istriot",
        "iso3": "ist",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isu (Menchum Division)",
        "iso3": "isu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Interslavic",
        "iso3": "isv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Italian",
        "iso3": "ita",
        "iso2b": "ita",
        "iso2t": "ita",
        "iso1": "it",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Binongan Itneg",
        "iso3": "itb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Tidung",
        "iso3": "itd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Itene",
        "iso3": "ite",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Inlaod Itneg",
        "iso3": "iti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Italian",
        "iso3": "itk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Itelmen",
        "iso3": "itl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Itu Mbon Uzo",
        "iso3": "itm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Itonama",
        "iso3": "ito",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iteri",
        "iso3": "itr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isekiri",
        "iso3": "its",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maeng Itneg",
        "iso3": "itt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Itawit",
        "iso3": "itv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ito",
        "iso3": "itw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Itik",
        "iso3": "itx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moyadan Itneg",
        "iso3": "ity",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Itzá",
        "iso3": "itz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iu Mien",
        "iso3": "ium",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibatan",
        "iso3": "ivb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ivatan",
        "iso3": "ivv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "I-Wak",
        "iso3": "iwk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iwam",
        "iso3": "iwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iwur",
        "iso3": "iwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sepik Iwam",
        "iso3": "iws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ixcatec",
        "iso3": "ixc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ixil",
        "iso3": "ixl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iyayu",
        "iso3": "iya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mesaka",
        "iso3": "iyo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaka (Congo)",
        "iso3": "iyx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ingrian",
        "iso3": "izh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kizamani",
        "iso3": "izm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Izere",
        "iso3": "izr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Izii",
        "iso3": "izz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jamamadí",
        "iso3": "jaa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hyam",
        "iso3": "jab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Popti'",
        "iso3": "jac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jahanka",
        "iso3": "jad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yabem",
        "iso3": "jae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jara",
        "iso3": "jaf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jah Hut",
        "iso3": "jah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zazao",
        "iso3": "jaj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jakun",
        "iso3": "jak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yalahatan",
        "iso3": "jal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jamaican Creole English",
        "iso3": "jam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jandai",
        "iso3": "jan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yanyuwa",
        "iso3": "jao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaqay",
        "iso3": "jaq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "New Caledonian Javanese",
        "iso3": "jas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jakati",
        "iso3": "jat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaur",
        "iso3": "jau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Javanese",
        "iso3": "jav",
        "iso2b": "jav",
        "iso2t": "jav",
        "iso1": "jv",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jambi Malay",
        "iso3": "jax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yan-nhangu",
        "iso3": "jay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jawe",
        "iso3": "jaz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Berber",
        "iso3": "jbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Badjiri",
        "iso3": "jbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Arandai",
        "iso3": "jbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barikewa",
        "iso3": "jbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bijim",
        "iso3": "jbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nafusi",
        "iso3": "jbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lojban",
        "iso3": "jbo",
        "iso2b": "jbo",
        "iso2t": "jbo",
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Jofotek-Bromnya",
        "iso3": "jbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jabutí",
        "iso3": "jbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jukun Takum",
        "iso3": "jbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yawijibaya",
        "iso3": "jbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Jamaican Country Sign Language",
        "iso3": "jcs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krymchak",
        "iso3": "jct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jad",
        "iso3": "jda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jadgali",
        "iso3": "jdg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Tat",
        "iso3": "jdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jebero",
        "iso3": "jeb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jerung",
        "iso3": "jee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jeh",
        "iso3": "jeh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yei",
        "iso3": "jei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jeri Kuo",
        "iso3": "jek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yelmek",
        "iso3": "jel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dza",
        "iso3": "jen",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jere",
        "iso3": "jer",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manem",
        "iso3": "jet",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jonkor Bourmataguil",
        "iso3": "jeu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngbee",
        "iso3": "jgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Judeo-Georgian",
        "iso3": "jge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gwak",
        "iso3": "jgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngomba",
        "iso3": "jgo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jehai",
        "iso3": "jhi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jhankot Sign Language",
        "iso3": "jhs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jina",
        "iso3": "jia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jibu",
        "iso3": "jib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tol",
        "iso3": "jic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bu (Kaduna State)",
        "iso3": "jid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jilbe",
        "iso3": "jie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jingulu",
        "iso3": "jig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "sTodsde",
        "iso3": "jih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jiiddu",
        "iso3": "jii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jilim",
        "iso3": "jil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jimi (Cameroon)",
        "iso3": "jim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jiamao",
        "iso3": "jio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guanyinqiao",
        "iso3": "jiq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jita",
        "iso3": "jit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Youle Jinuo",
        "iso3": "jiu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shuar",
        "iso3": "jiv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buyuan Jinuo",
        "iso3": "jiy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jejueo",
        "iso3": "jje",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bankal",
        "iso3": "jjr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaera",
        "iso3": "jka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mobwa Karen",
        "iso3": "jkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kubo",
        "iso3": "jko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paku Karen",
        "iso3": "jkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koro (India)",
        "iso3": "jkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amami Koniya Sign Language",
        "iso3": "jks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Labir",
        "iso3": "jku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngile",
        "iso3": "jle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jamaican Sign Language",
        "iso3": "jls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dima",
        "iso3": "jma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zumbun",
        "iso3": "jmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Machame",
        "iso3": "jmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yamdena",
        "iso3": "jmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jimi (Nigeria)",
        "iso3": "jmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jumli",
        "iso3": "jml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makuri Naga",
        "iso3": "jmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamara",
        "iso3": "jmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mashi (Nigeria)",
        "iso3": "jms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mouwase",
        "iso3": "jmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Juxtlahuaca Mixtec",
        "iso3": "jmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jangshung",
        "iso3": "jna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jandavra",
        "iso3": "jnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yangman",
        "iso3": "jng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Janji",
        "iso3": "jni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yemsa",
        "iso3": "jnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rawat",
        "iso3": "jnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jaunsari",
        "iso3": "jns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Joba",
        "iso3": "job",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wojenaka",
        "iso3": "jod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jogi",
        "iso3": "jog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jorá",
        "iso3": "jor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Jordanian Sign Language",
        "iso3": "jos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jowulu",
        "iso3": "jow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jewish Palestinian Aramaic",
        "iso3": "jpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Japanese",
        "iso3": "jpn",
        "iso2b": "jpn",
        "iso2t": "jpn",
        "iso1": "ja",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Persian",
        "iso3": "jpr",
        "iso2b": "jpr",
        "iso2t": "jpr",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jaqaru",
        "iso3": "jqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jarai",
        "iso3": "jra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Arabic",
        "iso3": "jrb",
        "iso2b": "jrb",
        "iso2t": "jrb",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Jiru",
        "iso3": "jrr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jakattoe",
        "iso3": "jrt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Japrería",
        "iso3": "jru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Japanese Sign Language",
        "iso3": "jsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Júma",
        "iso3": "jua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wannu",
        "iso3": "jub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jurchen",
        "iso3": "juc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Worodougou",
        "iso3": "jud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hõne",
        "iso3": "juh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngadjuri",
        "iso3": "jui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wapan",
        "iso3": "juk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jirel",
        "iso3": "jul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jumjum",
        "iso3": "jum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Juang",
        "iso3": "jun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jiba",
        "iso3": "juo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hupdë",
        "iso3": "jup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jurúna",
        "iso3": "jur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jumla Sign Language",
        "iso3": "jus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jutish",
        "iso3": "jut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ju",
        "iso3": "juu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wãpha",
        "iso3": "juw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Juray",
        "iso3": "juy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Javindo",
        "iso3": "jvd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Caribbean Javanese",
        "iso3": "jvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jwira-Pepesa",
        "iso3": "jwi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jiarong",
        "iso3": "jya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Yemeni Arabic",
        "iso3": "jye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jaya",
        "iso3": "jyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kara-Kalpak",
        "iso3": "kaa",
        "iso2b": "kaa",
        "iso2t": "kaa",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabyle",
        "iso3": "kab",
        "iso2b": "kab",
        "iso2t": "kab",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kachin",
        "iso3": "kac",
        "iso2b": "kac",
        "iso2t": "kac",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adara",
        "iso3": "kad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ketangalan",
        "iso3": "kae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Katso",
        "iso3": "kaf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kajaman",
        "iso3": "kag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kara (Central African Republic)",
        "iso3": "kah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karekare",
        "iso3": "kai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jju",
        "iso3": "kaj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalanguya",
        "iso3": "kak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalaallisut",
        "iso3": "kal",
        "iso2b": "kal",
        "iso2t": "kal",
        "iso1": "kl",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamba (Kenya)",
        "iso3": "kam",
        "iso2b": "kam",
        "iso2t": "kam",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kannada",
        "iso3": "kan",
        "iso2b": "kan",
        "iso2t": "kan",
        "iso1": "kn",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xaasongaxango",
        "iso3": "kao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bezhta",
        "iso3": "kap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Capanahua",
        "iso3": "kaq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kashmiri",
        "iso3": "kas",
        "iso2b": "kas",
        "iso2t": "kas",
        "iso1": "ks",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Georgian",
        "iso3": "kat",
        "iso2b": "geo",
        "iso2t": "kat",
        "iso1": "ka",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanuri",
        "iso3": "kau",
        "iso2b": "kau",
        "iso2t": "kau",
        "iso1": "kr",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Katukína",
        "iso3": "kav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kawi",
        "iso3": "kaw",
        "iso2b": "kaw",
        "iso2t": "kaw",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kao",
        "iso3": "kax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamayurá",
        "iso3": "kay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kazakh",
        "iso3": "kaz",
        "iso2b": "kaz",
        "iso2t": "kaz",
        "iso1": "kk",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalarko",
        "iso3": "kba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kaxuiâna",
        "iso3": "kbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kadiwéu",
        "iso3": "kbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabardian",
        "iso3": "kbd",
        "iso2b": "kbd",
        "iso2t": "kbd",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanju",
        "iso3": "kbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khamba",
        "iso3": "kbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Camsá",
        "iso3": "kbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaptiau",
        "iso3": "kbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kari",
        "iso3": "kbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Grass Koiari",
        "iso3": "kbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanembu",
        "iso3": "kbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iwal",
        "iso3": "kbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kare (Central African Republic)",
        "iso3": "kbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keliko",
        "iso3": "kbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabiyè",
        "iso3": "kbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamano",
        "iso3": "kbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kafa",
        "iso3": "kbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kande",
        "iso3": "kbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abadi",
        "iso3": "kbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabutra",
        "iso3": "kbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dera (Indonesia)",
        "iso3": "kbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaiep",
        "iso3": "kbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ap Ma",
        "iso3": "kbx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manga Kanuri",
        "iso3": "kby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duhwa",
        "iso3": "kbz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khanty",
        "iso3": "kca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kawacha",
        "iso3": "kcb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lubila",
        "iso3": "kcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngkâlmpw Kanum",
        "iso3": "kcd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaivi",
        "iso3": "kce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukaan",
        "iso3": "kcf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tyap",
        "iso3": "kcg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vono",
        "iso3": "kch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamantan",
        "iso3": "kci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kobiana",
        "iso3": "kcj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalanga",
        "iso3": "kck",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kela (Papua New Guinea)",
        "iso3": "kcl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gula (Central African Republic)",
        "iso3": "kcm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nubi",
        "iso3": "kcn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kinalakna",
        "iso3": "kco",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanga",
        "iso3": "kcp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamo",
        "iso3": "kcq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Katla",
        "iso3": "kcr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koenoem",
        "iso3": "kcs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaian",
        "iso3": "kct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kami (Tanzania)",
        "iso3": "kcu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kete",
        "iso3": "kcv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabwari",
        "iso3": "kcw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kachama-Ganjule",
        "iso3": "kcx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korandje",
        "iso3": "kcy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konongo",
        "iso3": "kcz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Worimi",
        "iso3": "kda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kutu",
        "iso3": "kdc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yankunytjatjara",
        "iso3": "kdd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makonde",
        "iso3": "kde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamusi",
        "iso3": "kdf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seba",
        "iso3": "kdg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tem",
        "iso3": "kdh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumam",
        "iso3": "kdi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karamojong",
        "iso3": "kdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Numèè",
        "iso3": "kdk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsikimba",
        "iso3": "kdl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kagoma",
        "iso3": "kdm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunda",
        "iso3": "kdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaningdon-Nindem",
        "iso3": "kdp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koch",
        "iso3": "kdq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karaim",
        "iso3": "kdr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuy",
        "iso3": "kdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kadaru",
        "iso3": "kdu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koneraw",
        "iso3": "kdw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kam",
        "iso3": "kdx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keder",
        "iso3": "kdy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwaja",
        "iso3": "kdz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabuverdianu",
        "iso3": "kea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kélé",
        "iso3": "keb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keiga",
        "iso3": "kec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kerewe",
        "iso3": "ked",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Keres",
        "iso3": "kee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpessi",
        "iso3": "kef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tese",
        "iso3": "keg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keak",
        "iso3": "keh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kei",
        "iso3": "kei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kadar",
        "iso3": "kej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kekchí",
        "iso3": "kek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kela (Democratic Republic of Congo)",
        "iso3": "kel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kemak",
        "iso3": "kem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kenyang",
        "iso3": "ken",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kakwa",
        "iso3": "keo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaikadi",
        "iso3": "kep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamar",
        "iso3": "keq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kera",
        "iso3": "ker",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kugbo",
        "iso3": "kes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ket",
        "iso3": "ket",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akebu",
        "iso3": "keu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanikkaran",
        "iso3": "kev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Kewa",
        "iso3": "kew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kukna",
        "iso3": "kex",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kupia",
        "iso3": "key",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kukele",
        "iso3": "kez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kodava",
        "iso3": "kfa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwestern Kolami",
        "iso3": "kfb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konda-Dora",
        "iso3": "kfc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korra Koraga",
        "iso3": "kfd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kota (India)",
        "iso3": "kfe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koya",
        "iso3": "kff",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kudiya",
        "iso3": "kfg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurichiya",
        "iso3": "kfh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kannada Kurumba",
        "iso3": "kfi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kemiehua",
        "iso3": "kfj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kinnauri",
        "iso3": "kfk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kung",
        "iso3": "kfl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khunsari",
        "iso3": "kfm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuk",
        "iso3": "kfn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koro (Côte d'Ivoire)",
        "iso3": "kfo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korwa",
        "iso3": "kfp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korku",
        "iso3": "kfq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kachhi",
        "iso3": "kfr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bilaspuri",
        "iso3": "kfs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanjari",
        "iso3": "kft",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Katkari",
        "iso3": "kfu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurmukar",
        "iso3": "kfv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kharam Naga",
        "iso3": "kfw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kullu Pahari",
        "iso3": "kfx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumaoni",
        "iso3": "kfy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koromfé",
        "iso3": "kfz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koyaga",
        "iso3": "kga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kawe",
        "iso3": "kgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Komering",
        "iso3": "kge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kube",
        "iso3": "kgf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kusunda",
        "iso3": "kgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Selangor Sign Language",
        "iso3": "kgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gamale Kham",
        "iso3": "kgj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaiwá",
        "iso3": "kgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunggari",
        "iso3": "kgl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Karingani",
        "iso3": "kgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krongo",
        "iso3": "kgo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaingang",
        "iso3": "kgp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamoro",
        "iso3": "kgq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abun",
        "iso3": "kgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumbainggar",
        "iso3": "kgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Somyev",
        "iso3": "kgt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kobol",
        "iso3": "kgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karas",
        "iso3": "kgv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karon Dori",
        "iso3": "kgw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamaru",
        "iso3": "kgx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kyerung",
        "iso3": "kgy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khasi",
        "iso3": "kha",
        "iso2b": "kha",
        "iso2t": "kha",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lü",
        "iso3": "khb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tukang Besi North",
        "iso3": "khc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bädi Kanum",
        "iso3": "khd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korowai",
        "iso3": "khe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khuen",
        "iso3": "khf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khams Tibetan",
        "iso3": "khg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kehu",
        "iso3": "khh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuturmi",
        "iso3": "khj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Halh Mongolian",
        "iso3": "khk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lusi",
        "iso3": "khl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khmer",
        "iso3": "khm",
        "iso2b": "khm",
        "iso2t": "khm",
        "iso1": "km",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khandesi",
        "iso3": "khn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khotanese",
        "iso3": "kho",
        "iso2b": "kho",
        "iso2t": "kho",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kapori",
        "iso3": "khp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koyra Chiini Songhay",
        "iso3": "khq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kharia",
        "iso3": "khr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kasua",
        "iso3": "khs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khamti",
        "iso3": "kht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkhumbi",
        "iso3": "khu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khvarshi",
        "iso3": "khv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khowar",
        "iso3": "khw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanu",
        "iso3": "khx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kele (Democratic Republic of Congo)",
        "iso3": "khy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keapara",
        "iso3": "khz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kim",
        "iso3": "kia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koalib",
        "iso3": "kib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kickapoo",
        "iso3": "kic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koshin",
        "iso3": "kid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kibet",
        "iso3": "kie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Parbate Kham",
        "iso3": "kif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kimaama",
        "iso3": "kig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kilmeri",
        "iso3": "kih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kitsai",
        "iso3": "kii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kilivila",
        "iso3": "kij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kikuyu",
        "iso3": "kik",
        "iso2b": "kik",
        "iso2t": "kik",
        "iso1": "ki",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kariya",
        "iso3": "kil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karagas",
        "iso3": "kim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kinyarwanda",
        "iso3": "kin",
        "iso2b": "kin",
        "iso2t": "kin",
        "iso1": "rw",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kiowa",
        "iso3": "kio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sheshi Kham",
        "iso3": "kip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kosadle",
        "iso3": "kiq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kirghiz",
        "iso3": "kir",
        "iso2b": "kir",
        "iso2t": "kir",
        "iso1": "ky",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kis",
        "iso3": "kis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agob",
        "iso3": "kit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kirmanjki (individual language)",
        "iso3": "kiu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kimbu",
        "iso3": "kiv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northeast Kiwai",
        "iso3": "kiw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khiamniungan Naga",
        "iso3": "kix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kirikiri",
        "iso3": "kiy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kisi",
        "iso3": "kiz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mlap",
        "iso3": "kja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Q'anjob'al",
        "iso3": "kjb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coastal Konjo",
        "iso3": "kjc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Kiwai",
        "iso3": "kjd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kisar",
        "iso3": "kje",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khmu",
        "iso3": "kjg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khakas",
        "iso3": "kjh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zabana",
        "iso3": "kji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khinalugh",
        "iso3": "kjj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Highland Konjo",
        "iso3": "kjk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Parbate Kham",
        "iso3": "kjl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kháng",
        "iso3": "kjm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunjen",
        "iso3": "kjn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Harijan Kinnauri",
        "iso3": "kjo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pwo Eastern Karen",
        "iso3": "kjp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Keres",
        "iso3": "kjq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurudu",
        "iso3": "kjr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Kewa",
        "iso3": "kjs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phrae Pwo Karen",
        "iso3": "kjt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kashaya",
        "iso3": "kju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaikavian Literary Language",
        "iso3": "kjv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ramopa",
        "iso3": "kjx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Erave",
        "iso3": "kjy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bumthangkha",
        "iso3": "kjz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kakanda",
        "iso3": "kka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwerisa",
        "iso3": "kkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Odoodee",
        "iso3": "kkc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kinuku",
        "iso3": "kkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kakabe",
        "iso3": "kke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalaktang Monpa",
        "iso3": "kkf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mabaka Valley Kalinga",
        "iso3": "kkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khün",
        "iso3": "kkh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kagulu",
        "iso3": "kki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kako",
        "iso3": "kkj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kokota",
        "iso3": "kkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kosarek Yale",
        "iso3": "kkl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kiong",
        "iso3": "kkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kon Keu",
        "iso3": "kkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karko",
        "iso3": "kko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gugubera",
        "iso3": "kkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaeku",
        "iso3": "kkq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kir-Balar",
        "iso3": "kkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Giiwo",
        "iso3": "kks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koi",
        "iso3": "kkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumi",
        "iso3": "kku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kangean",
        "iso3": "kkv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teke-Kukuya",
        "iso3": "kkw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kohin",
        "iso3": "kkx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guugu Yimidhirr",
        "iso3": "kky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaska",
        "iso3": "kkz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Klamath-Modoc",
        "iso3": "kla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kiliwa",
        "iso3": "klb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kolbila",
        "iso3": "klc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gamilaraay",
        "iso3": "kld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kulung (Nepal)",
        "iso3": "kle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kendeje",
        "iso3": "klf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagakaulo",
        "iso3": "klg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Weliki",
        "iso3": "klh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalumpang",
        "iso3": "kli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khalaj",
        "iso3": "klj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kono (Nigeria)",
        "iso3": "klk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kagan Kalagan",
        "iso3": "kll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Migum",
        "iso3": "klm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalenjin",
        "iso3": "kln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Kapya",
        "iso3": "klo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamasa",
        "iso3": "klp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rumu",
        "iso3": "klq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khaling",
        "iso3": "klr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalasha",
        "iso3": "kls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nukna",
        "iso3": "klt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Klao",
        "iso3": "klu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maskelynes",
        "iso3": "klv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tado",
        "iso3": "klw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koluwawa",
        "iso3": "klx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalao",
        "iso3": "kly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabola",
        "iso3": "klz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konni",
        "iso3": "kma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kimbundu",
        "iso3": "kmb",
        "iso2b": "kmb",
        "iso2t": "kmb",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Dong",
        "iso3": "kmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Majukayang Kalinga",
        "iso3": "kmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bakole",
        "iso3": "kme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kare (Papua New Guinea)",
        "iso3": "kmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kâte",
        "iso3": "kmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalam",
        "iso3": "kmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kami (Nigeria)",
        "iso3": "kmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumarbhag Paharia",
        "iso3": "kmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Limos Kalinga",
        "iso3": "kmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanudan Kalinga",
        "iso3": "kml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kom (India)",
        "iso3": "kmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awtuw",
        "iso3": "kmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwoma",
        "iso3": "kmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gimme",
        "iso3": "kmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwama",
        "iso3": "kmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Kurdish",
        "iso3": "kmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamasau",
        "iso3": "kms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kemtuik",
        "iso3": "kmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanite",
        "iso3": "kmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karipúna Creole French",
        "iso3": "kmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Komo (Democratic Republic of Congo)",
        "iso3": "kmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waboda",
        "iso3": "kmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koma",
        "iso3": "kmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khorasani Turkish",
        "iso3": "kmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dera (Nigeria)",
        "iso3": "kna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lubuagan Kalinga",
        "iso3": "knb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Kanuri",
        "iso3": "knc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konda",
        "iso3": "knd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kankanaey",
        "iso3": "kne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mankanya",
        "iso3": "knf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koongo",
        "iso3": "kng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanufi",
        "iso3": "kni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Kanjobal",
        "iso3": "knj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuranko",
        "iso3": "knk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keninjal",
        "iso3": "knl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanamarí",
        "iso3": "knm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konkani (individual language)",
        "iso3": "knn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kono (Sierra Leone)",
        "iso3": "kno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwanja",
        "iso3": "knp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kintaq",
        "iso3": "knq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaningra",
        "iso3": "knr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kensiu",
        "iso3": "kns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panoan Katukína",
        "iso3": "knt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kono (Guinea)",
        "iso3": "knu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabo",
        "iso3": "knv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kung-Ekoka",
        "iso3": "knw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kendayan",
        "iso3": "knx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanyok",
        "iso3": "kny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalamsé",
        "iso3": "knz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konomala",
        "iso3": "koa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpati",
        "iso3": "koc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kodi",
        "iso3": "kod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kacipo-Bale Suri",
        "iso3": "koe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kubi",
        "iso3": "kof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cogui",
        "iso3": "kog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koyo",
        "iso3": "koh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Komi-Permyak",
        "iso3": "koi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konkani (macrolanguage)",
        "iso3": "kok",
        "iso2b": "kok",
        "iso2t": "kok",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Kol (Papua New Guinea)",
        "iso3": "kol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Komi",
        "iso3": "kom",
        "iso2b": "kom",
        "iso2t": "kom",
        "iso1": "kv",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Kongo",
        "iso3": "kon",
        "iso2b": "kon",
        "iso2t": "kon",
        "iso1": "kg",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Konzo",
        "iso3": "koo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waube",
        "iso3": "kop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kota (Gabon)",
        "iso3": "koq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korean",
        "iso3": "kor",
        "iso2b": "kor",
        "iso2t": "kor",
        "iso1": "ko",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kosraean",
        "iso3": "kos",
        "iso2b": "kos",
        "iso2t": "kos",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lagwan",
        "iso3": "kot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koke",
        "iso3": "kou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kudu-Camo",
        "iso3": "kov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kugama",
        "iso3": "kow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koyukon",
        "iso3": "koy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korak",
        "iso3": "koz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kutto",
        "iso3": "kpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mullu Kurumba",
        "iso3": "kpb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Curripaco",
        "iso3": "kpc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koba",
        "iso3": "kpd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpelle",
        "iso3": "kpe",
        "iso2b": "kpe",
        "iso2t": "kpe",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Komba",
        "iso3": "kpf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kapingamarangi",
        "iso3": "kpg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kplang",
        "iso3": "kph",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kofei",
        "iso3": "kpi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karajá",
        "iso3": "kpj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpan",
        "iso3": "kpk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpala",
        "iso3": "kpl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koho",
        "iso3": "kpm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kepkiriwát",
        "iso3": "kpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ikposo",
        "iso3": "kpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korupun-Sela",
        "iso3": "kpq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korafe-Yegha",
        "iso3": "kpr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tehit",
        "iso3": "kps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karata",
        "iso3": "kpt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kafoa",
        "iso3": "kpu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Komi-Zyrian",
        "iso3": "kpv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kobon",
        "iso3": "kpw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mountain Koiali",
        "iso3": "kpx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koryak",
        "iso3": "kpy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kupsabiny",
        "iso3": "kpz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mum",
        "iso3": "kqa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kovai",
        "iso3": "kqb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doromu-Koki",
        "iso3": "kqc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koy Sanjaq Surat",
        "iso3": "kqd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalagan",
        "iso3": "kqe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kakabai",
        "iso3": "kqf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khe",
        "iso3": "kqg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kisankasa",
        "iso3": "kqh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koitabu",
        "iso3": "kqi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koromira",
        "iso3": "kqj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kotafon Gbe",
        "iso3": "kqk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kyenele",
        "iso3": "kql",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khisa",
        "iso3": "kqm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaonde",
        "iso3": "kqn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Krahn",
        "iso3": "kqo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kimré",
        "iso3": "kqp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krenak",
        "iso3": "kqq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kimaragang",
        "iso3": "kqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Kissi",
        "iso3": "kqs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Klias River Kadazan",
        "iso3": "kqt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seroa",
        "iso3": "kqu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Okolod",
        "iso3": "kqv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kandas",
        "iso3": "kqw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mser",
        "iso3": "kqx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koorete",
        "iso3": "kqy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korana",
        "iso3": "kqz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kumhali",
        "iso3": "kra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karkin",
        "iso3": "krb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Karachay-Balkar",
        "iso3": "krc",
        "iso2b": "krc",
        "iso2t": "krc",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kairui-Midiki",
        "iso3": "krd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panará",
        "iso3": "kre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koro (Vanuatu)",
        "iso3": "krf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurama",
        "iso3": "krh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krio",
        "iso3": "kri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kinaray-A",
        "iso3": "krj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kerek",
        "iso3": "krk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Karelian",
        "iso3": "krl",
        "iso2b": "krl",
        "iso2t": "krl",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sapo",
        "iso3": "krn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Durop",
        "iso3": "krp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krung",
        "iso3": "krr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gbaya (Sudan)",
        "iso3": "krs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumari Kanuri",
        "iso3": "krt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurukh",
        "iso3": "kru",
        "iso2b": "kru",
        "iso2t": "kru",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kavet",
        "iso3": "krv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Krahn",
        "iso3": "krw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karon",
        "iso3": "krx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kryts",
        "iso3": "kry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sota Kanum",
        "iso3": "krz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shambala",
        "iso3": "ksb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Kalinga",
        "iso3": "ksc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuanua",
        "iso3": "ksd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuni",
        "iso3": "kse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bafia",
        "iso3": "ksf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kusaghe",
        "iso3": "ksg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kölsch",
        "iso3": "ksh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krisa",
        "iso3": "ksi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uare",
        "iso3": "ksj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kansa",
        "iso3": "ksk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumalu",
        "iso3": "ksl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumba",
        "iso3": "ksm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kasiguranin",
        "iso3": "ksn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kofa",
        "iso3": "kso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaba",
        "iso3": "ksp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwaami",
        "iso3": "ksq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Borong",
        "iso3": "ksr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Kisi",
        "iso3": "kss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Winyé",
        "iso3": "kst",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khamyang",
        "iso3": "ksu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kusu",
        "iso3": "ksv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "S'gaw Karen",
        "iso3": "ksw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kedang",
        "iso3": "ksx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kharia Thar",
        "iso3": "ksy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kodaku",
        "iso3": "ksz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Katua",
        "iso3": "kta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kambaata",
        "iso3": "ktb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kholok",
        "iso3": "ktc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kokata",
        "iso3": "ktd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nubri",
        "iso3": "kte",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwami",
        "iso3": "ktf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalkutung",
        "iso3": "ktg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Karanga",
        "iso3": "kth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Muyu",
        "iso3": "kti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Plapo Krumen",
        "iso3": "ktj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaniet",
        "iso3": "ktk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Koroshi",
        "iso3": "ktl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurti",
        "iso3": "ktm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karitiâna",
        "iso3": "ktn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuot",
        "iso3": "kto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaduo",
        "iso3": "ktp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Katabaga",
        "iso3": "ktq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "South Muyu",
        "iso3": "kts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ketum",
        "iso3": "ktt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kituba (Democratic Republic of Congo)",
        "iso3": "ktu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Katu",
        "iso3": "ktv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kato",
        "iso3": "ktw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kaxararí",
        "iso3": "ktx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kango (Bas-Uélé District)",
        "iso3": "kty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Juǀʼhoan",
        "iso3": "ktz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuanyama",
        "iso3": "kua",
        "iso2b": "kua",
        "iso2t": "kua",
        "iso1": "kj",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kutep",
        "iso3": "kub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwinsu",
        "iso3": "kuc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "'Auhelawa",
        "iso3": "kud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuman (Papua New Guinea)",
        "iso3": "kue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Katu",
        "iso3": "kuf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kupa",
        "iso3": "kug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kushi",
        "iso3": "kuh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuikúro-Kalapálo",
        "iso3": "kui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuria",
        "iso3": "kuj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kepo'",
        "iso3": "kuk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kulere",
        "iso3": "kul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumyk",
        "iso3": "kum",
        "iso2b": "kum",
        "iso2t": "kum",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunama",
        "iso3": "kun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumukio",
        "iso3": "kuo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunimaipa",
        "iso3": "kup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karipuna",
        "iso3": "kuq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurdish",
        "iso3": "kur",
        "iso2b": "kur",
        "iso2t": "kur",
        "iso1": "ku",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Kusaal",
        "iso3": "kus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kutenai",
        "iso3": "kut",
        "iso2b": "kut",
        "iso2t": "kut",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Kuskokwim",
        "iso3": "kuu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kur",
        "iso3": "kuv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpagua",
        "iso3": "kuw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kukatja",
        "iso3": "kux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuuku-Ya'u",
        "iso3": "kuy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunza",
        "iso3": "kuz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bagvalal",
        "iso3": "kva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kubu",
        "iso3": "kvb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kove",
        "iso3": "kvc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kui (Indonesia)",
        "iso3": "kvd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalabakan",
        "iso3": "kve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabalai",
        "iso3": "kvf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuni-Boazi",
        "iso3": "kvg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Komodo",
        "iso3": "kvh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwang",
        "iso3": "kvi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Psikye",
        "iso3": "kvj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korean Sign Language",
        "iso3": "kvk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayaw",
        "iso3": "kvl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kendem",
        "iso3": "kvm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Border Kuna",
        "iso3": "kvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dobel",
        "iso3": "kvo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kompane",
        "iso3": "kvp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Geba Karen",
        "iso3": "kvq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kerinci",
        "iso3": "kvr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lahta Karen",
        "iso3": "kvt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yinbaw Karen",
        "iso3": "kvu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kola",
        "iso3": "kvv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wersing",
        "iso3": "kvw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parkari Koli",
        "iso3": "kvx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yintale Karen",
        "iso3": "kvy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsakwambo",
        "iso3": "kvz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dâw",
        "iso3": "kwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwa",
        "iso3": "kwb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Likwala",
        "iso3": "kwc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwaio",
        "iso3": "kwd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwerba",
        "iso3": "kwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwara'ae",
        "iso3": "kwf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sara Kaba Deme",
        "iso3": "kwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kowiai",
        "iso3": "kwh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awa-Cuaiquer",
        "iso3": "kwi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwanga",
        "iso3": "kwj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwakiutl",
        "iso3": "kwk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kofyar",
        "iso3": "kwl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwambi",
        "iso3": "kwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwangali",
        "iso3": "kwn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwomtari",
        "iso3": "kwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kodia",
        "iso3": "kwp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwer",
        "iso3": "kwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwese",
        "iso3": "kws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwesten",
        "iso3": "kwt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwakum",
        "iso3": "kwu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sara Kaba Náà",
        "iso3": "kwv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwinti",
        "iso3": "kww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khirwar",
        "iso3": "kwx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Salvador Kongo",
        "iso3": "kwy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwadi",
        "iso3": "kwz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kairiru",
        "iso3": "kxa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krobu",
        "iso3": "kxb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konso",
        "iso3": "kxc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brunei",
        "iso3": "kxd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manumanaw Karen",
        "iso3": "kxf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karo (Ethiopia)",
        "iso3": "kxh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keningau Murut",
        "iso3": "kxi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kulfa",
        "iso3": "kxj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zayein Karen",
        "iso3": "kxk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Khmer",
        "iso3": "kxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanowit-Tanjong Melanau",
        "iso3": "kxn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanoé",
        "iso3": "kxo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wadiyara Koli",
        "iso3": "kxp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Smärky Kanum",
        "iso3": "kxq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koro (Papua New Guinea)",
        "iso3": "kxr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kangjia",
        "iso3": "kxs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koiwat",
        "iso3": "kxt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuvi",
        "iso3": "kxv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konai",
        "iso3": "kxw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Likuba",
        "iso3": "kxx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayong",
        "iso3": "kxy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kerewo",
        "iso3": "kxz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwaya",
        "iso3": "kya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Butbut Kalinga",
        "iso3": "kyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kyaka",
        "iso3": "kyc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karey",
        "iso3": "kyd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krache",
        "iso3": "kye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kouya",
        "iso3": "kyf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keyagana",
        "iso3": "kyg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karok",
        "iso3": "kyh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kiput",
        "iso3": "kyi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karao",
        "iso3": "kyj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamayo",
        "iso3": "kyk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalapuya",
        "iso3": "kyl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpatili",
        "iso3": "kym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Binukidnon",
        "iso3": "kyn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kelon",
        "iso3": "kyo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kang",
        "iso3": "kyp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kenga",
        "iso3": "kyq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuruáya",
        "iso3": "kyr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baram Kayan",
        "iso3": "kys",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayagar",
        "iso3": "kyt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Kayah",
        "iso3": "kyu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayort",
        "iso3": "kyv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kudmali",
        "iso3": "kyw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rapoisi",
        "iso3": "kyx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kambaira",
        "iso3": "kyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayabí",
        "iso3": "kyz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Karaboro",
        "iso3": "kza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaibobo",
        "iso3": "kzb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bondoukou Kulango",
        "iso3": "kzc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kadai",
        "iso3": "kzd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kosena",
        "iso3": "kze",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Da'a Kaili",
        "iso3": "kzf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kikai",
        "iso3": "kzg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kelabit",
        "iso3": "kzi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kazukuru",
        "iso3": "kzk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kayeli",
        "iso3": "kzl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kais",
        "iso3": "kzm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kokola",
        "iso3": "kzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaningi",
        "iso3": "kzo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaidipang",
        "iso3": "kzp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaike",
        "iso3": "kzq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karang",
        "iso3": "kzr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sugut Dusun",
        "iso3": "kzs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayupulau",
        "iso3": "kzu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Komyandaret",
        "iso3": "kzv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karirí-Xocó",
        "iso3": "kzw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kamarian",
        "iso3": "kzx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kango (Tshopo District)",
        "iso3": "kzy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalabra",
        "iso3": "kzz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Subanen",
        "iso3": "laa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Linear A",
        "iso3": "lab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Lacandon",
        "iso3": "lac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ladino",
        "iso3": "lad",
        "iso2b": "lad",
        "iso2t": "lad",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pattani",
        "iso3": "lae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lafofa",
        "iso3": "laf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rangi",
        "iso3": "lag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lahnda",
        "iso3": "lah",
        "iso2b": "lah",
        "iso2t": "lah",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Lambya",
        "iso3": "lai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lango (Uganda)",
        "iso3": "laj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lalia",
        "iso3": "lal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamba",
        "iso3": "lam",
        "iso2b": "lam",
        "iso2t": "lam",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laru",
        "iso3": "lan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lao",
        "iso3": "lao",
        "iso2b": "lao",
        "iso2t": "lao",
        "iso1": "lo",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laka (Chad)",
        "iso3": "lap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Qabiao",
        "iso3": "laq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Larteh",
        "iso3": "lar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lama (Togo)",
        "iso3": "las",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Latin",
        "iso3": "lat",
        "iso2b": "lat",
        "iso2t": "lat",
        "iso1": "la",
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Laba",
        "iso3": "lau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Latvian",
        "iso3": "lav",
        "iso2b": "lav",
        "iso2t": "lav",
        "iso1": "lv",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Lauje",
        "iso3": "law",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiwa",
        "iso3": "lax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lama Bai",
        "iso3": "lay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aribwatsa",
        "iso3": "laz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Label",
        "iso3": "lbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lakkia",
        "iso3": "lbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lak",
        "iso3": "lbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tinani",
        "iso3": "lbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laopang",
        "iso3": "lbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "La'bi",
        "iso3": "lbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ladakhi",
        "iso3": "lbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Bontok",
        "iso3": "lbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Libon Bikol",
        "iso3": "lbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lodhi",
        "iso3": "lbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rmeet",
        "iso3": "lbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laven",
        "iso3": "lbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wampar",
        "iso3": "lbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lohorung",
        "iso3": "lbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Libyan Sign Language",
        "iso3": "lbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lachi",
        "iso3": "lbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Labu",
        "iso3": "lbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lavatbura-Lamusong",
        "iso3": "lbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tolaki",
        "iso3": "lbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lawangan",
        "iso3": "lbx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamalama",
        "iso3": "lby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lardil",
        "iso3": "lbz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Legenyem",
        "iso3": "lcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lola",
        "iso3": "lcd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loncong",
        "iso3": "lce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lubu",
        "iso3": "lcf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luchazi",
        "iso3": "lch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lisela",
        "iso3": "lcl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tungag",
        "iso3": "lcm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Lawa",
        "iso3": "lcp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luhu",
        "iso3": "lcq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lisabata-Nuniali",
        "iso3": "lcs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kla-Dan",
        "iso3": "lda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dũya",
        "iso3": "ldb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luri",
        "iso3": "ldd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lenyima",
        "iso3": "ldg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamja-Dengsa-Tola",
        "iso3": "ldh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laari",
        "iso3": "ldi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lemoro",
        "iso3": "ldj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Leelau",
        "iso3": "ldk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaan",
        "iso3": "ldl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Landoma",
        "iso3": "ldm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Láadan",
        "iso3": "ldn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Loo",
        "iso3": "ldo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tso",
        "iso3": "ldp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lufu",
        "iso3": "ldq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lega-Shabunda",
        "iso3": "lea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lala-Bisa",
        "iso3": "leb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Leco",
        "iso3": "lec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lendu",
        "iso3": "led",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lyélé",
        "iso3": "lee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lelemi",
        "iso3": "lef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lenje",
        "iso3": "leh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lemio",
        "iso3": "lei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lengola",
        "iso3": "lej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Leipon",
        "iso3": "lek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lele (Democratic Republic of Congo)",
        "iso3": "lel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nomaande",
        "iso3": "lem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lenca",
        "iso3": "len",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Leti (Cameroon)",
        "iso3": "leo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lepcha",
        "iso3": "lep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lembena",
        "iso3": "leq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lenkau",
        "iso3": "ler",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lese",
        "iso3": "les",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lesing-Gelimi",
        "iso3": "let",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kara (Papua New Guinea)",
        "iso3": "leu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamma",
        "iso3": "lev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ledo Kaili",
        "iso3": "lew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luang",
        "iso3": "lex",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lemolang",
        "iso3": "ley",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lezghian",
        "iso3": "lez",
        "iso2b": "lez",
        "iso2t": "lez",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lefa",
        "iso3": "lfa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lingua Franca Nova",
        "iso3": "lfn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Lungga",
        "iso3": "lga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laghu",
        "iso3": "lgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lugbara",
        "iso3": "lgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laghuu",
        "iso3": "lgh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lengilu",
        "iso3": "lgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lingarak",
        "iso3": "lgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wala",
        "iso3": "lgl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lega-Mwenga",
        "iso3": "lgm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "T'apo",
        "iso3": "lgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lango (South Sudan)",
        "iso3": "lgo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Logba",
        "iso3": "lgq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lengo",
        "iso3": "lgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guinea-Bissau Sign Language",
        "iso3": "lgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pahi",
        "iso3": "lgt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Longgu",
        "iso3": "lgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ligenza",
        "iso3": "lgz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laha (Viet Nam)",
        "iso3": "lha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laha (Indonesia)",
        "iso3": "lhh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lahu Shi",
        "iso3": "lhi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lahul Lohar",
        "iso3": "lhl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lhomi",
        "iso3": "lhm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lahanan",
        "iso3": "lhn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lhokpu",
        "iso3": "lhp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mlahsö",
        "iso3": "lhs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lo-Toga",
        "iso3": "lht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lahu",
        "iso3": "lhu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West-Central Limba",
        "iso3": "lia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Likum",
        "iso3": "lib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hlai",
        "iso3": "lic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyindrou",
        "iso3": "lid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Likila",
        "iso3": "lie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Limbu",
        "iso3": "lif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ligbi",
        "iso3": "lig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lihir",
        "iso3": "lih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ligurian",
        "iso3": "lij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lika",
        "iso3": "lik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lillooet",
        "iso3": "lil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Limburgan",
        "iso3": "lim",
        "iso2b": "lim",
        "iso2t": "lim",
        "iso1": "li",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lingala",
        "iso3": "lin",
        "iso2b": "lin",
        "iso2t": "lin",
        "iso1": "ln",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Liki",
        "iso3": "lio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sekpele",
        "iso3": "lip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Libido",
        "iso3": "liq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Liberian English",
        "iso3": "lir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lisu",
        "iso3": "lis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lithuanian",
        "iso3": "lit",
        "iso2b": "lit",
        "iso2t": "lit",
        "iso1": "lt",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Logorik",
        "iso3": "liu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Liv",
        "iso3": "liv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Col",
        "iso3": "liw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Liabuku",
        "iso3": "lix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banda-Bambari",
        "iso3": "liy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Libinza",
        "iso3": "liz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Golpa",
        "iso3": "lja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Rampi",
        "iso3": "lje",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laiyolo",
        "iso3": "lji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Li'o",
        "iso3": "ljl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lampung Api",
        "iso3": "ljp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yirandali",
        "iso3": "ljw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yuru",
        "iso3": "ljx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lakalei",
        "iso3": "lka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabras",
        "iso3": "lkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kucong",
        "iso3": "lkc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lakondê",
        "iso3": "lkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kenyi",
        "iso3": "lke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lakha",
        "iso3": "lkh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laki",
        "iso3": "lki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Remun",
        "iso3": "lkj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laeko-Libuat",
        "iso3": "lkl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalaamaya",
        "iso3": "lkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lakon",
        "iso3": "lkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khayo",
        "iso3": "lko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Päri",
        "iso3": "lkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kisa",
        "iso3": "lks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lakota",
        "iso3": "lkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kungkari",
        "iso3": "lku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lokoya",
        "iso3": "lky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lala-Roba",
        "iso3": "lla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lolo",
        "iso3": "llb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lele (Guinea)",
        "iso3": "llc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ladin",
        "iso3": "lld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lele (Papua New Guinea)",
        "iso3": "lle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hermit",
        "iso3": "llf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lole",
        "iso3": "llg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamu",
        "iso3": "llh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teke-Laali",
        "iso3": "lli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ladji Ladji",
        "iso3": "llj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lelak",
        "iso3": "llk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lilau",
        "iso3": "lll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lasalimu",
        "iso3": "llm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lele (Chad)",
        "iso3": "lln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Efate",
        "iso3": "llp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lolak",
        "iso3": "llq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lithuanian Sign Language",
        "iso3": "lls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lau",
        "iso3": "llu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lauan",
        "iso3": "llx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Limba",
        "iso3": "lma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Merei",
        "iso3": "lmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Limilngan",
        "iso3": "lmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lumun",
        "iso3": "lmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pévé",
        "iso3": "lme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Lembata",
        "iso3": "lmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamogai",
        "iso3": "lmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lambichhong",
        "iso3": "lmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lombi",
        "iso3": "lmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Lembata",
        "iso3": "lmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamkang",
        "iso3": "lmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hano",
        "iso3": "lml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lambadi",
        "iso3": "lmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lombard",
        "iso3": "lmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Limbum",
        "iso3": "lmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamatuka",
        "iso3": "lmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamalera",
        "iso3": "lmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamenu",
        "iso3": "lmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lomaiviti",
        "iso3": "lmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lake Miwok",
        "iso3": "lmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laimbue",
        "iso3": "lmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamboya",
        "iso3": "lmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Langbashe",
        "iso3": "lna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbalanhu",
        "iso3": "lnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lundayeh",
        "iso3": "lnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Langobardic",
        "iso3": "lng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Lanoh",
        "iso3": "lnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Daantanai'",
        "iso3": "lni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Leningitij",
        "iso3": "lnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "South Central Banda",
        "iso3": "lnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Langam",
        "iso3": "lnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lorediakarkar",
        "iso3": "lnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lamnso'",
        "iso3": "lns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Longuda",
        "iso3": "lnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lanima",
        "iso3": "lnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lonzo",
        "iso3": "lnz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loloda",
        "iso3": "loa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lobi",
        "iso3": "lob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inonhan",
        "iso3": "loc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saluan",
        "iso3": "loe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Logol",
        "iso3": "lof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Logo",
        "iso3": "log",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laarim",
        "iso3": "loh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loma (Côte d'Ivoire)",
        "iso3": "loi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lou",
        "iso3": "loj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loko",
        "iso3": "lok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mongo",
        "iso3": "lol",
        "iso2b": "lol",
        "iso2t": "lol",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loma (Liberia)",
        "iso3": "lom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malawi Lomwe",
        "iso3": "lon",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lombo",
        "iso3": "loo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lopa",
        "iso3": "lop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lobala",
        "iso3": "loq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Téén",
        "iso3": "lor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loniu",
        "iso3": "los",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Otuho",
        "iso3": "lot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Louisiana Creole",
        "iso3": "lou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lopi",
        "iso3": "lov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tampias Lobu",
        "iso3": "low",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loun",
        "iso3": "lox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loke",
        "iso3": "loy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lozi",
        "iso3": "loz",
        "iso2b": "loz",
        "iso2t": "loz",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lelepa",
        "iso3": "lpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lepki",
        "iso3": "lpe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Long Phuri Naga",
        "iso3": "lpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lipo",
        "iso3": "lpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lopit",
        "iso3": "lpx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Logir",
        "iso3": "lqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rara Bakati'",
        "iso3": "lra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Luri",
        "iso3": "lrc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laurentian",
        "iso3": "lre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Laragia",
        "iso3": "lrg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Marachi",
        "iso3": "lri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loarki",
        "iso3": "lrk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lari",
        "iso3": "lrl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marama",
        "iso3": "lrm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lorang",
        "iso3": "lrn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laro",
        "iso3": "lro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Yamphu",
        "iso3": "lrr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Larantuka Malay",
        "iso3": "lrt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Larevat",
        "iso3": "lrv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lemerig",
        "iso3": "lrz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lasgerdi",
        "iso3": "lsa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burundian Sign Language",
        "iso3": "lsb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Albarradas Sign Language",
        "iso3": "lsc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lishana Deni",
        "iso3": "lsd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lusengo",
        "iso3": "lse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lish",
        "iso3": "lsh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lashi",
        "iso3": "lsi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Latvian Sign Language",
        "iso3": "lsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saamia",
        "iso3": "lsm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tibetan Sign Language",
        "iso3": "lsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laos Sign Language",
        "iso3": "lso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panamanian Sign Language",
        "iso3": "lsp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aruop",
        "iso3": "lsr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lasi",
        "iso3": "lss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Trinidad and Tobago Sign Language",
        "iso3": "lst",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sivia Sign Language",
        "iso3": "lsv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seychelles Sign Language",
        "iso3": "lsw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mauritian Sign Language",
        "iso3": "lsy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Late Middle Chinese",
        "iso3": "ltc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Latgalian",
        "iso3": "ltg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thur",
        "iso3": "lth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Leti (Indonesia)",
        "iso3": "lti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Latundê",
        "iso3": "ltn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsotso",
        "iso3": "lto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tachoni",
        "iso3": "lts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Latu",
        "iso3": "ltu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luxembourgish",
        "iso3": "ltz",
        "iso2b": "ltz",
        "iso2t": "ltz",
        "iso1": "lb",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luba-Lulua",
        "iso3": "lua",
        "iso2b": "lua",
        "iso2t": "lua",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luba-Katanga",
        "iso3": "lub",
        "iso2b": "lub",
        "iso2t": "lub",
        "iso1": "lu",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aringa",
        "iso3": "luc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ludian",
        "iso3": "lud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luvale",
        "iso3": "lue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laua",
        "iso3": "luf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ganda",
        "iso3": "lug",
        "iso2b": "lug",
        "iso2t": "lug",
        "iso1": "lg",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Leizhou Chinese",
        "iso3": "luh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luiseno",
        "iso3": "lui",
        "iso2b": "lui",
        "iso2t": "lui",
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Luna",
        "iso3": "luj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lunanakha",
        "iso3": "luk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Olu'bo",
        "iso3": "lul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luimbi",
        "iso3": "lum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lunda",
        "iso3": "lun",
        "iso2b": "lun",
        "iso2t": "lun",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luo (Kenya and Tanzania)",
        "iso3": "luo",
        "iso2b": "luo",
        "iso2t": "luo",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lumbu",
        "iso3": "lup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lucumi",
        "iso3": "luq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laura",
        "iso3": "lur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lushai",
        "iso3": "lus",
        "iso2b": "lus",
        "iso2t": "lus",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lushootseed",
        "iso3": "lut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lumba-Yakkha",
        "iso3": "luu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luwati",
        "iso3": "luv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luo (Cameroon)",
        "iso3": "luw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luyia",
        "iso3": "luy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Southern Luri",
        "iso3": "luz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maku'a",
        "iso3": "lva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lavi",
        "iso3": "lvi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lavukaleve",
        "iso3": "lvk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lwel",
        "iso3": "lvl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Standard Latvian",
        "iso3": "lvs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Levuka",
        "iso3": "lvu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lwalu",
        "iso3": "lwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lewo Eleng",
        "iso3": "lwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wanga",
        "iso3": "lwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "White Lachi",
        "iso3": "lwh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Lawa",
        "iso3": "lwl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laomian",
        "iso3": "lwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luwo",
        "iso3": "lwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malawian Sign Language",
        "iso3": "lws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lewotobi",
        "iso3": "lwt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lawu",
        "iso3": "lwu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lewo",
        "iso3": "lww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lakurumau",
        "iso3": "lxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Layakha",
        "iso3": "lya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lyngngam",
        "iso3": "lyg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luyana",
        "iso3": "lyn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Literary Chinese",
        "iso3": "lzh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Litzlitz",
        "iso3": "lzl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Leinong Naga",
        "iso3": "lzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Laz",
        "iso3": "lzz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Jerónimo Tecóatl Mazatec",
        "iso3": "maa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yutanduchi Mixtec",
        "iso3": "mab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Madurese",
        "iso3": "mad",
        "iso2b": "mad",
        "iso2t": "mad",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bo-Rukul",
        "iso3": "mae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mafa",
        "iso3": "maf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Magahi",
        "iso3": "mag",
        "iso2b": "mag",
        "iso2t": "mag",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marshallese",
        "iso3": "mah",
        "iso2b": "mah",
        "iso2t": "mah",
        "iso1": "mh",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maithili",
        "iso3": "mai",
        "iso2b": "mai",
        "iso2t": "mai",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jalapa De Díaz Mazatec",
        "iso3": "maj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makasar",
        "iso3": "mak",
        "iso2b": "mak",
        "iso2t": "mak",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malayalam",
        "iso3": "mal",
        "iso2b": "mal",
        "iso2t": "mal",
        "iso1": "ml",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mam",
        "iso3": "mam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandingo",
        "iso3": "man",
        "iso2b": "man",
        "iso2t": "man",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Chiquihuitlán Mazatec",
        "iso3": "maq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marathi",
        "iso3": "mar",
        "iso2b": "mar",
        "iso2t": "mar",
        "iso1": "mr",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masai",
        "iso3": "mas",
        "iso2b": "mas",
        "iso2t": "mas",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Francisco Matlatzinca",
        "iso3": "mat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huautla Mazatec",
        "iso3": "mau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sateré-Mawé",
        "iso3": "mav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mampruli",
        "iso3": "maw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Moluccan Malay",
        "iso3": "max",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Mazahua",
        "iso3": "maz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Higaonon",
        "iso3": "mba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Bukidnon Manobo",
        "iso3": "mbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Macushi",
        "iso3": "mbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dibabawon Manobo",
        "iso3": "mbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Molale",
        "iso3": "mbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Baba Malay",
        "iso3": "mbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangseng",
        "iso3": "mbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ilianen Manobo",
        "iso3": "mbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nadëb",
        "iso3": "mbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malol",
        "iso3": "mbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maxakalí",
        "iso3": "mbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ombamba",
        "iso3": "mbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Macaguán",
        "iso3": "mbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbo (Cameroon)",
        "iso3": "mbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malayo",
        "iso3": "mbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maisin",
        "iso3": "mbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nukak Makú",
        "iso3": "mbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sarangani Manobo",
        "iso3": "mbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matigsalug Manobo",
        "iso3": "mbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbula-Bwazza",
        "iso3": "mbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbulungish",
        "iso3": "mbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maring",
        "iso3": "mbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mari (East Sepik Province)",
        "iso3": "mbx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Memoni",
        "iso3": "mby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amoltepec Mixtec",
        "iso3": "mbz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maca",
        "iso3": "mca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Machiguenga",
        "iso3": "mcb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bitur",
        "iso3": "mcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sharanahua",
        "iso3": "mcd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Itundujia Mixtec",
        "iso3": "mce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matsés",
        "iso3": "mcf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mapoyo",
        "iso3": "mcg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maquiritari",
        "iso3": "mch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mese",
        "iso3": "mci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mvanip",
        "iso3": "mcj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbunda",
        "iso3": "mck",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Macaguaje",
        "iso3": "mcl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Malaccan Creole Portuguese",
        "iso3": "mcm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masana",
        "iso3": "mcn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coatlán Mixe",
        "iso3": "mco",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makaa",
        "iso3": "mcp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ese",
        "iso3": "mcq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Menya",
        "iso3": "mcr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mambai",
        "iso3": "mcs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mengisa",
        "iso3": "mct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cameroon Mambila",
        "iso3": "mcu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minanibai",
        "iso3": "mcv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mawa (Chad)",
        "iso3": "mcw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpiemo",
        "iso3": "mcx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Watut",
        "iso3": "mcy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mawan",
        "iso3": "mcz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mada (Nigeria)",
        "iso3": "mda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Morigi",
        "iso3": "mdb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Male (Papua New Guinea)",
        "iso3": "mdc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbum",
        "iso3": "mdd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maba (Chad)",
        "iso3": "mde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moksha",
        "iso3": "mdf",
        "iso2b": "mdf",
        "iso2t": "mdf",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Massalat",
        "iso3": "mdg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maguindanaon",
        "iso3": "mdh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamvu",
        "iso3": "mdi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangbetu",
        "iso3": "mdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangbutu",
        "iso3": "mdk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maltese Sign Language",
        "iso3": "mdl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mayogo",
        "iso3": "mdm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbati",
        "iso3": "mdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbala",
        "iso3": "mdp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbole",
        "iso3": "mdq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandar",
        "iso3": "mdr",
        "iso2b": "mdr",
        "iso2t": "mdr",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maria (Papua New Guinea)",
        "iso3": "mds",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbere",
        "iso3": "mdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mboko",
        "iso3": "mdu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santa Lucía Monteverde Mixtec",
        "iso3": "mdv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbosi",
        "iso3": "mdw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dizin",
        "iso3": "mdx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Male (Ethiopia)",
        "iso3": "mdy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suruí Do Pará",
        "iso3": "mdz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Menka",
        "iso3": "mea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikobi",
        "iso3": "meb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marra",
        "iso3": "mec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Melpa",
        "iso3": "med",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mengen",
        "iso3": "mee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Megam",
        "iso3": "mef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Tlaxiaco Mixtec",
        "iso3": "meh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Midob",
        "iso3": "mei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Meyah",
        "iso3": "mej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mekeo",
        "iso3": "mek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Melanau",
        "iso3": "mel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangala",
        "iso3": "mem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mende (Sierra Leone)",
        "iso3": "men",
        "iso2b": "men",
        "iso2t": "men",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kedah Malay",
        "iso3": "meo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miriwoong",
        "iso3": "mep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Merey",
        "iso3": "meq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Meru",
        "iso3": "mer",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masmaje",
        "iso3": "mes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mato",
        "iso3": "met",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Motu",
        "iso3": "meu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mano",
        "iso3": "mev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maaka",
        "iso3": "mew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hassaniyya",
        "iso3": "mey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Menominee",
        "iso3": "mez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pattani Malay",
        "iso3": "mfa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bangka",
        "iso3": "mfb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mba",
        "iso3": "mfc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mendankwe-Nkwen",
        "iso3": "mfd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Morisyen",
        "iso3": "mfe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naki",
        "iso3": "mff",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mogofin",
        "iso3": "mfg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matal",
        "iso3": "mfh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wandala",
        "iso3": "mfi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mefele",
        "iso3": "mfj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Mofu",
        "iso3": "mfk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Putai",
        "iso3": "mfl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marghi South",
        "iso3": "mfm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cross River Mbembe",
        "iso3": "mfn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbe",
        "iso3": "mfo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makassar Malay",
        "iso3": "mfp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moba",
        "iso3": "mfq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marrithiyel",
        "iso3": "mfr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mexican Sign Language",
        "iso3": "mfs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mokerang",
        "iso3": "mft",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbwela",
        "iso3": "mfu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandjak",
        "iso3": "mfv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mulaha",
        "iso3": "mfw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Melo",
        "iso3": "mfx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mayo",
        "iso3": "mfy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mabaan",
        "iso3": "mfz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Irish (900-1200)",
        "iso3": "mga",
        "iso2b": "mga",
        "iso2t": "mga",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mararit",
        "iso3": "mgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Morokodo",
        "iso3": "mgc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moru",
        "iso3": "mgd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mango",
        "iso3": "mge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maklew",
        "iso3": "mgf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpumpong",
        "iso3": "mgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makhuwa-Meetto",
        "iso3": "mgh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lijili",
        "iso3": "mgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abureni",
        "iso3": "mgj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mawes",
        "iso3": "mgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maleu-Kilenge",
        "iso3": "mgl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mambae",
        "iso3": "mgm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbangi",
        "iso3": "mgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Meta'",
        "iso3": "mgo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Magar",
        "iso3": "mgp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malila",
        "iso3": "mgq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mambwe-Lungu",
        "iso3": "mgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manda (Tanzania)",
        "iso3": "mgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mongol",
        "iso3": "mgt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mailu",
        "iso3": "mgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matengo",
        "iso3": "mgv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matumbi",
        "iso3": "mgw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbunga",
        "iso3": "mgy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbugwe",
        "iso3": "mgz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manda (India)",
        "iso3": "mha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mahongwe",
        "iso3": "mhb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mocho",
        "iso3": "mhc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbugu",
        "iso3": "mhd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Besisi",
        "iso3": "mhe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamaa",
        "iso3": "mhf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Margu",
        "iso3": "mhg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ma'di",
        "iso3": "mhi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mogholi",
        "iso3": "mhj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mungaka",
        "iso3": "mhk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mauwake",
        "iso3": "mhl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makhuwa-Moniga",
        "iso3": "mhm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mócheno",
        "iso3": "mhn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mashi (Zambia)",
        "iso3": "mho",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balinese Malay",
        "iso3": "mhp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandan",
        "iso3": "mhq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Mari",
        "iso3": "mhr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buru (Indonesia)",
        "iso3": "mhs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandahuaca",
        "iso3": "mht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Digaro-Mishmi",
        "iso3": "mhu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbukushu",
        "iso3": "mhw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maru",
        "iso3": "mhx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ma'anyan",
        "iso3": "mhy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mor (Mor Islands)",
        "iso3": "mhz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miami",
        "iso3": "mia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atatláhuca Mixtec",
        "iso3": "mib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mi'kmaq",
        "iso3": "mic",
        "iso2b": "mic",
        "iso2t": "mic",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandaic",
        "iso3": "mid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ocotepec Mixtec",
        "iso3": "mie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mofu-Gudur",
        "iso3": "mif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Miguel El Grande Mixtec",
        "iso3": "mig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chayuco Mixtec",
        "iso3": "mih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chigmecatitlán Mixtec",
        "iso3": "mii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Abar",
        "iso3": "mij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mikasuki",
        "iso3": "mik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Peñoles Mixtec",
        "iso3": "mil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alacatlatzala Mixtec",
        "iso3": "mim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minangkabau",
        "iso3": "min",
        "iso2b": "min",
        "iso2t": "min",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pinotepa Nacional Mixtec",
        "iso3": "mio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apasco-Apoala Mixtec",
        "iso3": "mip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mískito",
        "iso3": "miq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isthmus Mixe",
        "iso3": "mir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uncoded languages",
        "iso3": "mis",
        "iso2b": "mis",
        "iso2t": "mis",
        "iso1": None,
        "scope": "Special",
        "type": "Special",
    },
    {
        "name": "Southern Puebla Mixtec",
        "iso3": "mit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cacaloxtepec Mixtec",
        "iso3": "miu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akoye",
        "iso3": "miw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mixtepec Mixtec",
        "iso3": "mix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayutla Mixtec",
        "iso3": "miy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coatzospan Mixtec",
        "iso3": "miz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makalero",
        "iso3": "mjb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Juan Colorado Mixtec",
        "iso3": "mjc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwest Maidu",
        "iso3": "mjd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muskum",
        "iso3": "mje",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tu",
        "iso3": "mjg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mwera (Nyasa)",
        "iso3": "mjh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kim Mun",
        "iso3": "mji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mawak",
        "iso3": "mjj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matukar",
        "iso3": "mjk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandeali",
        "iso3": "mjl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Medebur",
        "iso3": "mjm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ma (Papua New Guinea)",
        "iso3": "mjn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malankuravan",
        "iso3": "mjo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malapandaram",
        "iso3": "mjp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malaryan",
        "iso3": "mjq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Malavedan",
        "iso3": "mjr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miship",
        "iso3": "mjs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sauria Paharia",
        "iso3": "mjt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manna-Dora",
        "iso3": "mju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mannan",
        "iso3": "mjv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karbi",
        "iso3": "mjw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mahali",
        "iso3": "mjx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mahican",
        "iso3": "mjy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Majhi",
        "iso3": "mjz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbre",
        "iso3": "mka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mal Paharia",
        "iso3": "mkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siliput",
        "iso3": "mkc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Macedonian",
        "iso3": "mkd",
        "iso2b": "mac",
        "iso2t": "mkd",
        "iso1": "mk",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mawchi",
        "iso3": "mke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miya",
        "iso3": "mkf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mak (China)",
        "iso3": "mkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhatki",
        "iso3": "mki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mokilese",
        "iso3": "mkj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Byep",
        "iso3": "mkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mokole",
        "iso3": "mkl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moklen",
        "iso3": "mkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kupang Malay",
        "iso3": "mkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mingang Doso",
        "iso3": "mko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moikodi",
        "iso3": "mkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bay Miwok",
        "iso3": "mkq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Malas",
        "iso3": "mkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Silacayoapan Mixtec",
        "iso3": "mks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vamale",
        "iso3": "mkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konyanka Maninka",
        "iso3": "mku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mafea",
        "iso3": "mkv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kituba (Congo)",
        "iso3": "mkw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kinamiging Manobo",
        "iso3": "mkx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Makian",
        "iso3": "mky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makasae",
        "iso3": "mkz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malo",
        "iso3": "mla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbule",
        "iso3": "mlb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cao Lan",
        "iso3": "mlc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manambu",
        "iso3": "mle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mal",
        "iso3": "mlf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malagasy",
        "iso3": "mlg",
        "iso2b": "mlg",
        "iso2t": "mlg",
        "iso1": "mg",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Mape",
        "iso3": "mlh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malimpung",
        "iso3": "mli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miltu",
        "iso3": "mlj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ilwana",
        "iso3": "mlk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malua Bay",
        "iso3": "mll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mulam",
        "iso3": "mlm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malango",
        "iso3": "mln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mlomp",
        "iso3": "mlo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bargam",
        "iso3": "mlp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Maninkakan",
        "iso3": "mlq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vame",
        "iso3": "mlr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masalit",
        "iso3": "mls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maltese",
        "iso3": "mlt",
        "iso2b": "mlt",
        "iso2t": "mlt",
        "iso1": "mt",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "To'abaita",
        "iso3": "mlu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Motlav",
        "iso3": "mlv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moloko",
        "iso3": "mlw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malfaxal",
        "iso3": "mlx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malaynon",
        "iso3": "mlz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mama",
        "iso3": "mma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Momina",
        "iso3": "mmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Michoacán Mazahua",
        "iso3": "mmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maonan",
        "iso3": "mmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mae",
        "iso3": "mme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mundat",
        "iso3": "mmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Ambrym",
        "iso3": "mmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mehináku",
        "iso3": "mmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hember Avu",
        "iso3": "mmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Majhwar",
        "iso3": "mmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mukha-Dora",
        "iso3": "mmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Man Met",
        "iso3": "mml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maii",
        "iso3": "mmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamanwa",
        "iso3": "mmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangga Buang",
        "iso3": "mmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siawi",
        "iso3": "mmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Musak",
        "iso3": "mmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Xiangxi Miao",
        "iso3": "mmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malalamai",
        "iso3": "mmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mmaala",
        "iso3": "mmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miriti",
        "iso3": "mmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Emae",
        "iso3": "mmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Madak",
        "iso3": "mmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Migaama",
        "iso3": "mmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mabaale",
        "iso3": "mmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbula",
        "iso3": "mna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muna",
        "iso3": "mnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manchu",
        "iso3": "mnc",
        "iso2b": "mnc",
        "iso2t": "mnc",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mondé",
        "iso3": "mnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naba",
        "iso3": "mne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mundani",
        "iso3": "mnf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Mnong",
        "iso3": "mng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mono (Democratic Republic of Congo)",
        "iso3": "mnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manipuri",
        "iso3": "mni",
        "iso2b": "mni",
        "iso2t": "mni",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Munji",
        "iso3": "mnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandinka",
        "iso3": "mnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiale",
        "iso3": "mnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mapena",
        "iso3": "mnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Mnong",
        "iso3": "mnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Min Bei Chinese",
        "iso3": "mnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minriq",
        "iso3": "mnq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mono (USA)",
        "iso3": "mnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mansi",
        "iso3": "mns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mer",
        "iso3": "mnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rennell-Bellona",
        "iso3": "mnv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mon",
        "iso3": "mnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manikion",
        "iso3": "mnx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manyawa",
        "iso3": "mny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moni",
        "iso3": "mnz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mwan",
        "iso3": "moa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mocoví",
        "iso3": "moc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mobilian",
        "iso3": "mod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Innu",
        "iso3": "moe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mongondow",
        "iso3": "mog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mohawk",
        "iso3": "moh",
        "iso2b": "moh",
        "iso2t": "moh",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mboi",
        "iso3": "moi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Monzombo",
        "iso3": "moj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Morori",
        "iso3": "mok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangue",
        "iso3": "mom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mongolian",
        "iso3": "mon",
        "iso2b": "mon",
        "iso2t": "mon",
        "iso1": "mn",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Monom",
        "iso3": "moo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mopán Maya",
        "iso3": "mop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mor (Bomberai Peninsula)",
        "iso3": "moq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moro",
        "iso3": "mor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mossi",
        "iso3": "mos",
        "iso2b": "mos",
        "iso2t": "mos",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barí",
        "iso3": "mot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mogum",
        "iso3": "mou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mohave",
        "iso3": "mov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moi (Congo)",
        "iso3": "mow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Molima",
        "iso3": "mox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shekkacho",
        "iso3": "moy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mukulu",
        "iso3": "moz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpoto",
        "iso3": "mpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malak Malak",
        "iso3": "mpb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangarrayi",
        "iso3": "mpc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Machinere",
        "iso3": "mpd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Majang",
        "iso3": "mpe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marba",
        "iso3": "mpg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maung",
        "iso3": "mph",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpade",
        "iso3": "mpi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Martu Wangka",
        "iso3": "mpj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbara (Chad)",
        "iso3": "mpk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Watut",
        "iso3": "mpl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yosondúa Mixtec",
        "iso3": "mpm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mindiri",
        "iso3": "mpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miu",
        "iso3": "mpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Migabac",
        "iso3": "mpp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matís",
        "iso3": "mpq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vangunu",
        "iso3": "mpr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dadibi",
        "iso3": "mps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mian",
        "iso3": "mpt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makuráp",
        "iso3": "mpu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mungkip",
        "iso3": "mpv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mapidian",
        "iso3": "mpw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Misima-Panaeati",
        "iso3": "mpx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mapia",
        "iso3": "mpy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpi",
        "iso3": "mpz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maba (Indonesia)",
        "iso3": "mqa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbuko",
        "iso3": "mqb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangole",
        "iso3": "mqc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matepi",
        "iso3": "mqe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Momuna",
        "iso3": "mqf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kota Bangun Kutai Malay",
        "iso3": "mqg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tlazoyaltepec Mixtec",
        "iso3": "mqh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mariri",
        "iso3": "mqi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamasa",
        "iso3": "mqj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rajah Kabunsuwan Manobo",
        "iso3": "mqk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbelime",
        "iso3": "mql",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Marquesan",
        "iso3": "mqm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moronene",
        "iso3": "mqn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Modole",
        "iso3": "mqo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manipa",
        "iso3": "mqp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minokok",
        "iso3": "mqq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mander",
        "iso3": "mqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Makian",
        "iso3": "mqs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mok",
        "iso3": "mqt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandari",
        "iso3": "mqu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mosimo",
        "iso3": "mqv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Murupi",
        "iso3": "mqw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamuju",
        "iso3": "mqx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manggarai",
        "iso3": "mqy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pano",
        "iso3": "mqz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mlabri",
        "iso3": "mra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marino",
        "iso3": "mrb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maricopa",
        "iso3": "mrc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Magar",
        "iso3": "mrd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Martha's Vineyard Sign Language",
        "iso3": "mre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Elseng",
        "iso3": "mrf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mising",
        "iso3": "mrg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mara Chin",
        "iso3": "mrh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maori",
        "iso3": "mri",
        "iso2b": "mao",
        "iso2t": "mri",
        "iso1": "mi",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Mari",
        "iso3": "mrj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hmwaveke",
        "iso3": "mrk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mortlockese",
        "iso3": "mrl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Merlav",
        "iso3": "mrm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cheke Holo",
        "iso3": "mrn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mru",
        "iso3": "mro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Morouas",
        "iso3": "mrp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Marquesan",
        "iso3": "mrq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maria (India)",
        "iso3": "mrr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maragus",
        "iso3": "mrs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marghi Central",
        "iso3": "mrt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mono (Cameroon)",
        "iso3": "mru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangareva",
        "iso3": "mrv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maranao",
        "iso3": "mrw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maremgi",
        "iso3": "mrx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandaya",
        "iso3": "mry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marind",
        "iso3": "mrz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malay (macrolanguage)",
        "iso3": "msa",
        "iso2b": "may",
        "iso2t": "msa",
        "iso1": "ms",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Masbatenyo",
        "iso3": "msb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sankaran Maninka",
        "iso3": "msc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yucatec Maya Sign Language",
        "iso3": "msd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Musey",
        "iso3": "mse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mekwei",
        "iso3": "msf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moraid",
        "iso3": "msg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masikoro Malagasy",
        "iso3": "msh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sabah Malay",
        "iso3": "msi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ma (Democratic Republic of Congo)",
        "iso3": "msj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mansaka",
        "iso3": "msk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Molof",
        "iso3": "msl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agusan Manobo",
        "iso3": "msm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vurës",
        "iso3": "msn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mombum",
        "iso3": "mso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maritsauá",
        "iso3": "msp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Caac",
        "iso3": "msq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mongolian Sign Language",
        "iso3": "msr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Masela",
        "iso3": "mss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Musom",
        "iso3": "msu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maslam",
        "iso3": "msv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mansoanka",
        "iso3": "msw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moresada",
        "iso3": "msx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aruamu",
        "iso3": "msy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Momare",
        "iso3": "msz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cotabato Manobo",
        "iso3": "mta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anyin Morofo",
        "iso3": "mtb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Munit",
        "iso3": "mtc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mualang",
        "iso3": "mtd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mono (Solomon Islands)",
        "iso3": "mte",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Murik (Papua New Guinea)",
        "iso3": "mtf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Una",
        "iso3": "mtg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Munggui",
        "iso3": "mth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maiwa (Papua New Guinea)",
        "iso3": "mti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moskona",
        "iso3": "mtj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbe'",
        "iso3": "mtk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Montol",
        "iso3": "mtl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mator",
        "iso3": "mtm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Matagalpa",
        "iso3": "mtn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Totontepec Mixe",
        "iso3": "mto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wichí Lhamtés Nocten",
        "iso3": "mtp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muong",
        "iso3": "mtq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mewari",
        "iso3": "mtr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yora",
        "iso3": "mts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mota",
        "iso3": "mtt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tututepec Mixtec",
        "iso3": "mtu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asaro'o",
        "iso3": "mtv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Binukidnon",
        "iso3": "mtw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tidaá Mixtec",
        "iso3": "mtx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nabi",
        "iso3": "mty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mundang",
        "iso3": "mua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mubi",
        "iso3": "mub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ajumbu",
        "iso3": "muc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mednyj Aleut",
        "iso3": "mud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Media Lengua",
        "iso3": "mue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Musgu",
        "iso3": "mug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mündü",
        "iso3": "muh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Musi",
        "iso3": "mui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mabire",
        "iso3": "muj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mugom",
        "iso3": "muk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Multiple languages",
        "iso3": "mul",
        "iso2b": "mul",
        "iso2t": "mul",
        "iso1": None,
        "scope": "Special",
        "type": "Special",
    },
    {
        "name": "Maiwala",
        "iso3": "mum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyong",
        "iso3": "muo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malvi",
        "iso3": "mup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Xiangxi Miao",
        "iso3": "muq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Murle",
        "iso3": "mur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Creek",
        "iso3": "mus",
        "iso2b": "mus",
        "iso2t": "mus",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Muria",
        "iso3": "mut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaaku",
        "iso3": "muu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muthuvan",
        "iso3": "muv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bo-Ung",
        "iso3": "mux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muyang",
        "iso3": "muy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mursi",
        "iso3": "muz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manam",
        "iso3": "mva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mattole",
        "iso3": "mvb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mamboru",
        "iso3": "mvd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marwari (Pakistan)",
        "iso3": "mve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Peripheral Mongolian",
        "iso3": "mvf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yucuañe Mixtec",
        "iso3": "mvg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mulgi",
        "iso3": "mvh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miyako",
        "iso3": "mvi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mekmek",
        "iso3": "mvk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbara (Australia)",
        "iso3": "mvl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Minaveha",
        "iso3": "mvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marovo",
        "iso3": "mvo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duri",
        "iso3": "mvp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moere",
        "iso3": "mvq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marau",
        "iso3": "mvr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Massep",
        "iso3": "mvs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpotovoro",
        "iso3": "mvt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marfa",
        "iso3": "mvu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagal Murut",
        "iso3": "mvv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Machinga",
        "iso3": "mvw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Meoswar",
        "iso3": "mvx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Indus Kohistani",
        "iso3": "mvy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mesqan",
        "iso3": "mvz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mwatebu",
        "iso3": "mwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Juwal",
        "iso3": "mwb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Are",
        "iso3": "mwc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mwera (Chimwera)",
        "iso3": "mwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Murrinh-Patha",
        "iso3": "mwf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aiklep",
        "iso3": "mwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mouk-Aria",
        "iso3": "mwh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Labo",
        "iso3": "mwi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kita Maninkakan",
        "iso3": "mwk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mirandese",
        "iso3": "mwl",
        "iso2b": "mwl",
        "iso2t": "mwl",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sar",
        "iso3": "mwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyamwanga",
        "iso3": "mwn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Maewo",
        "iso3": "mwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kala Lagaw Ya",
        "iso3": "mwp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mün Chin",
        "iso3": "mwq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marwari",
        "iso3": "mwr",
        "iso2b": "mwr",
        "iso2t": "mwr",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Mwimbi-Muthambi",
        "iso3": "mws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moken",
        "iso3": "mwt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mittu",
        "iso3": "mwu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mentawai",
        "iso3": "mwv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hmong Daw",
        "iso3": "mww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moingi",
        "iso3": "mwz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwest Oaxaca Mixtec",
        "iso3": "mxa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tezoatlán Mixtec",
        "iso3": "mxb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manyika",
        "iso3": "mxc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Modang",
        "iso3": "mxd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mele-Fila",
        "iso3": "mxe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malgbe",
        "iso3": "mxf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbangala",
        "iso3": "mxg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mvuba",
        "iso3": "mxh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mozarabic",
        "iso3": "mxi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Miju-Mishmi",
        "iso3": "mxj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Monumbo",
        "iso3": "mxk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maxi Gbe",
        "iso3": "mxl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Meramera",
        "iso3": "mxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moi (Indonesia)",
        "iso3": "mxn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbowe",
        "iso3": "mxo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tlahuitoltepec Mixe",
        "iso3": "mxp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Juquila Mixe",
        "iso3": "mxq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Murik (Malaysia)",
        "iso3": "mxr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huitepec Mixtec",
        "iso3": "mxs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jamiltepec Mixtec",
        "iso3": "mxt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mada (Cameroon)",
        "iso3": "mxu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Metlatónoc Mixtec",
        "iso3": "mxv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namo",
        "iso3": "mxw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mahou",
        "iso3": "mxx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeastern Nochixtlán Mixtec",
        "iso3": "mxy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Masela",
        "iso3": "mxz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burmese",
        "iso3": "mya",
        "iso2b": "bur",
        "iso2t": "mya",
        "iso1": "my",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbay",
        "iso3": "myb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mayeka",
        "iso3": "myc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Myene",
        "iso3": "mye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bambassi",
        "iso3": "myf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manta",
        "iso3": "myg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makah",
        "iso3": "myh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangayat",
        "iso3": "myj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamara Senoufo",
        "iso3": "myk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moma",
        "iso3": "myl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Me'en",
        "iso3": "mym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anfillo",
        "iso3": "myo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pirahã",
        "iso3": "myp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muniche",
        "iso3": "myr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mesmes",
        "iso3": "mys",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mundurukú",
        "iso3": "myu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Erzya",
        "iso3": "myv",
        "iso2b": "myv",
        "iso2t": "myv",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muyuw",
        "iso3": "myw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masaaba",
        "iso3": "myx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Macuna",
        "iso3": "myy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Classical Mandaic",
        "iso3": "myz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Santa María Zacatepec Mixtec",
        "iso3": "mza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumzabt",
        "iso3": "mzb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Madagascar Sign Language",
        "iso3": "mzc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malimba",
        "iso3": "mzd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Morawa",
        "iso3": "mze",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Monastic Sign Language",
        "iso3": "mzg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wichí Lhamtés Güisnay",
        "iso3": "mzh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ixcatlán Mazatec",
        "iso3": "mzi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manya",
        "iso3": "mzj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nigeria Mambila",
        "iso3": "mzk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mazatlán Mixe",
        "iso3": "mzl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mumuye",
        "iso3": "mzm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mazanderani",
        "iso3": "mzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matipuhy",
        "iso3": "mzo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Movima",
        "iso3": "mzp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mori Atas",
        "iso3": "mzq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marúbo",
        "iso3": "mzr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Macanese",
        "iso3": "mzs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mintil",
        "iso3": "mzt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inapang",
        "iso3": "mzu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manza",
        "iso3": "mzv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Deg",
        "iso3": "mzw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mawayana",
        "iso3": "mzx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mozambican Sign Language",
        "iso3": "mzy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maiadomu",
        "iso3": "mzz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namla",
        "iso3": "naa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Nambikuára",
        "iso3": "nab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Narak",
        "iso3": "nac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naka'ela",
        "iso3": "nae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nabak",
        "iso3": "naf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naga Pidgin",
        "iso3": "nag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nalu",
        "iso3": "naj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nakanai",
        "iso3": "nak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nalik",
        "iso3": "nal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngan'gityemerri",
        "iso3": "nam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Min Nan Chinese",
        "iso3": None,
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naaba",
        "iso3": "nao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Neapolitan",
        "iso3": "nap",
        "iso2b": "nap",
        "iso2t": "nap",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khoekhoe",
        "iso3": "naq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iguta",
        "iso3": "nar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naasioi",
        "iso3": "nas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ca̱hungwa̱rya̱",
        "iso3": "nat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nauru",
        "iso3": "nau",
        "iso2b": "nau",
        "iso2t": "nau",
        "iso1": "na",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Navajo",
        "iso3": "nav",
        "iso2b": "nav",
        "iso2t": "nav",
        "iso1": "nv",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nawuri",
        "iso3": "naw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nakwi",
        "iso3": "nax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngarrindjeri",
        "iso3": "nay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Coatepec Nahuatl",
        "iso3": "naz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyemba",
        "iso3": "nba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndoe",
        "iso3": "nbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chang Naga",
        "iso3": "nbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngbinda",
        "iso3": "nbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konyak Naga",
        "iso3": "nbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nagarchal",
        "iso3": "nbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngamo",
        "iso3": "nbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mao Naga",
        "iso3": "nbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngarinyman",
        "iso3": "nbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nake",
        "iso3": "nbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Ndebele",
        "iso3": "nbl",
        "iso2b": "nbl",
        "iso2t": "nbl",
        "iso1": "nr",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngbaka Ma'bo",
        "iso3": "nbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuri",
        "iso3": "nbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkukoli",
        "iso3": "nbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nnam",
        "iso3": "nbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nggem",
        "iso3": "nbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Numana",
        "iso3": "nbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namibian Sign Language",
        "iso3": "nbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Na",
        "iso3": "nbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rongmei Naga",
        "iso3": "nbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngamambo",
        "iso3": "nbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Ngbandi",
        "iso3": "nbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ningera",
        "iso3": "nby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iyo",
        "iso3": "nca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Nicobarese",
        "iso3": "ncb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ponam",
        "iso3": "ncc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nachering",
        "iso3": "ncd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yale",
        "iso3": "nce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Notsi",
        "iso3": "ncf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nisga'a",
        "iso3": "ncg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Huasteca Nahuatl",
        "iso3": "nch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Classical Nahuatl",
        "iso3": "nci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Northern Puebla Nahuatl",
        "iso3": "ncj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Na-kara",
        "iso3": "nck",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Michoacán Nahuatl",
        "iso3": "ncl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nambo",
        "iso3": "ncm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nauna",
        "iso3": "ncn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sibe",
        "iso3": "nco",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Katang",
        "iso3": "ncq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ncane",
        "iso3": "ncr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nicaraguan Sign Language",
        "iso3": "ncs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chothe Naga",
        "iso3": "nct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chumburung",
        "iso3": "ncu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Puebla Nahuatl",
        "iso3": "ncx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Natchez",
        "iso3": "ncz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ndasa",
        "iso3": "nda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kenswei Nsei",
        "iso3": "ndb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndau",
        "iso3": "ndc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nde-Nsele-Nta",
        "iso3": "ndd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Ndebele",
        "iso3": "nde",
        "iso2b": "nde",
        "iso2t": "nde",
        "iso1": "nd",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nadruvian",
        "iso3": "ndf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ndengereko",
        "iso3": "ndg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndali",
        "iso3": "ndh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samba Leko",
        "iso3": "ndi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndamba",
        "iso3": "ndj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndaka",
        "iso3": "ndk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndolo",
        "iso3": "ndl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndam",
        "iso3": "ndm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngundi",
        "iso3": "ndn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndonga",
        "iso3": "ndo",
        "iso2b": "ndo",
        "iso2t": "ndo",
        "iso1": "ng",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndo",
        "iso3": "ndp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndombe",
        "iso3": "ndq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndoola",
        "iso3": "ndr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Low German",
        "iso3": "nds",
        "iso2b": "nds",
        "iso2t": "nds",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndunga",
        "iso3": "ndt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dugun",
        "iso3": "ndu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndut",
        "iso3": "ndv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndobo",
        "iso3": "ndw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nduga",
        "iso3": "ndx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lutos",
        "iso3": "ndy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndogo",
        "iso3": "ndz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Ngad'a",
        "iso3": "nea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toura (Côte d'Ivoire)",
        "iso3": "neb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nedebang",
        "iso3": "nec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nde-Gbite",
        "iso3": "ned",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nêlêmwa-Nixumwak",
        "iso3": "nee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nefamese",
        "iso3": "nef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Negidal",
        "iso3": "neg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyenkha",
        "iso3": "neh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Neo-Hittite",
        "iso3": "nei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Neko",
        "iso3": "nej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Neku",
        "iso3": "nek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nemi",
        "iso3": "nem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nengone",
        "iso3": "nen",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ná-Meo",
        "iso3": "neo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nepali (macrolanguage)",
        "iso3": "nep",
        "iso2b": "nep",
        "iso2t": "nep",
        "iso1": "ne",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "North Central Mixe",
        "iso3": "neq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yahadian",
        "iso3": "ner",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bhoti Kinnauri",
        "iso3": "nes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nete",
        "iso3": "net",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Neo",
        "iso3": "neu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Nyaheun",
        "iso3": "nev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Newari",
        "iso3": "new",
        "iso2b": "new",
        "iso2t": "new",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Neme",
        "iso3": "nex",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Neyo",
        "iso3": "ney",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nez Perce",
        "iso3": "nez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dhao",
        "iso3": "nfa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ahwai",
        "iso3": "nfd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayiwo",
        "iso3": "nfl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nafaanra",
        "iso3": "nfr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mfumte",
        "iso3": "nfu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngbaka",
        "iso3": "nga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Ngbandi",
        "iso3": "ngb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngombe (Democratic Republic of Congo)",
        "iso3": "ngc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngando (Central African Republic)",
        "iso3": "ngd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngemba",
        "iso3": "nge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngbaka Manza",
        "iso3": "ngg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nǁng",
        "iso3": "ngh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngizim",
        "iso3": "ngi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngie",
        "iso3": "ngj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dalabon",
        "iso3": "ngk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lomwe",
        "iso3": "ngl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngatik Men's Creole",
        "iso3": "ngm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngwo",
        "iso3": "ngn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngulu",
        "iso3": "ngp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngurimi",
        "iso3": "ngq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Engdewu",
        "iso3": "ngr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gvoko",
        "iso3": "ngs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kriang",
        "iso3": "ngt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guerrero Nahuatl",
        "iso3": "ngu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nagumi",
        "iso3": "ngv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ngwaba",
        "iso3": "ngw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nggwahyi",
        "iso3": "ngx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tibea",
        "iso3": "ngy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngungwel",
        "iso3": "ngz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nhanda",
        "iso3": "nha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Beng",
        "iso3": "nhb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabasco Nahuatl",
        "iso3": "nhc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chiripá",
        "iso3": "nhd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Huasteca Nahuatl",
        "iso3": "nhe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nhuwala",
        "iso3": "nhf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tetelcingo Nahuatl",
        "iso3": "nhg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nahari",
        "iso3": "nhh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zacatlán-Ahuacatlán-Tepetzintla Nahuatl",
        "iso3": "nhi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isthmus-Cosoleacaque Nahuatl",
        "iso3": "nhk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Morelos Nahuatl",
        "iso3": "nhm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Nahuatl",
        "iso3": "nhn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Takuu",
        "iso3": "nho",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isthmus-Pajapan Nahuatl",
        "iso3": "nhp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huaxcaleca Nahuatl",
        "iso3": "nhq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naro",
        "iso3": "nhr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ometepec Nahuatl",
        "iso3": "nht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Noone",
        "iso3": "nhu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Temascaltepec Nahuatl",
        "iso3": "nhv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Huasteca Nahuatl",
        "iso3": "nhw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isthmus-Mecayapan Nahuatl",
        "iso3": "nhx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Oaxaca Nahuatl",
        "iso3": "nhy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santa María La Alta Nahuatl",
        "iso3": "nhz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nias",
        "iso3": "nia",
        "iso2b": "nia",
        "iso2t": "nia",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nakame",
        "iso3": "nib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngandi",
        "iso3": "nid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Niellim",
        "iso3": "nie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nek",
        "iso3": "nif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngalakgan",
        "iso3": "nig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nyiha (Tanzania)",
        "iso3": "nih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nii",
        "iso3": "nii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngaju",
        "iso3": "nij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Nicobarese",
        "iso3": "nik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nila",
        "iso3": "nil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nilamba",
        "iso3": "nim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ninzo",
        "iso3": "nin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nganasan",
        "iso3": "nio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nandi",
        "iso3": "niq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nimboran",
        "iso3": "nir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nimi",
        "iso3": "nis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeastern Kolami",
        "iso3": "nit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Niuean",
        "iso3": "niu",
        "iso2b": "niu",
        "iso2t": "niu",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gilyak",
        "iso3": "niv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nimo",
        "iso3": "niw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hema",
        "iso3": "nix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngiti",
        "iso3": "niy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ningil",
        "iso3": "niz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nzanyi",
        "iso3": "nja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nocte Naga",
        "iso3": "njb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndonde Hamba",
        "iso3": "njd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lotha Naga",
        "iso3": "njh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gudanji",
        "iso3": "nji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Njen",
        "iso3": "njj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Njalgulgule",
        "iso3": "njl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angami Naga",
        "iso3": "njm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Liangmai Naga",
        "iso3": "njn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ao Naga",
        "iso3": "njo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Njerep",
        "iso3": "njr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nisa",
        "iso3": "njs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndyuka-Trio Pidgin",
        "iso3": "njt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngadjunmaya",
        "iso3": "nju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunyi",
        "iso3": "njx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Njyem",
        "iso3": "njy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyishi",
        "iso3": "njz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkoya",
        "iso3": "nka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khoibu Naga",
        "iso3": "nkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkongho",
        "iso3": "nkc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koireng",
        "iso3": "nkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duke",
        "iso3": "nke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inpui Naga",
        "iso3": "nkf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nekgini",
        "iso3": "nkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khezha Naga",
        "iso3": "nkh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thangal Naga",
        "iso3": "nki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nakai",
        "iso3": "nkj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nokuku",
        "iso3": "nkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namat",
        "iso3": "nkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkangala",
        "iso3": "nkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkonya",
        "iso3": "nko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Niuatoputapu",
        "iso3": "nkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nkami",
        "iso3": "nkq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nukuoro",
        "iso3": "nkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Asmat",
        "iso3": "nks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyika (Tanzania)",
        "iso3": "nkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bouna Kulango",
        "iso3": "nku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyika (Malawi and Zambia)",
        "iso3": "nkv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkutu",
        "iso3": "nkw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkoroo",
        "iso3": "nkx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nkari",
        "iso3": "nkz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngombale",
        "iso3": "nla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nalca",
        "iso3": "nlc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dutch",
        "iso3": "nld",
        "iso2b": "dut",
        "iso2t": "nld",
        "iso1": "nl",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Nyala",
        "iso3": "nle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gela",
        "iso3": "nlg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Grangali",
        "iso3": "nli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyali",
        "iso3": "nlj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ninia Yali",
        "iso3": "nlk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nihali",
        "iso3": "nll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mankiyali",
        "iso3": "nlm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngul",
        "iso3": "nlo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lao Naga",
        "iso3": "nlq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nchumbulu",
        "iso3": "nlu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orizaba Nahuatl",
        "iso3": "nlv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Walangama",
        "iso3": "nlw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nahali",
        "iso3": "nlx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyamal",
        "iso3": "nly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nalögo",
        "iso3": "nlz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maram Naga",
        "iso3": "nma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Big Nambas",
        "iso3": "nmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngam",
        "iso3": "nmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndumu",
        "iso3": "nmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mzieme Naga",
        "iso3": "nme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tangkhul Naga (India)",
        "iso3": "nmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwasio",
        "iso3": "nmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Monsang Naga",
        "iso3": "nmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyam",
        "iso3": "nmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngombe (Central African Republic)",
        "iso3": "nmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namakura",
        "iso3": "nmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndemli",
        "iso3": "nml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manangba",
        "iso3": "nmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ǃXóõ",
        "iso3": "nmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moyon Naga",
        "iso3": "nmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nimanbur",
        "iso3": "nmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nambya",
        "iso3": "nmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nimbari",
        "iso3": "nmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Letemboi",
        "iso3": "nms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namonuito",
        "iso3": "nmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northeast Maidu",
        "iso3": "nmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngamini",
        "iso3": "nmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nimoa",
        "iso3": "nmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nama (Papua New Guinea)",
        "iso3": "nmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namuyi",
        "iso3": "nmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nawdm",
        "iso3": "nmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyangumarta",
        "iso3": "nna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nande",
        "iso3": "nnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nancere",
        "iso3": "nnc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Ambae",
        "iso3": "nnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngandyera",
        "iso3": "nne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngaing",
        "iso3": "nnf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maring Naga",
        "iso3": "nng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngiemboon",
        "iso3": "nnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Nuaulu",
        "iso3": "nni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyangatom",
        "iso3": "nnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nankina",
        "iso3": "nnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Rengma Naga",
        "iso3": "nnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namia",
        "iso3": "nnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngete",
        "iso3": "nnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Norwegian Nynorsk",
        "iso3": "nno",
        "iso2b": "nno",
        "iso2t": "nno",
        "iso1": "nn",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wancho Naga",
        "iso3": "nnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngindo",
        "iso3": "nnq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Narungga",
        "iso3": "nnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nanticoke",
        "iso3": "nnt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dwang",
        "iso3": "nnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nugunu (Australia)",
        "iso3": "nnv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Southern Nuni",
        "iso3": "nnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyangga",
        "iso3": "nny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nda'nda'",
        "iso3": "nnz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Woun Meu",
        "iso3": "noa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Norwegian Bokmål",
        "iso3": "nob",
        "iso2b": "nob",
        "iso2t": "nob",
        "iso1": "nb",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nuk",
        "iso3": "noc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Thai",
        "iso3": "nod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nimadi",
        "iso3": "noe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nomane",
        "iso3": "nof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nogai",
        "iso3": "nog",
        "iso2b": "nog",
        "iso2t": "nog",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nomu",
        "iso3": "noh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Noiri",
        "iso3": "noi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nonuya",
        "iso3": "noj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nooksack",
        "iso3": "nok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nomlaki",
        "iso3": "nol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Old Norse",
        "iso3": "non",
        "iso2b": "non",
        "iso2t": "non",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Numanggang",
        "iso3": "nop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngongo",
        "iso3": "noq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Norwegian",
        "iso3": "nor",
        "iso2b": "nor",
        "iso2t": "nor",
        "iso1": "no",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Eastern Nisu",
        "iso3": "nos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nomatsiguenga",
        "iso3": "not",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ewage-Notu",
        "iso3": "nou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Novial",
        "iso3": "nov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Nyambo",
        "iso3": "now",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Noy",
        "iso3": "noy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nayi",
        "iso3": "noz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nar Phu",
        "iso3": "npa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nupbikha",
        "iso3": "npb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ponyo-Gongwang Naga",
        "iso3": "npg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phom Naga",
        "iso3": "nph",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nepali (individual language)",
        "iso3": "npi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeastern Puebla Nahuatl",
        "iso3": "npl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mondropolon",
        "iso3": "npn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pochuri Naga",
        "iso3": "npo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nipsan",
        "iso3": "nps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puimei Naga",
        "iso3": "npu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Noipx",
        "iso3": "npx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Napu",
        "iso3": "npy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Nago",
        "iso3": "nqg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kura Ede Nago",
        "iso3": "nqk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngendelengo",
        "iso3": "nql",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndom",
        "iso3": "nqm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nen",
        "iso3": "nqn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "N'Ko",
        "iso3": "nqo",
        "iso2b": "nqo",
        "iso2t": "nqo",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kyan-Karyaw Naga",
        "iso3": "nqq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nteng",
        "iso3": "nqt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akyaung Ari Naga",
        "iso3": "nqy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngom",
        "iso3": "nra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nara",
        "iso3": "nrb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Noric",
        "iso3": "nrc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Southern Rengma Naga",
        "iso3": "nre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jèrriais",
        "iso3": "nrf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Narango",
        "iso3": "nrg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chokri Naga",
        "iso3": "nri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngarla",
        "iso3": "nrk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngarluma",
        "iso3": "nrl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Narom",
        "iso3": "nrm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Norn",
        "iso3": "nrn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "North Picene",
        "iso3": "nrp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Norra",
        "iso3": "nrr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Northern Kalapuya",
        "iso3": "nrt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Narua",
        "iso3": "nru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngurmbur",
        "iso3": "nrx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lala",
        "iso3": "nrz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sangtam Naga",
        "iso3": "nsa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Nossob",
        "iso3": "nsb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nshi",
        "iso3": "nsc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Nisu",
        "iso3": "nsd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nsenga",
        "iso3": "nse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwestern Nisu",
        "iso3": "nsf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngasa",
        "iso3": "nsg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngoshie",
        "iso3": "nsh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nigerian Sign Language",
        "iso3": "nsi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naskapi",
        "iso3": "nsk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Norwegian Sign Language",
        "iso3": "nsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sumi Naga",
        "iso3": "nsm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nehan",
        "iso3": "nsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pedi",
        "iso3": "nso",
        "iso2b": "nso",
        "iso2t": "nso",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nepalese Sign Language",
        "iso3": "nsp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Sierra Miwok",
        "iso3": "nsq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maritime Sign Language",
        "iso3": "nsr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nali",
        "iso3": "nss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tase Naga",
        "iso3": "nst",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sierra Negra Nahuatl",
        "iso3": "nsu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Nisu",
        "iso3": "nsv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Navut",
        "iso3": "nsw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nsongo",
        "iso3": "nsx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nasal",
        "iso3": "nsy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nisenan",
        "iso3": "nsz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Tidung",
        "iso3": "ntd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngantangarra",
        "iso3": "ntg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Natioro",
        "iso3": "nti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngaanyatjarra",
        "iso3": "ntj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ikoma-Nata-Isenye",
        "iso3": "ntk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nateni",
        "iso3": "ntm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ntomba",
        "iso3": "nto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Tepehuan",
        "iso3": "ntp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Delo",
        "iso3": "ntr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Natügu",
        "iso3": "ntu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nottoway",
        "iso3": "ntw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tangkhul Naga (Myanmar)",
        "iso3": "ntx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mantsi",
        "iso3": "nty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Natanzi",
        "iso3": "ntz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yuanga",
        "iso3": "nua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nukuini",
        "iso3": "nuc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ngala",
        "iso3": "nud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngundu",
        "iso3": "nue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nusu",
        "iso3": "nuf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nungali",
        "iso3": "nug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ndunda",
        "iso3": "nuh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngumbi",
        "iso3": "nui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyole",
        "iso3": "nuj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nuu-chah-nulth",
        "iso3": "nuk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nusa Laut",
        "iso3": "nul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Niuafo'ou",
        "iso3": "num",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anong",
        "iso3": "nun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nguôn",
        "iso3": "nuo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nupe-Nupe-Tako",
        "iso3": "nup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nukumanu",
        "iso3": "nuq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nukuria",
        "iso3": "nur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nuer",
        "iso3": "nus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nung (Viet Nam)",
        "iso3": "nut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngbundu",
        "iso3": "nuu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Nuni",
        "iso3": "nuv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nguluwan",
        "iso3": "nuw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mehek",
        "iso3": "nux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nunggubuyu",
        "iso3": "nuy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tlamacazapa Nahuatl",
        "iso3": "nuz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nasarian",
        "iso3": "nvh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Namiae",
        "iso3": "nvm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyokon",
        "iso3": "nvo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nawathinehena",
        "iso3": "nwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nyabwa",
        "iso3": "nwb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Classical Newari",
        "iso3": "nwc",
        "iso2b": "nwc",
        "iso2t": "nwc",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ngwe",
        "iso3": "nwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngayawung",
        "iso3": "nwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Southwest Tanna",
        "iso3": "nwi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyamusa-Molo",
        "iso3": "nwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nauo",
        "iso3": "nwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nawaru",
        "iso3": "nwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndwewe",
        "iso3": "nww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Newar",
        "iso3": "nwx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Nottoway-Meherrin",
        "iso3": "nwy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nauete",
        "iso3": "nxa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngando (Democratic Republic of Congo)",
        "iso3": "nxd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nage",
        "iso3": "nxe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngad'a",
        "iso3": "nxg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nindi",
        "iso3": "nxi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koki Naga",
        "iso3": "nxk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Nuaulu",
        "iso3": "nxl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Numidian",
        "iso3": "nxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ngawun",
        "iso3": "nxn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ndambomo",
        "iso3": "nxo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naxi",
        "iso3": "nxq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ninggerum",
        "iso3": "nxr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nafri",
        "iso3": "nxx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyanja",
        "iso3": "nya",
        "iso2b": "nya",
        "iso2t": "nya",
        "iso1": "ny",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyangbo",
        "iso3": "nyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyanga-li",
        "iso3": "nyc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyore",
        "iso3": "nyd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyengo",
        "iso3": "nye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Giryama",
        "iso3": "nyf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyindu",
        "iso3": "nyg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyikina",
        "iso3": "nyh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ama (Sudan)",
        "iso3": "nyi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyanga",
        "iso3": "nyj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyaneka",
        "iso3": "nyk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyeu",
        "iso3": "nyl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyamwezi",
        "iso3": "nym",
        "iso2b": "nym",
        "iso2t": "nym",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyankole",
        "iso3": "nyn",
        "iso2b": "nyn",
        "iso2t": "nyn",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyoro",
        "iso3": "nyo",
        "iso2b": "nyo",
        "iso2t": "nyo",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyang'i",
        "iso3": "nyp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nayini",
        "iso3": "nyq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyiha (Malawi)",
        "iso3": "nyr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyungar",
        "iso3": "nys",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyawaygi",
        "iso3": "nyt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nyungwe",
        "iso3": "nyu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyulnyul",
        "iso3": "nyv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nyaw",
        "iso3": "nyw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nganyaywana",
        "iso3": "nyx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nyakyusa-Ngonde",
        "iso3": "nyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tigon Mbembe",
        "iso3": "nza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Njebi",
        "iso3": "nzb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nzadi",
        "iso3": "nzd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nzima",
        "iso3": "nzi",
        "iso2b": "nzi",
        "iso2t": "nzi",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nzakara",
        "iso3": "nzk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zeme Naga",
        "iso3": "nzm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dir-Nyamzak-Mbarimi",
        "iso3": "nzr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "New Zealand Sign Language",
        "iso3": "nzs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teke-Nzikou",
        "iso3": "nzu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nzakambay",
        "iso3": "nzy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nanga Dama Dogon",
        "iso3": "nzz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orok",
        "iso3": "oaa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oroch",
        "iso3": "oac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Aramaic (up to 700 BCE)",
        "iso3": "oar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Old Avar",
        "iso3": "oav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Obispeño",
        "iso3": "obi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Southern Bontok",
        "iso3": "obk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oblo",
        "iso3": "obl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moabite",
        "iso3": "obm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Obo Manobo",
        "iso3": "obo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Burmese",
        "iso3": "obr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Old Breton",
        "iso3": "obt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Obulom",
        "iso3": "obu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ocaina",
        "iso3": "oca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Chinese",
        "iso3": "och",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Occitan (post 1500)",
        "iso3": "oci",
        "iso2b": "oci",
        "iso2t": "oci",
        "iso1": "oc",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Cham",
        "iso3": "ocm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Old Cornish",
        "iso3": "oco",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Atzingo Matlatzinca",
        "iso3": "ocu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Odut",
        "iso3": "oda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Od",
        "iso3": "odk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Dutch",
        "iso3": "odt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Odual",
        "iso3": "odu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ofo",
        "iso3": "ofo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Old Frisian",
        "iso3": "ofs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Efutop",
        "iso3": "ofu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ogbia",
        "iso3": "ogb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ogbah",
        "iso3": "ogc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Georgian",
        "iso3": "oge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ogbogolo",
        "iso3": "ogg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khana",
        "iso3": "ogo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ogbronuagum",
        "iso3": "ogu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Hittite",
        "iso3": "oht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Old Hungarian",
        "iso3": "ohu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Oirata",
        "iso3": "oia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Okolie",
        "iso3": "oie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inebu One",
        "iso3": "oin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northwestern Ojibwa",
        "iso3": "ojb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Ojibwa",
        "iso3": "ojc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Ojibwa",
        "iso3": "ojg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ojibwa",
        "iso3": "oji",
        "iso2b": "oji",
        "iso2t": "oji",
        "iso1": "oj",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Old Japanese",
        "iso3": "ojp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Severn Ojibwa",
        "iso3": "ojs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ontong Java",
        "iso3": "ojv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Ojibwa",
        "iso3": "ojw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Okanagan",
        "iso3": "oka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Okobo",
        "iso3": "okb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kobo",
        "iso3": "okc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Okodia",
        "iso3": "okd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Okpe (Southwestern Edo)",
        "iso3": "oke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koko Babangk",
        "iso3": "okg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Koresh-e Rostam",
        "iso3": "okh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Okiek",
        "iso3": "oki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oko-Juwoi",
        "iso3": "okj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kwamtim One",
        "iso3": "okk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Kentish Sign Language",
        "iso3": "okl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Middle Korean (10th-16th cent.)",
        "iso3": "okm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Oki-No-Erabu",
        "iso3": "okn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Korean (3rd-9th cent.)",
        "iso3": "oko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kirike",
        "iso3": "okr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oko-Eni-Osayen",
        "iso3": "oks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oku",
        "iso3": "oku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orokaiva",
        "iso3": "okv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Okpe (Northwestern Edo)",
        "iso3": "okx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Khmer",
        "iso3": "okz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Walungge",
        "iso3": "ola",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mochi",
        "iso3": "old",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Olekha",
        "iso3": "ole",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Olkol",
        "iso3": "olk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Oloma",
        "iso3": "olm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Livvi",
        "iso3": "olo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Olrat",
        "iso3": "olr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Lithuanian",
        "iso3": "olt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kuvale",
        "iso3": "olu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Omaha-Ponca",
        "iso3": "oma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Ambae",
        "iso3": "omb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mochica",
        "iso3": "omc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Omagua",
        "iso3": "omg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Omi",
        "iso3": "omi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Omok",
        "iso3": "omk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ombo",
        "iso3": "oml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minoan",
        "iso3": "omn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Utarmbung",
        "iso3": "omo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Manipuri",
        "iso3": "omp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Old Marathi",
        "iso3": "omr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Omotik",
        "iso3": "omt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Omurano",
        "iso3": "omu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "South Tairora",
        "iso3": "omw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Mon",
        "iso3": "omx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Old Malay",
        "iso3": "omy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ona",
        "iso3": "ona",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lingao",
        "iso3": "onb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oneida",
        "iso3": "one",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Olo",
        "iso3": "ong",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Onin",
        "iso3": "oni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Onjob",
        "iso3": "onj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabore One",
        "iso3": "onk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Onobasulu",
        "iso3": "onn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Onondaga",
        "iso3": "ono",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sartang",
        "iso3": "onp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern One",
        "iso3": "onr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ono",
        "iso3": "ons",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ontenu",
        "iso3": "ont",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Unua",
        "iso3": "onu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Nubian",
        "iso3": "onw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Onin Based Pidgin",
        "iso3": "onx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tohono O'odham",
        "iso3": "ood",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ong",
        "iso3": "oog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Önge",
        "iso3": "oon",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oorlams",
        "iso3": "oor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Ossetic",
        "iso3": "oos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Okpamheri",
        "iso3": "opa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kopkaka",
        "iso3": "opk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oksapmin",
        "iso3": "opm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Opao",
        "iso3": "opo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Opata",
        "iso3": "opt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ofayé",
        "iso3": "opy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oroha",
        "iso3": "ora",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orma",
        "iso3": "orc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orejón",
        "iso3": "ore",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oring",
        "iso3": "org",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oroqen",
        "iso3": "orh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oriya (macrolanguage)",
        "iso3": "ori",
        "iso2b": "ori",
        "iso2t": "ori",
        "iso1": "or",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Oromo",
        "iso3": "orm",
        "iso2b": "orm",
        "iso2t": "orm",
        "iso1": "om",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Orang Kanaq",
        "iso3": "orn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orokolo",
        "iso3": "oro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oruma",
        "iso3": "orr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orang Seletar",
        "iso3": "ors",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adivasi Oriya",
        "iso3": "ort",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ormuri",
        "iso3": "oru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Russian",
        "iso3": "orv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Oro Win",
        "iso3": "orw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oro",
        "iso3": "orx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Odia",
        "iso3": "ory",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ormu",
        "iso3": "orz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Osage",
        "iso3": "osa",
        "iso2b": "osa",
        "iso2t": "osa",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oscan",
        "iso3": "osc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Osing",
        "iso3": "osi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Sundanese",
        "iso3": "osn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ososo",
        "iso3": "oso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Spanish",
        "iso3": "osp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ossetian",
        "iso3": "oss",
        "iso2b": "oss",
        "iso2t": "oss",
        "iso1": "os",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Osatu",
        "iso3": "ost",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern One",
        "iso3": "osu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Saxon",
        "iso3": "osx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ottoman Turkish (1500-1928)",
        "iso3": "ota",
        "iso2b": "ota",
        "iso2t": "ota",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Old Tibetan",
        "iso3": "otb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ot Danum",
        "iso3": "otd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mezquital Otomi",
        "iso3": "ote",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oti",
        "iso3": "oti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Old Turkish",
        "iso3": "otk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Tilapa Otomi",
        "iso3": "otl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Highland Otomi",
        "iso3": "otm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tenango Otomi",
        "iso3": "otn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Querétaro Otomi",
        "iso3": "otq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Otoro",
        "iso3": "otr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Estado de México Otomi",
        "iso3": "ots",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Temoaya Otomi",
        "iso3": "ott",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Otuke",
        "iso3": "otu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ottawa",
        "iso3": "otw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Texcatepec Otomi",
        "iso3": "otx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Tamil",
        "iso3": "oty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ixtenco Otomi",
        "iso3": "otz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagargrent",
        "iso3": "oua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Glio-Oubi",
        "iso3": "oub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oune",
        "iso3": "oue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Uighur",
        "iso3": "oui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ouma",
        "iso3": "oum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Elfdalian",
        "iso3": "ovd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Owiniga",
        "iso3": "owi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Welsh",
        "iso3": "owl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Oy",
        "iso3": "oyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oyda",
        "iso3": "oyd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wayampi",
        "iso3": "oym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oya'oya",
        "iso3": "oyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koonzime",
        "iso3": "ozm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parecís",
        "iso3": "pab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pacoh",
        "iso3": "pac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paumarí",
        "iso3": "pad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pagibete",
        "iso3": "pae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paranawát",
        "iso3": "paf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pangasinan",
        "iso3": "pag",
        "iso2b": "pag",
        "iso2t": "pag",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tenharim",
        "iso3": "pah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pe",
        "iso3": "pai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parakanã",
        "iso3": "pak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pahlavi",
        "iso3": "pal",
        "iso2b": "pal",
        "iso2t": "pal",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Pampanga",
        "iso3": "pam",
        "iso2b": "pam",
        "iso2t": "pam",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panjabi",
        "iso3": "pan",
        "iso2b": "pan",
        "iso2t": "pan",
        "iso1": "pa",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Paiute",
        "iso3": "pao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papiamento",
        "iso3": "pap",
        "iso2b": "pap",
        "iso2t": "pap",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parya",
        "iso3": "paq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panamint",
        "iso3": "par",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papasena",
        "iso3": "pas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Palauan",
        "iso3": "pau",
        "iso2b": "pau",
        "iso2t": "pau",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pakaásnovos",
        "iso3": "pav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pawnee",
        "iso3": "paw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pankararé",
        "iso3": "pax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pech",
        "iso3": "pay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pankararú",
        "iso3": "paz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Páez",
        "iso3": "pbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Patamona",
        "iso3": "pbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mezontla Popoloca",
        "iso3": "pbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coyotepec Popoloca",
        "iso3": "pbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paraujano",
        "iso3": "pbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "E'ñapa Woromaipu",
        "iso3": "pbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parkwa",
        "iso3": "pbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mak (Nigeria)",
        "iso3": "pbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puebla Mazatec",
        "iso3": "pbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kpasam",
        "iso3": "pbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papel",
        "iso3": "pbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Badyara",
        "iso3": "pbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pangwa",
        "iso3": "pbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Pame",
        "iso3": "pbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Pashto",
        "iso3": "pbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Pashto",
        "iso3": "pbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pnar",
        "iso3": "pbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pyu (Papua New Guinea)",
        "iso3": "pby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santa Inés Ahuatempan Popoloca",
        "iso3": "pca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pear",
        "iso3": "pcb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bouyei",
        "iso3": "pcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Picard",
        "iso3": "pcd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ruching Palaung",
        "iso3": "pce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paliyan",
        "iso3": "pcf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paniya",
        "iso3": "pcg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pardhan",
        "iso3": "pch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Duruwa",
        "iso3": "pci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parenga",
        "iso3": "pcj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paite Chin",
        "iso3": "pck",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pardhi",
        "iso3": "pcl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nigerian Pidgin",
        "iso3": "pcm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piti",
        "iso3": "pcn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pacahuara",
        "iso3": "pcp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pyapun",
        "iso3": "pcw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anam",
        "iso3": "pda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pennsylvania German",
        "iso3": "pdc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pa Di",
        "iso3": "pdi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Podena",
        "iso3": "pdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Padoe",
        "iso3": "pdo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Plautdietsch",
        "iso3": "pdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayan",
        "iso3": "pdu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Peranakan Indonesian",
        "iso3": "pea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Pomo",
        "iso3": "peb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mala (Papua New Guinea)",
        "iso3": "ped",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taje",
        "iso3": "pee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northeastern Pomo",
        "iso3": "pef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pengo",
        "iso3": "peg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bonan",
        "iso3": "peh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chichimeca-Jonaz",
        "iso3": "pei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Pomo",
        "iso3": "pej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Penchal",
        "iso3": "pek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pekal",
        "iso3": "pel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phende",
        "iso3": "pem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Persian (ca. 600-400 B.C.)",
        "iso3": "peo",
        "iso2b": "peo",
        "iso2t": "peo",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kunja",
        "iso3": "pep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Pomo",
        "iso3": "peq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iranian Persian",
        "iso3": "pes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pémono",
        "iso3": "pev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Petats",
        "iso3": "pex",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Petjo",
        "iso3": "pey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Penan",
        "iso3": "pez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pááfang",
        "iso3": "pfa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pere",
        "iso3": "pfe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pfaelzisch",
        "iso3": "pfl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sudanese Creole Arabic",
        "iso3": "pga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gāndhārī",
        "iso3": "pgd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Pangwali",
        "iso3": "pgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pagi",
        "iso3": "pgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rerep",
        "iso3": "pgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Primitive Irish",
        "iso3": "pgl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Paelignian",
        "iso3": "pgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Pangseng",
        "iso3": "pgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pagu",
        "iso3": "pgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papua New Guinean Sign Language",
        "iso3": "pgz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pa-Hng",
        "iso3": "pha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phudagi",
        "iso3": "phd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phuong",
        "iso3": "phg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phukha",
        "iso3": "phh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pahari",
        "iso3": "phj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phake",
        "iso3": "phk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phalura",
        "iso3": "phl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phimbi",
        "iso3": "phm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phoenician",
        "iso3": "phn",
        "iso2b": "phn",
        "iso2t": "phn",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Phunoi",
        "iso3": "pho",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phana'",
        "iso3": "phq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pahari-Potwari",
        "iso3": "phr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phu Thai",
        "iso3": "pht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phuan",
        "iso3": "phu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pahlavani",
        "iso3": "phv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phangduwali",
        "iso3": "phw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pima Bajo",
        "iso3": "pia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yine",
        "iso3": "pib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pinji",
        "iso3": "pic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piaroa",
        "iso3": "pid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piro",
        "iso3": "pie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pingelapese",
        "iso3": "pif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pisabo",
        "iso3": "pig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pitcairn-Norfolk",
        "iso3": "pih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pijao",
        "iso3": "pij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yom",
        "iso3": "pil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Powhatan",
        "iso3": "pim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Piame",
        "iso3": "pin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piapoco",
        "iso3": "pio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pero",
        "iso3": "pip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piratapuyo",
        "iso3": "pir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pijin",
        "iso3": "pis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pitta Pitta",
        "iso3": "pit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pintupi-Luritja",
        "iso3": "piu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pileni",
        "iso3": "piv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pimbwe",
        "iso3": "piw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piu",
        "iso3": "pix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piya-Kwonci",
        "iso3": "piy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pije",
        "iso3": "piz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pitjantjatjara",
        "iso3": "pjt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ardhamāgadhī Prākrit",
        "iso3": "pka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Pokomo",
        "iso3": "pkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paekche",
        "iso3": "pkc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Pak-Tong",
        "iso3": "pkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pankhu",
        "iso3": "pkh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pakanha",
        "iso3": "pkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pökoot",
        "iso3": "pko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pukapuka",
        "iso3": "pkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Attapady Kurumba",
        "iso3": "pkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pakistan Sign Language",
        "iso3": "pks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maleng",
        "iso3": "pkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paku",
        "iso3": "pku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miani",
        "iso3": "pla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Polonombauk",
        "iso3": "plb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Palawano",
        "iso3": "plc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Polari",
        "iso3": "pld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Palu'e",
        "iso3": "ple",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pilagá",
        "iso3": "plg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paulohi",
        "iso3": "plh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pali",
        "iso3": "pli",
        "iso2b": "pli",
        "iso2t": "pli",
        "iso1": "pi",
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kohistani Shina",
        "iso3": "plk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shwe Palaung",
        "iso3": "pll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Palenquero",
        "iso3": "pln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oluta Popoluca",
        "iso3": "plo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Palaic",
        "iso3": "plq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Palaka Senoufo",
        "iso3": "plr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Marcos Tlacoyalco Popoloca",
        "iso3": "pls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Plateau Malagasy",
        "iso3": "plt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Palikúr",
        "iso3": "plu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwest Palawano",
        "iso3": "plv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brooke's Point Palawano",
        "iso3": "plw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolyu",
        "iso3": "ply",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paluan",
        "iso3": "plz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paama",
        "iso3": "pma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pambia",
        "iso3": "pmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pallanganmiddang",
        "iso3": "pmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pwaamei",
        "iso3": "pme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pamona",
        "iso3": "pmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Māhārāṣṭri Prākrit",
        "iso3": "pmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Northern Pumi",
        "iso3": "pmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Pumi",
        "iso3": "pmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lingua Franca",
        "iso3": "pml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pomo",
        "iso3": "pmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pam",
        "iso3": "pmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pom",
        "iso3": "pmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Pame",
        "iso3": "pmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paynamar",
        "iso3": "pmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piemontese",
        "iso3": "pms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuamotuan",
        "iso3": "pmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Plains Miwok",
        "iso3": "pmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Poumei Naga",
        "iso3": "pmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papuan Malay",
        "iso3": "pmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Pame",
        "iso3": "pmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Punan Bah-Biau",
        "iso3": "pna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Panjabi",
        "iso3": "pnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pannei",
        "iso3": "pnc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpinda",
        "iso3": "pnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Penan",
        "iso3": "pne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pangu",
        "iso3": "png",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Penrhyn",
        "iso3": "pnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aoheng",
        "iso3": "pni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pinjarup",
        "iso3": "pnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Paunaka",
        "iso3": "pnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paleni",
        "iso3": "pnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Punan Batu 1",
        "iso3": "pnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pinai-Hagahai",
        "iso3": "pnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panobo",
        "iso3": "pno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pancana",
        "iso3": "pnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pana (Burkina Faso)",
        "iso3": "pnq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panim",
        "iso3": "pnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ponosakan",
        "iso3": "pns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pontic",
        "iso3": "pnt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jiongnai Bunu",
        "iso3": "pnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pinigura",
        "iso3": "pnv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banyjima",
        "iso3": "pnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phong-Kniang",
        "iso3": "pnx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pinyin",
        "iso3": "pny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pana (Central African Republic)",
        "iso3": "pnz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Poqomam",
        "iso3": "poc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Juan Atzingo Popoloca",
        "iso3": "poe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Poke",
        "iso3": "pof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Potiguára",
        "iso3": "pog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Poqomchi'",
        "iso3": "poh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Highland Popoluca",
        "iso3": "poi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pokangá",
        "iso3": "pok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Polish",
        "iso3": "pol",
        "iso2b": "pol",
        "iso2t": "pol",
        "iso1": "pl",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeastern Pomo",
        "iso3": "pom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pohnpeian",
        "iso3": "pon",
        "iso2b": "pon",
        "iso2t": "pon",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Pomo",
        "iso3": "poo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pwapwâ",
        "iso3": "pop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Texistepec Popoluca",
        "iso3": "poq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Portuguese",
        "iso3": "por",
        "iso2b": "por",
        "iso2t": "por",
        "iso1": "pt",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sayula Popoluca",
        "iso3": "pos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Potawatomi",
        "iso3": "pot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Guinea Crioulo",
        "iso3": "pov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Felipe Otlaltepec Popoloca",
        "iso3": "pow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Polabian",
        "iso3": "pox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pogolo",
        "iso3": "poy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papi",
        "iso3": "ppe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paipai",
        "iso3": "ppi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uma",
        "iso3": "ppk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pipil",
        "iso3": "ppl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papuma",
        "iso3": "ppm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papapana",
        "iso3": "ppn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Folopa",
        "iso3": "ppo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pelende",
        "iso3": "ppp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pei",
        "iso3": "ppq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Luís Temalacayuca Popoloca",
        "iso3": "pps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pare",
        "iso3": "ppt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papora",
        "iso3": "ppu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pa'a",
        "iso3": "pqa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malecite-Passamaquoddy",
        "iso3": "pqm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parachi",
        "iso3": "prc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parsi-Dari",
        "iso3": "prd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Principense",
        "iso3": "pre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paranan",
        "iso3": "prf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Prussian",
        "iso3": "prg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Porohanon",
        "iso3": "prh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paicî",
        "iso3": "pri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parauk",
        "iso3": "prk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Peruvian Sign Language",
        "iso3": "prl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kibiri",
        "iso3": "prm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Prasuni",
        "iso3": "prn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Provençal (to 1500)",
        "iso3": "pro",
        "iso2b": "pro",
        "iso2t": "pro",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ashéninka Perené",
        "iso3": "prq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puri",
        "iso3": "prr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dari",
        "iso3": "prs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phai",
        "iso3": "prt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puragi",
        "iso3": "pru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Parawen",
        "iso3": "prw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Purik",
        "iso3": "prx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Providencia Sign Language",
        "iso3": "prz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asue Awyu",
        "iso3": "psa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iranian Sign Language",
        "iso3": "psc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Plains Indian Sign Language",
        "iso3": "psd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Malay",
        "iso3": "pse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Penang Sign Language",
        "iso3": "psg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwest Pashai",
        "iso3": "psh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeast Pashai",
        "iso3": "psi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puerto Rican Sign Language",
        "iso3": "psl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pauserna",
        "iso3": "psm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Panasuan",
        "iso3": "psn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Polish Sign Language",
        "iso3": "pso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Philippine Sign Language",
        "iso3": "psp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pasi",
        "iso3": "psq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Portuguese Sign Language",
        "iso3": "psr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaulong",
        "iso3": "pss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Pashto",
        "iso3": "pst",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sauraseni Prākrit",
        "iso3": "psu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Port Sandwich",
        "iso3": "psw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piscataway",
        "iso3": "psy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pai Tavytera",
        "iso3": "pta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pataxó Hã-Ha-Hãe",
        "iso3": "pth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pindiini",
        "iso3": "pti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Patani",
        "iso3": "ptn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zo'é",
        "iso3": "pto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Patep",
        "iso3": "ptp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pattapu",
        "iso3": "ptq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Piamatsina",
        "iso3": "ptr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enrekang",
        "iso3": "ptt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bambam",
        "iso3": "ptu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Port Vato",
        "iso3": "ptv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pentlatch",
        "iso3": "ptw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pathiya",
        "iso3": "pty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Highland Purepecha",
        "iso3": "pua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Purum",
        "iso3": "pub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Punan Merap",
        "iso3": "puc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Punan Aput",
        "iso3": "pud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puelche",
        "iso3": "pue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Punan Merah",
        "iso3": "puf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phuie",
        "iso3": "pug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puinave",
        "iso3": "pui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Punan Tubu",
        "iso3": "puj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puma",
        "iso3": "pum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puoc",
        "iso3": "puo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pulabu",
        "iso3": "pup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puquina",
        "iso3": "puq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Puruborá",
        "iso3": "pur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pushto",
        "iso3": "pus",
        "iso2b": "pus",
        "iso2t": "pus",
        "iso1": "ps",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Putoh",
        "iso3": "put",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Punu",
        "iso3": "puu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puluwatese",
        "iso3": "puw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puare",
        "iso3": "pux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Purisimeño",
        "iso3": "puy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pawaia",
        "iso3": "pwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panawa",
        "iso3": "pwb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gapapaiwa",
        "iso3": "pwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Patwin",
        "iso3": "pwi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Molbog",
        "iso3": "pwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paiwan",
        "iso3": "pwn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pwo Western Karen",
        "iso3": "pwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Powari",
        "iso3": "pwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pwo Northern Karen",
        "iso3": "pww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quetzaltepec Mixe",
        "iso3": "pxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pye Krumen",
        "iso3": "pye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Fyam",
        "iso3": "pym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Poyanáwa",
        "iso3": "pyn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paraguayan Sign Language",
        "iso3": "pys",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puyuma",
        "iso3": "pyu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pyu (Myanmar)",
        "iso3": "pyx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Pyen",
        "iso3": "pyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pesse",
        "iso3": "pze",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pazeh",
        "iso3": "pzh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jejara Naga",
        "iso3": "pzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quapaw",
        "iso3": "qua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huallaga Huánuco Quechua",
        "iso3": "qub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "K'iche'",
        "iso3": "quc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Calderón Highland Quichua",
        "iso3": "qud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quechua",
        "iso3": "que",
        "iso2b": "que",
        "iso2t": "que",
        "iso1": "qu",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Lambayeque Quechua",
        "iso3": "quf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chimborazo Highland Quichua",
        "iso3": "qug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Bolivian Quechua",
        "iso3": "quh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quileute",
        "iso3": "qui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chachapoyas Quechua",
        "iso3": "quk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Bolivian Quechua",
        "iso3": "qul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sipacapense",
        "iso3": "qum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quinault",
        "iso3": "qun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Southern Pastaza Quechua",
        "iso3": "qup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quinqui",
        "iso3": "quq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yanahuanca Pasco Quechua",
        "iso3": "qur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santiago del Estero Quichua",
        "iso3": "qus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sacapulteco",
        "iso3": "quv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tena Lowland Quichua",
        "iso3": "quw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yauyos Quechua",
        "iso3": "qux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayacucho Quechua",
        "iso3": "quy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cusco Quechua",
        "iso3": "quz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ambo-Pasco Quechua",
        "iso3": "qva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cajamarca Quechua",
        "iso3": "qvc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Apurímac Quechua",
        "iso3": "qve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huamalíes-Dos de Mayo Huánuco Quechua",
        "iso3": "qvh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Imbabura Highland Quichua",
        "iso3": "qvi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loja Highland Quichua",
        "iso3": "qvj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cajatambo North Lima Quechua",
        "iso3": "qvl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Margos-Yarowilca-Lauricocha Quechua",
        "iso3": "qvm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Junín Quechua",
        "iso3": "qvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Napo Lowland Quechua",
        "iso3": "qvo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pacaraos Quechua",
        "iso3": "qvp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Martín Quechua",
        "iso3": "qvs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huaylla Wanca Quechua",
        "iso3": "qvw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Queyu",
        "iso3": "qvy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Pastaza Quichua",
        "iso3": "qvz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Corongo Ancash Quechua",
        "iso3": "qwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Classical Quechua",
        "iso3": "qwc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Huaylas Ancash Quechua",
        "iso3": "qwh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuman (Russia)",
        "iso3": "qwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sihuas Ancash Quechua",
        "iso3": "qws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwalhioqua-Tlatskanai",
        "iso3": "qwt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chiquián Ancash Quechua",
        "iso3": "qxa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chincha Quechua",
        "iso3": "qxc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panao Huánuco Quechua",
        "iso3": "qxh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Salasaca Highland Quichua",
        "iso3": "qxl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Conchucos Ancash Quechua",
        "iso3": "qxn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Conchucos Ancash Quechua",
        "iso3": "qxo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Puno Quechua",
        "iso3": "qxp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Qashqa'i",
        "iso3": "qxq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cañar Highland Quichua",
        "iso3": "qxr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Qiang",
        "iso3": "qxs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santa Ana de Tusi Pasco Quechua",
        "iso3": "qxt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arequipa-La Unión Quechua",
        "iso3": "qxu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jauja Wanca Quechua",
        "iso3": "qxw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quenya",
        "iso3": "qya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Quiripi",
        "iso3": "qyp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Dungmali",
        "iso3": "raa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Camling",
        "iso3": "rab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rasawa",
        "iso3": "rac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rade",
        "iso3": "rad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Meohang",
        "iso3": "raf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Logooli",
        "iso3": "rag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rabha",
        "iso3": "rah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ramoaaina",
        "iso3": "rai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rajasthani",
        "iso3": "raj",
        "iso2b": "raj",
        "iso2t": "raj",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Tulu-Bohuai",
        "iso3": "rak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ralte",
        "iso3": "ral",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Canela",
        "iso3": "ram",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Riantana",
        "iso3": "ran",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rao",
        "iso3": "rao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rapanui",
        "iso3": "rap",
        "iso2b": "rap",
        "iso2t": "rap",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saam",
        "iso3": "raq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rarotongan",
        "iso3": "rar",
        "iso2b": "rar",
        "iso2t": "rar",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tegali",
        "iso3": "ras",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Razajerdi",
        "iso3": "rat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Raute",
        "iso3": "rau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sampang",
        "iso3": "rav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rawang",
        "iso3": "raw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rang",
        "iso3": "rax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rapa",
        "iso3": "ray",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rahambuu",
        "iso3": "raz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rumai Palaung",
        "iso3": "rbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Bontok",
        "iso3": "rbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miraya Bikol",
        "iso3": "rbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barababaraba",
        "iso3": "rbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Réunion Creole French",
        "iso3": "rcf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rudbari",
        "iso3": "rdb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rerau",
        "iso3": "rea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rembong",
        "iso3": "reb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rejang Kayan",
        "iso3": "ree",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kara (Tanzania)",
        "iso3": "reg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Reli",
        "iso3": "rei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rejang",
        "iso3": "rej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rendille",
        "iso3": "rel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Remo",
        "iso3": "rem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Rengao",
        "iso3": "ren",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rer Bare",
        "iso3": "rer",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Reshe",
        "iso3": "res",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Retta",
        "iso3": "ret",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Reyesano",
        "iso3": "rey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Roria",
        "iso3": "rga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Romano-Greek",
        "iso3": "rge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rangkas",
        "iso3": "rgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Romagnol",
        "iso3": "rgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Resígaro",
        "iso3": "rgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Roglai",
        "iso3": "rgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ringgou",
        "iso3": "rgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rohingya",
        "iso3": "rhg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yahang",
        "iso3": "rhp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Riang (India)",
        "iso3": "ria",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bribri Sign Language",
        "iso3": "rib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tarifit",
        "iso3": "rif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Riang Lang",
        "iso3": "ril",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyaturu",
        "iso3": "rim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nungu",
        "iso3": "rin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ribun",
        "iso3": "rir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ritharrngu",
        "iso3": "rit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Riung",
        "iso3": "riu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rajong",
        "iso3": "rjg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Raji",
        "iso3": "rji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rajbanshi",
        "iso3": "rjs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kraol",
        "iso3": "rka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rikbaktsa",
        "iso3": "rkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rakahanga-Manihiki",
        "iso3": "rkh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rakhine",
        "iso3": "rki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marka",
        "iso3": "rkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rangpuri",
        "iso3": "rkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arakwal",
        "iso3": "rkw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Rama",
        "iso3": "rma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rembarrnga",
        "iso3": "rmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Carpathian Romani",
        "iso3": "rmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Traveller Danish",
        "iso3": "rmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Angloromani",
        "iso3": "rme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalo Finnish Romani",
        "iso3": "rmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Traveller Norwegian",
        "iso3": "rmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Murkim",
        "iso3": "rmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lomavren",
        "iso3": "rmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Romkun",
        "iso3": "rmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baltic Romani",
        "iso3": "rml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Roma",
        "iso3": "rmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balkan Romani",
        "iso3": "rmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sinte Romani",
        "iso3": "rmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rempi",
        "iso3": "rmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Caló",
        "iso3": "rmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Romanian Sign Language",
        "iso3": "rms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Domari",
        "iso3": "rmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tavringer Romani",
        "iso3": "rmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Romanova",
        "iso3": "rmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Welsh Romani",
        "iso3": "rmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Romam",
        "iso3": "rmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vlax Romani",
        "iso3": "rmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marma",
        "iso3": "rmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brunca Sign Language",
        "iso3": "rnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ruund",
        "iso3": "rnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ronga",
        "iso3": "rng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ranglong",
        "iso3": "rnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Roon",
        "iso3": "rnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rongpo",
        "iso3": "rnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nari Nari",
        "iso3": "rnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Rungwa",
        "iso3": "rnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tae'",
        "iso3": "rob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cacgia Roglai",
        "iso3": "roc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rogo",
        "iso3": "rod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ronji",
        "iso3": "roe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rombo",
        "iso3": "rof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Roglai",
        "iso3": "rog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Romansh",
        "iso3": "roh",
        "iso2b": "roh",
        "iso2t": "roh",
        "iso1": "rm",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Romblomanon",
        "iso3": "rol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Romany",
        "iso3": "rom",
        "iso2b": "rom",
        "iso2t": "rom",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Romanian",
        "iso3": "ron",
        "iso2b": "rum",
        "iso2t": "ron",
        "iso1": "ro",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rotokas",
        "iso3": "roo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kriol",
        "iso3": "rop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rongga",
        "iso3": "ror",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Runga",
        "iso3": "rou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dela-Oenale",
        "iso3": "row",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Repanbitip",
        "iso3": "rpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rapting",
        "iso3": "rpt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ririo",
        "iso3": "rri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moriori",
        "iso3": "rrm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Waima",
        "iso3": "rro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arritinngithigh",
        "iso3": "rrt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Romano-Serbian",
        "iso3": "rsb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ruthenian",
        "iso3": "rsk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Russian Sign Language",
        "iso3": "rsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miriwoong Sign Language",
        "iso3": "rsm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rwandan Sign Language",
        "iso3": "rsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rishiwa",
        "iso3": "rsw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rungtu Chin",
        "iso3": "rtc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ratahan",
        "iso3": "rth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rotuman",
        "iso3": "rtm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yurats",
        "iso3": "rts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Rathawi",
        "iso3": "rtw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gungu",
        "iso3": "rub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ruuli",
        "iso3": "ruc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rusyn",
        "iso3": "rue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Luguru",
        "iso3": "ruf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Roviana",
        "iso3": "rug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ruga",
        "iso3": "ruh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rufiji",
        "iso3": "rui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Che",
        "iso3": "ruk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rundi",
        "iso3": "run",
        "iso2b": "run",
        "iso2t": "run",
        "iso1": "rn",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Istro Romanian",
        "iso3": "ruo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Macedo-Romanian",
        "iso3": "rup",
        "iso2b": "rup",
        "iso2t": "rup",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Megleno Romanian",
        "iso3": "ruq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Russian",
        "iso3": "rus",
        "iso2b": "rus",
        "iso2t": "rus",
        "iso1": "ru",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rutul",
        "iso3": "rut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lanas Lobu",
        "iso3": "ruu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mala (Nigeria)",
        "iso3": "ruy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ruma",
        "iso3": "ruz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rawo",
        "iso3": "rwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rwa",
        "iso3": "rwk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ruwila",
        "iso3": "rwl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amba (Uganda)",
        "iso3": "rwm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rawa",
        "iso3": "rwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marwari (India)",
        "iso3": "rwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngardi",
        "iso3": "rxd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karuwali",
        "iso3": "rxw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Northern Amami-Oshima",
        "iso3": "ryn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaeyama",
        "iso3": "rys",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Okinawan",
        "iso3": "ryu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rāziḥī",
        "iso3": "rzh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saba",
        "iso3": "saa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buglere",
        "iso3": "sab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Meskwaki",
        "iso3": "sac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sandawe",
        "iso3": "sad",
        "iso2b": "sad",
        "iso2t": "sad",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sabanê",
        "iso3": "sae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Safaliba",
        "iso3": "saf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sango",
        "iso3": "sag",
        "iso2b": "sag",
        "iso2t": "sag",
        "iso1": "sg",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yakut",
        "iso3": "sah",
        "iso2b": "sah",
        "iso2t": "sah",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sahu",
        "iso3": "saj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sake",
        "iso3": "sak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samaritan Aramaic",
        "iso3": "sam",
        "iso2b": "sam",
        "iso2t": "sam",
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sanskrit",
        "iso3": "san",
        "iso2b": "san",
        "iso2t": "san",
        "iso1": "sa",
        "scope": "Macrolanguage",
        "type": "Historical",
    },
    {
        "name": "Sause",
        "iso3": "sao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samburu",
        "iso3": "saq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saraveca",
        "iso3": "sar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sasak",
        "iso3": "sas",
        "iso2b": "sas",
        "iso2t": "sas",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santali",
        "iso3": "sat",
        "iso2b": "sat",
        "iso2t": "sat",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saleman",
        "iso3": "sau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saafi-Saafi",
        "iso3": "sav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sawi",
        "iso3": "saw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sa",
        "iso3": "sax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saya",
        "iso3": "say",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saurashtra",
        "iso3": "saz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngambay",
        "iso3": "sba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Simbo",
        "iso3": "sbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kele (Papua New Guinea)",
        "iso3": "sbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Samo",
        "iso3": "sbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saliba",
        "iso3": "sbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chabu",
        "iso3": "sbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seget",
        "iso3": "sbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sori-Harengan",
        "iso3": "sbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seti",
        "iso3": "sbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Surbakhal",
        "iso3": "sbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Safwa",
        "iso3": "sbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Botolan Sambal",
        "iso3": "sbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sagala",
        "iso3": "sbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sindhi Bhil",
        "iso3": "sbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sabüm",
        "iso3": "sbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sangu (Tanzania)",
        "iso3": "sbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sileibi",
        "iso3": "sbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sembakung Murut",
        "iso3": "sbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Subiya",
        "iso3": "sbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kimki",
        "iso3": "sbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Stod Bhoti",
        "iso3": "sbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sabine",
        "iso3": "sbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Simba",
        "iso3": "sbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seberuang",
        "iso3": "sbx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Soli",
        "iso3": "sby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sara Kaba",
        "iso3": "sbz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chut",
        "iso3": "scb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dongxiang",
        "iso3": "sce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Miguel Creole French",
        "iso3": "scf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sanggau",
        "iso3": "scg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sakachep",
        "iso3": "sch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sri Lankan Creole Malay",
        "iso3": "sci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sadri",
        "iso3": "sck",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shina",
        "iso3": "scl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sicilian",
        "iso3": "scn",
        "iso2b": "scn",
        "iso2t": "scn",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Scots",
        "iso3": "sco",
        "iso2b": "sco",
        "iso2t": "sco",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hyolmo",
        "iso3": "scp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sa'och",
        "iso3": "scq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Slavey",
        "iso3": "scs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Katang",
        "iso3": "sct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shumcho",
        "iso3": "scu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sheni",
        "iso3": "scv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sha",
        "iso3": "scw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sicel",
        "iso3": "scx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Toraja-Sa'dan",
        "iso3": "sda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shabak",
        "iso3": "sdb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sassarese Sardinian",
        "iso3": "sdc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Surubu",
        "iso3": "sde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sarli",
        "iso3": "sdf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Savi",
        "iso3": "sdg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Kurdish",
        "iso3": "sdh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suundi",
        "iso3": "sdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sos Kundi",
        "iso3": "sdk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saudi Arabian Sign Language",
        "iso3": "sdl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gallurese Sardinian",
        "iso3": "sdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bukar-Sadung Bidayuh",
        "iso3": "sdo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sherdukpen",
        "iso3": "sdp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Semandang",
        "iso3": "sdq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Oraon Sadri",
        "iso3": "sdr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sened",
        "iso3": "sds",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Shuadit",
        "iso3": "sdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sarudu",
        "iso3": "sdu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sibu Melanau",
        "iso3": "sdx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sallands",
        "iso3": "sdz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Semai",
        "iso3": "sea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shempire Senoufo",
        "iso3": "seb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sechelt",
        "iso3": "sec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sedang",
        "iso3": "sed",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seneca",
        "iso3": "see",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cebaara Senoufo",
        "iso3": "sef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Segeju",
        "iso3": "seg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sena",
        "iso3": "seh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seri",
        "iso3": "sei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sene",
        "iso3": "sej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sekani",
        "iso3": "sek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Selkup",
        "iso3": "sel",
        "iso2b": "sel",
        "iso2t": "sel",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nanerigé Sénoufo",
        "iso3": "sen",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suarmin",
        "iso3": "seo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sìcìté Sénoufo",
        "iso3": "sep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Senara Sénoufo",
        "iso3": "seq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Serrano",
        "iso3": "ser",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koyraboro Senni Songhai",
        "iso3": "ses",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sentani",
        "iso3": "set",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Serui-Laut",
        "iso3": "seu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyarafolo Senoufo",
        "iso3": "sev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sewa Bay",
        "iso3": "sew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Secoya",
        "iso3": "sey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Senthang Chin",
        "iso3": "sez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Langue des signes de Belgique Francophone",
        "iso3": "sfb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Subanen",
        "iso3": "sfe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Small Flowery Miao",
        "iso3": "sfm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South African Sign Language",
        "iso3": "sfs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sehwi",
        "iso3": "sfw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Old Irish (to 900)",
        "iso3": "sga",
        "iso2b": "sga",
        "iso2t": "sga",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mag-antsi Ayta",
        "iso3": "sgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kipsigis",
        "iso3": "sgc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Surigaonon",
        "iso3": "sgd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Segai",
        "iso3": "sge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swiss-German Sign Language",
        "iso3": "sgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shughni",
        "iso3": "sgh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suga",
        "iso3": "sgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Surgujia",
        "iso3": "sgj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sangkong",
        "iso3": "sgk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Singa",
        "iso3": "sgm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Singpho",
        "iso3": "sgp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sangisari",
        "iso3": "sgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samogitian",
        "iso3": "sgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Brokpake",
        "iso3": "sgt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Salas",
        "iso3": "sgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sebat Bet Gurage",
        "iso3": "sgw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sierra Leone Sign Language",
        "iso3": "sgx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sanglechi",
        "iso3": "sgy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sursurunga",
        "iso3": "sgz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shall-Zwall",
        "iso3": "sha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ninam",
        "iso3": "shb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sonde",
        "iso3": "shc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kundal Shahi",
        "iso3": "shd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sheko",
        "iso3": "she",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shua",
        "iso3": "shg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shoshoni",
        "iso3": "shh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tachelhit",
        "iso3": "shi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shatt",
        "iso3": "shj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shilluk",
        "iso3": "shk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shendu",
        "iso3": "shl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shahrudi",
        "iso3": "shm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shan",
        "iso3": "shn",
        "iso2b": "shn",
        "iso2t": "shn",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shanga",
        "iso3": "sho",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shipibo-Conibo",
        "iso3": "shp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sala",
        "iso3": "shq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shi",
        "iso3": "shr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shuswap",
        "iso3": "shs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shasta",
        "iso3": "sht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chadian Arabic",
        "iso3": "shu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shehri",
        "iso3": "shv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shwai",
        "iso3": "shw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "She",
        "iso3": "shx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tachawit",
        "iso3": "shy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Syenara Senoufo",
        "iso3": "shz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akkala Sami",
        "iso3": "sia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sebop",
        "iso3": "sib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sidamo",
        "iso3": "sid",
        "iso2b": "sid",
        "iso2t": "sid",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Simaa",
        "iso3": "sie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siamou",
        "iso3": "sif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Paasaal",
        "iso3": "sig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zire",
        "iso3": "sih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shom Peng",
        "iso3": "sii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Numbami",
        "iso3": "sij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sikiana",
        "iso3": "sik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumulung Sisaala",
        "iso3": "sil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mende (Papua New Guinea)",
        "iso3": "sim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sinhala",
        "iso3": "sin",
        "iso2b": "sin",
        "iso2t": "sin",
        "iso1": "si",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sikkimese",
        "iso3": "sip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sonia",
        "iso3": "siq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siri",
        "iso3": "sir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siuslaw",
        "iso3": "sis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sinagen",
        "iso3": "siu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sumariup",
        "iso3": "siv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siwai",
        "iso3": "siw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sumau",
        "iso3": "six",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sivandi",
        "iso3": "siy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siwi",
        "iso3": "siz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Epena",
        "iso3": "sja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sajau Basap",
        "iso3": "sjb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shaojiang Chinese",
        "iso3": "sjc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kildin Sami",
        "iso3": "sjd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pite Sami",
        "iso3": "sje",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Assangori",
        "iso3": "sjg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kemi Sami",
        "iso3": "sjk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sajalong",
        "iso3": "sjl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mapun",
        "iso3": "sjm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sindarin",
        "iso3": "sjn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Xibe",
        "iso3": "sjo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Surjapuri",
        "iso3": "sjp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siar-Lak",
        "iso3": "sjr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Senhaja De Srair",
        "iso3": "sjs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ter Sami",
        "iso3": "sjt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ume Sami",
        "iso3": "sju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shawnee",
        "iso3": "sjw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Skagit",
        "iso3": "ska",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saek",
        "iso3": "skb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ma Manda",
        "iso3": "skc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Sierra Miwok",
        "iso3": "skd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seke (Vanuatu)",
        "iso3": "ske",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sakirabiá",
        "iso3": "skf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sakalava Malagasy",
        "iso3": "skg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sikule",
        "iso3": "skh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sika",
        "iso3": "ski",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seke (Nepal)",
        "iso3": "skj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kutong",
        "iso3": "skm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kolibugan Subanon",
        "iso3": "skn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seko Tengah",
        "iso3": "sko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sekapan",
        "iso3": "skp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sininkere",
        "iso3": "skq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saraiki",
        "iso3": "skr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maia",
        "iso3": "sks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sakata",
        "iso3": "skt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sakao",
        "iso3": "sku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Skou",
        "iso3": "skv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Skepi Creole Dutch",
        "iso3": "skw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Seko Padang",
        "iso3": "skx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sikaiana",
        "iso3": "sky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sekar",
        "iso3": "skz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sáliba",
        "iso3": "slc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sissala",
        "iso3": "sld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sholaga",
        "iso3": "sle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swiss-Italian Sign Language",
        "iso3": "slf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Selungai Murut",
        "iso3": "slg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Puget Sound Salish",
        "iso3": "slh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Silesian",
        "iso3": "sli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Salumá",
        "iso3": "slj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Slovak",
        "iso3": "slk",
        "iso2b": "slo",
        "iso2t": "slk",
        "iso1": "sk",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Salt-Yui",
        "iso3": "sll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pangutaran Sama",
        "iso3": "slm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Salinan",
        "iso3": "sln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lamaholot",
        "iso3": "slp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Salar",
        "iso3": "slr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Singapore Sign Language",
        "iso3": "sls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sila",
        "iso3": "slt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Selaru",
        "iso3": "slu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Slovenian",
        "iso3": "slv",
        "iso2b": "slv",
        "iso2t": "slv",
        "iso1": "sl",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sialum",
        "iso3": "slw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Salampasu",
        "iso3": "slx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Selayar",
        "iso3": "sly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ma'ya",
        "iso3": "slz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Sami",
        "iso3": "sma",
        "iso2b": "sma",
        "iso2t": "sma",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Simbari",
        "iso3": "smb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Som",
        "iso3": "smc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Northern Sami",
        "iso3": "sme",
        "iso2b": "sme",
        "iso2t": "sme",
        "iso1": "se",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Auwe",
        "iso3": "smf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Simbali",
        "iso3": "smg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samei",
        "iso3": "smh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lule Sami",
        "iso3": "smj",
        "iso2b": "smj",
        "iso2t": "smj",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bolinao",
        "iso3": "smk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Sama",
        "iso3": "sml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Musasa",
        "iso3": "smm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Inari Sami",
        "iso3": "smn",
        "iso2b": "smn",
        "iso2t": "smn",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samoan",
        "iso3": "smo",
        "iso2b": "smo",
        "iso2t": "smo",
        "iso1": "sm",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samaritan",
        "iso3": "smp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Samo",
        "iso3": "smq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Simeulue",
        "iso3": "smr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Skolt Sami",
        "iso3": "sms",
        "iso2b": "sms",
        "iso2t": "sms",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Simte",
        "iso3": "smt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Somray",
        "iso3": "smu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Samvedi",
        "iso3": "smv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sumbawa",
        "iso3": "smw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samba",
        "iso3": "smx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Semnani",
        "iso3": "smy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Simeku",
        "iso3": "smz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shona",
        "iso3": "sna",
        "iso2b": "sna",
        "iso2t": "sna",
        "iso1": "sn",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sinaugoro",
        "iso3": "snc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sindhi",
        "iso3": "snd",
        "iso2b": "snd",
        "iso2t": "snd",
        "iso1": "sd",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bau Bidayuh",
        "iso3": "sne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Noon",
        "iso3": "snf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sanga (Democratic Republic of Congo)",
        "iso3": "sng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sensi",
        "iso3": "sni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Riverain Sango",
        "iso3": "snj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Soninke",
        "iso3": "snk",
        "iso2b": "snk",
        "iso2t": "snk",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sangil",
        "iso3": "snl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Ma'di",
        "iso3": "snm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siona",
        "iso3": "snn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Snohomish",
        "iso3": "sno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siane",
        "iso3": "snp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sangu (Gabon)",
        "iso3": "snq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sihan",
        "iso3": "snr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South West Bay",
        "iso3": "sns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Senggi",
        "iso3": "snu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sa'ban",
        "iso3": "snv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Selee",
        "iso3": "snw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sam",
        "iso3": "snx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saniyo-Hiyewe",
        "iso3": "sny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kou",
        "iso3": "snz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thai Song",
        "iso3": "soa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sobei",
        "iso3": "sob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "So (Democratic Republic of Congo)",
        "iso3": "soc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Songoora",
        "iso3": "sod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Songomeno",
        "iso3": "soe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sogdian",
        "iso3": "sog",
        "iso2b": "sog",
        "iso2t": "sog",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Aka",
        "iso3": "soh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sonha",
        "iso3": "soi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Soi",
        "iso3": "soj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sokoro",
        "iso3": "sok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Solos",
        "iso3": "sol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Somali",
        "iso3": "som",
        "iso2b": "som",
        "iso2t": "som",
        "iso1": "so",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Songo",
        "iso3": "soo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Songe",
        "iso3": "sop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanasi",
        "iso3": "soq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Somrai",
        "iso3": "sor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seeku",
        "iso3": "sos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Sotho",
        "iso3": "sot",
        "iso2b": "sot",
        "iso2t": "sot",
        "iso1": "st",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Thai",
        "iso3": "sou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sonsorol",
        "iso3": "sov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sowanda",
        "iso3": "sow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swo",
        "iso3": "sox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miyobe",
        "iso3": "soy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Temi",
        "iso3": "soz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Spanish",
        "iso3": "spa",
        "iso2b": "spa",
        "iso2t": "spa",
        "iso1": "es",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sepa (Indonesia)",
        "iso3": "spb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sapé",
        "iso3": "spc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saep",
        "iso3": "spd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sepa (Papua New Guinea)",
        "iso3": "spe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sian",
        "iso3": "spg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saponi",
        "iso3": "spi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sengo",
        "iso3": "spk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Selepet",
        "iso3": "spl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akukem",
        "iso3": "spm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sanapaná",
        "iso3": "spn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Spokane",
        "iso3": "spo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Supyire Senoufo",
        "iso3": "spp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loreto-Ucayali Spanish",
        "iso3": "spq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saparua",
        "iso3": "spr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saposa",
        "iso3": "sps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Spiti Bhoti",
        "iso3": "spt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sapuan",
        "iso3": "spu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sambalpuri",
        "iso3": "spv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Picene",
        "iso3": "spx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Sabaot",
        "iso3": "spy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shama-Sambuga",
        "iso3": "sqa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shau",
        "iso3": "sqh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Albanian",
        "iso3": "sqi",
        "iso2b": "alb",
        "iso2t": "sqi",
        "iso1": "sq",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Albanian Sign Language",
        "iso3": "sqk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suma",
        "iso3": "sqm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Susquehannock",
        "iso3": "sqn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sorkhei",
        "iso3": "sqo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sou",
        "iso3": "sqq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siculo Arabic",
        "iso3": "sqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Sri Lankan Sign Language",
        "iso3": "sqs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Soqotri",
        "iso3": "sqt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Squamish",
        "iso3": "squ",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kufr Qassem Sign Language (KQSL)",
        "iso3": "sqx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saruga",
        "iso3": "sra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sora",
        "iso3": "srb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Logudorese Sardinian",
        "iso3": "src",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sardinian",
        "iso3": "srd",
        "iso2b": "srd",
        "iso2t": "srd",
        "iso1": "sc",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Sara",
        "iso3": "sre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nafi",
        "iso3": "srf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sulod",
        "iso3": "srg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sarikoli",
        "iso3": "srh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siriano",
        "iso3": "sri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Serudung Murut",
        "iso3": "srk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isirawa",
        "iso3": "srl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saramaccan",
        "iso3": "srm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sranan Tongo",
        "iso3": "srn",
        "iso2b": "srn",
        "iso2t": "srn",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Campidanese Sardinian",
        "iso3": "sro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Serbian",
        "iso3": "srp",
        "iso2b": "srp",
        "iso2t": "srp",
        "iso1": "sr",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sirionó",
        "iso3": "srq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Serer",
        "iso3": "srr",
        "iso2b": "srr",
        "iso2t": "srr",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sarsi",
        "iso3": "srs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sauri",
        "iso3": "srt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suruí",
        "iso3": "sru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Sorsoganon",
        "iso3": "srv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Serua",
        "iso3": "srw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sirmauri",
        "iso3": "srx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sera",
        "iso3": "sry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shahmirzadi",
        "iso3": "srz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Sama",
        "iso3": "ssb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suba-Simbiti",
        "iso3": "ssc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siroi",
        "iso3": "ssd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balangingi",
        "iso3": "sse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thao",
        "iso3": "ssf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seimat",
        "iso3": "ssg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shihhi Arabic",
        "iso3": "ssh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sansi",
        "iso3": "ssi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sausi",
        "iso3": "ssj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sunam",
        "iso3": "ssk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Sisaala",
        "iso3": "ssl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Semnam",
        "iso3": "ssm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waata",
        "iso3": "ssn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sissano",
        "iso3": "sso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Spanish Sign Language",
        "iso3": "ssp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "So'a",
        "iso3": "ssq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swiss-French Sign Language",
        "iso3": "ssr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sô",
        "iso3": "sss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sinasina",
        "iso3": "sst",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Susuami",
        "iso3": "ssu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shark Bay",
        "iso3": "ssv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swati",
        "iso3": "ssw",
        "iso2b": "ssw",
        "iso2t": "ssw",
        "iso1": "ss",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samberigi",
        "iso3": "ssx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saho",
        "iso3": "ssy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sengseng",
        "iso3": "ssz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Settla",
        "iso3": "sta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Subanen",
        "iso3": "stb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sentinel",
        "iso3": "std",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Liana-Seti",
        "iso3": "ste",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seta",
        "iso3": "stf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Trieng",
        "iso3": "stg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shelta",
        "iso3": "sth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bulo Stieng",
        "iso3": "sti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matya Samo",
        "iso3": "stj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Arammba",
        "iso3": "stk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Stellingwerfs",
        "iso3": "stl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Setaman",
        "iso3": "stm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Owa",
        "iso3": "stn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Stoney",
        "iso3": "sto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeastern Tepehuan",
        "iso3": "stp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saterfriesisch",
        "iso3": "stq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Straits Salish",
        "iso3": "str",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shumashti",
        "iso3": "sts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Budeh Stieng",
        "iso3": "stt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samtao",
        "iso3": "stu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Silt'e",
        "iso3": "stv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Satawalese",
        "iso3": "stw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siberian Tatar",
        "iso3": "sty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sulka",
        "iso3": "sua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suku",
        "iso3": "sub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Subanon",
        "iso3": "suc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suena",
        "iso3": "sue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suganga",
        "iso3": "sug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suki",
        "iso3": "sui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shubi",
        "iso3": "suj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sukuma",
        "iso3": "suk",
        "iso2b": "suk",
        "iso2t": "suk",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sundanese",
        "iso3": "sun",
        "iso2b": "sun",
        "iso2t": "sun",
        "iso1": "su",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bouni",
        "iso3": "suo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tirmaga-Chai Suri",
        "iso3": "suq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mwaghavul",
        "iso3": "sur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Susu",
        "iso3": "sus",
        "iso2b": "sus",
        "iso2t": "sus",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Subtiaba",
        "iso3": "sut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Puroik",
        "iso3": "suv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sumbwa",
        "iso3": "suw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sumerian",
        "iso3": "sux",
        "iso2b": "sux",
        "iso2t": "sux",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Suyá",
        "iso3": "suy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sunwar",
        "iso3": "suz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Svan",
        "iso3": "sva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ulau-Suain",
        "iso3": "svb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vincentian Creole English",
        "iso3": "svc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Serili",
        "iso3": "sve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Slovakian Sign Language",
        "iso3": "svk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Slavomolisano",
        "iso3": "svm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Savosavo",
        "iso3": "svs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Skalvian",
        "iso3": "svx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Swahili (macrolanguage)",
        "iso3": "swa",
        "iso2b": "swa",
        "iso2t": "swa",
        "iso1": "sw",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Maore Comorian",
        "iso3": "swb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Congo Swahili",
        "iso3": "swc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swedish",
        "iso3": "swe",
        "iso2b": "swe",
        "iso2t": "swe",
        "iso1": "sv",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sere",
        "iso3": "swf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swabian",
        "iso3": "swg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swahili (individual language)",
        "iso3": "swh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sui",
        "iso3": "swi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sira",
        "iso3": "swj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malawi Sena",
        "iso3": "swk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Swedish Sign Language",
        "iso3": "swl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samosa",
        "iso3": "swm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sawknah",
        "iso3": "swn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shanenawa",
        "iso3": "swo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suau",
        "iso3": "swp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sharwa",
        "iso3": "swq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saweru",
        "iso3": "swr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seluwasan",
        "iso3": "sws",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sawila",
        "iso3": "swt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suwawa",
        "iso3": "swu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shekhawati",
        "iso3": "swv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sowa",
        "iso3": "sww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Suruahá",
        "iso3": "swx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sarua",
        "iso3": "swy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suba",
        "iso3": "sxb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sicanian",
        "iso3": "sxc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Sighu",
        "iso3": "sxe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shuhi",
        "iso3": "sxg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Kalapuya",
        "iso3": "sxk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Selian",
        "iso3": "sxl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Samre",
        "iso3": "sxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sangir",
        "iso3": "sxn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sorothaptic",
        "iso3": "sxo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Saaroa",
        "iso3": "sxr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sasaru",
        "iso3": "sxs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Saxon",
        "iso3": "sxu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Saxwe Gbe",
        "iso3": "sxw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Siang",
        "iso3": "sya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Subanen",
        "iso3": "syb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Classical Syriac",
        "iso3": "syc",
        "iso2b": "syc",
        "iso2t": "syc",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Seki",
        "iso3": "syi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sukur",
        "iso3": "syk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sylheti",
        "iso3": "syl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maya Samo",
        "iso3": "sym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Senaya",
        "iso3": "syn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suoy",
        "iso3": "syo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Syriac",
        "iso3": "syr",
        "iso2b": "syr",
        "iso2t": "syr",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Sinyar",
        "iso3": "sys",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kagate",
        "iso3": "syw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samay",
        "iso3": "syx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Al-Sayyid Bedouin Sign Language",
        "iso3": "syy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Semelai",
        "iso3": "sza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngalum",
        "iso3": "szb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Semaq Beri",
        "iso3": "szc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Seze",
        "iso3": "sze",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sengele",
        "iso3": "szg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Silesian",
        "iso3": "szl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sula",
        "iso3": "szn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Suabo",
        "iso3": "szp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Solomon Islands Sign Language",
        "iso3": "szs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isu (Fako Division)",
        "iso3": "szv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sawai",
        "iso3": "szw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sakizaya",
        "iso3": "szy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Tanana",
        "iso3": "taa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabassaran",
        "iso3": "tab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lowland Tarahumara",
        "iso3": "tac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tause",
        "iso3": "tad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tariana",
        "iso3": "tae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tapirapé",
        "iso3": "taf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagoi",
        "iso3": "tag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tahitian",
        "iso3": "tah",
        "iso2b": "tah",
        "iso2t": "tah",
        "iso1": "ty",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Tamang",
        "iso3": "taj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tala",
        "iso3": "tak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tal",
        "iso3": "tal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tamil",
        "iso3": "tam",
        "iso2b": "tam",
        "iso2t": "tam",
        "iso1": "ta",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tangale",
        "iso3": "tan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yami",
        "iso3": "tao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taabwa",
        "iso3": "tap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tamasheq",
        "iso3": "taq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Tarahumara",
        "iso3": "tar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tay Boi",
        "iso3": "tas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tatar",
        "iso3": "tat",
        "iso2b": "tat",
        "iso2t": "tat",
        "iso1": "tt",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Tanana",
        "iso3": "tau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tatuyo",
        "iso3": "tav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai",
        "iso3": "taw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tamki",
        "iso3": "tax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Atayal",
        "iso3": "tay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tocho",
        "iso3": "taz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aikanã",
        "iso3": "tba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Takia",
        "iso3": "tbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaki Ae",
        "iso3": "tbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanimbili",
        "iso3": "tbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandara",
        "iso3": "tbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Tairora",
        "iso3": "tbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dharawal",
        "iso3": "tbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gaam",
        "iso3": "tbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiang",
        "iso3": "tbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Calamian Tagbanwa",
        "iso3": "tbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tboli",
        "iso3": "tbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagbu",
        "iso3": "tbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Barro Negro Tunebo",
        "iso3": "tbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tawala",
        "iso3": "tbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taworta",
        "iso3": "tbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumtum",
        "iso3": "tbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanguat",
        "iso3": "tbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tembo (Kitembo)",
        "iso3": "tbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tubar",
        "iso3": "tbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tobo",
        "iso3": "tbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagbanwa",
        "iso3": "tbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kapin",
        "iso3": "tbx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabaru",
        "iso3": "tby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ditammari",
        "iso3": "tbz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ticuna",
        "iso3": "tca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanacross",
        "iso3": "tcb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Datooga",
        "iso3": "tcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tafi",
        "iso3": "tcd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Tutchone",
        "iso3": "tce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malinaltepec Me'phaa",
        "iso3": "tcf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tamagario",
        "iso3": "tcg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turks And Caicos Creole English",
        "iso3": "tch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wára",
        "iso3": "tci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tchitchege",
        "iso3": "tck",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taman (Myanmar)",
        "iso3": "tcl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tanahmerah",
        "iso3": "tcm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tichurong",
        "iso3": "tcn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taungyo",
        "iso3": "tco",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tawr Chin",
        "iso3": "tcp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaiy",
        "iso3": "tcq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Torres Strait Creole",
        "iso3": "tcs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "T'en",
        "iso3": "tct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeastern Tarahumara",
        "iso3": "tcu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tecpatlán Totonac",
        "iso3": "tcw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toda",
        "iso3": "tcx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tulu",
        "iso3": "tcy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thado Chin",
        "iso3": "tcz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagdal",
        "iso3": "tda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Panchpargania",
        "iso3": "tdb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Emberá-Tadó",
        "iso3": "tdc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Nüa",
        "iso3": "tdd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiranige Diga Dogon",
        "iso3": "tde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talieng",
        "iso3": "tdf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Tamang",
        "iso3": "tdg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thulung",
        "iso3": "tdh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tomadino",
        "iso3": "tdi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tajio",
        "iso3": "tdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tambas",
        "iso3": "tdk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sur",
        "iso3": "tdl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taruma",
        "iso3": "tdm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tondano",
        "iso3": "tdn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teme",
        "iso3": "tdo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tita",
        "iso3": "tdq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Todrah",
        "iso3": "tdr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doutai",
        "iso3": "tds",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tetun Dili",
        "iso3": "tdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toro",
        "iso3": "tdv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tandroy-Mahafaly Malagasy",
        "iso3": "tdx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tadyawan",
        "iso3": "tdy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Temiar",
        "iso3": "tea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tetete",
        "iso3": "teb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Terik",
        "iso3": "tec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tepo Krumen",
        "iso3": "ted",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huehuetla Tepehua",
        "iso3": "tee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teressa",
        "iso3": "tef",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teke-Tege",
        "iso3": "teg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tehuelche",
        "iso3": "teh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Torricelli",
        "iso3": "tei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ibali Teke",
        "iso3": "tek",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Telugu",
        "iso3": "tel",
        "iso2b": "tel",
        "iso2t": "tel",
        "iso1": "te",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Timne",
        "iso3": "tem",
        "iso2b": "tem",
        "iso2t": "tem",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tama (Colombia)",
        "iso3": "ten",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Teso",
        "iso3": "teo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tepecano",
        "iso3": "tep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Temein",
        "iso3": "teq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tereno",
        "iso3": "ter",
        "iso2b": "ter",
        "iso2t": "ter",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tengger",
        "iso3": "tes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tetum",
        "iso3": "tet",
        "iso2b": "tet",
        "iso2t": "tet",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Soo",
        "iso3": "teu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teor",
        "iso3": "tev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tewa (USA)",
        "iso3": "tew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tennet",
        "iso3": "tex",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tulishi",
        "iso3": "tey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tetserret",
        "iso3": "tez",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tofin Gbe",
        "iso3": "tfi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanaina",
        "iso3": "tfn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tefaro",
        "iso3": "tfo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teribe",
        "iso3": "tfr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ternate",
        "iso3": "tft",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sagalla",
        "iso3": "tga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tobilung",
        "iso3": "tgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tigak",
        "iso3": "tgc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ciwogai",
        "iso3": "tgd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Gorkha Tamang",
        "iso3": "tge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chalikha",
        "iso3": "tgf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tobagonian Creole English",
        "iso3": "tgh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lawunuia",
        "iso3": "tgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagin",
        "iso3": "tgj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tajik",
        "iso3": "tgk",
        "iso2b": "tgk",
        "iso2t": "tgk",
        "iso1": "tg",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagalog",
        "iso3": "tgl",
        "iso2b": "tgl",
        "iso2t": "tgl",
        "iso1": "tl",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tandaganon",
        "iso3": "tgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sudest",
        "iso3": "tgo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tangoa",
        "iso3": "tgp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tring",
        "iso3": "tgq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tareng",
        "iso3": "tgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nume",
        "iso3": "tgs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Tagbanwa",
        "iso3": "tgt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanggu",
        "iso3": "tgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tingui-Boto",
        "iso3": "tgv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tagwana Senoufo",
        "iso3": "tgw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tagish",
        "iso3": "tgx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Togoyo",
        "iso3": "tgy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tagalaka",
        "iso3": "tgz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Thai",
        "iso3": "tha",
        "iso2b": "tha",
        "iso2t": "tha",
        "iso1": "th",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuuk Thaayorre",
        "iso3": "thd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chitwania Tharu",
        "iso3": "the",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thangmi",
        "iso3": "thf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Tarahumara",
        "iso3": "thh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Long",
        "iso3": "thi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tharaka",
        "iso3": "thk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dangaura Tharu",
        "iso3": "thl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aheu",
        "iso3": "thm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thachanadan",
        "iso3": "thn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thompson",
        "iso3": "thp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kochila Tharu",
        "iso3": "thq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rana Tharu",
        "iso3": "thr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thakali",
        "iso3": "ths",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tahltan",
        "iso3": "tht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thuri",
        "iso3": "thu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tahaggart Tamahaq",
        "iso3": "thv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tha",
        "iso3": "thy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tayart Tamajeq",
        "iso3": "thz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tidikelt Tamazight",
        "iso3": "tia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tira",
        "iso3": "tic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tifal",
        "iso3": "tif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tigre",
        "iso3": "tig",
        "iso2b": "tig",
        "iso2t": "tig",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Timugon Murut",
        "iso3": "tih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiene",
        "iso3": "tii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tilung",
        "iso3": "tij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tikar",
        "iso3": "tik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tillamook",
        "iso3": "til",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Timbe",
        "iso3": "tim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tindi",
        "iso3": "tin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teop",
        "iso3": "tio",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Trimuris",
        "iso3": "tip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiéfo",
        "iso3": "tiq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tigrinya",
        "iso3": "tir",
        "iso2b": "tir",
        "iso2t": "tir",
        "iso1": "ti",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Masadiit Itneg",
        "iso3": "tis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tinigua",
        "iso3": "tit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adasen",
        "iso3": "tiu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiv",
        "iso3": "tiv",
        "iso2b": "tiv",
        "iso2t": "tiv",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiwi",
        "iso3": "tiw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Tiwa",
        "iso3": "tix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiruray",
        "iso3": "tiy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Hongjin",
        "iso3": "tiz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tajuasohn",
        "iso3": "tja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tunjung",
        "iso3": "tjg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Tujia",
        "iso3": "tji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tjungundji",
        "iso3": "tjj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Laing",
        "iso3": "tjl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Timucua",
        "iso3": "tjm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tonjon",
        "iso3": "tjn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Temacine Tamazight",
        "iso3": "tjo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tjupany",
        "iso3": "tjp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Tujia",
        "iso3": "tjs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tjurruru",
        "iso3": "tju",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Djabwurrung",
        "iso3": "tjw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Truká",
        "iso3": "tka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Buksa",
        "iso3": "tkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tukudede",
        "iso3": "tkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Takwane",
        "iso3": "tke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tukumanféd",
        "iso3": "tkf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tesaka Malagasy",
        "iso3": "tkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tokelau",
        "iso3": "tkl",
        "iso2b": "tkl",
        "iso2t": "tkl",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Takelma",
        "iso3": "tkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Toku-No-Shima",
        "iso3": "tkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tikopia",
        "iso3": "tkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tee",
        "iso3": "tkq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsakhur",
        "iso3": "tkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Takestani",
        "iso3": "tks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kathoriya Tharu",
        "iso3": "tkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Necaxa Totonac",
        "iso3": "tku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mur Pano",
        "iso3": "tkv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teanu",
        "iso3": "tkw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tangko",
        "iso3": "tkx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Takua",
        "iso3": "tkz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Tepehuan",
        "iso3": "tla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tobelo",
        "iso3": "tlb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yecuatla Totonac",
        "iso3": "tlc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talaud",
        "iso3": "tld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Telefol",
        "iso3": "tlf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tofanma",
        "iso3": "tlg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Klingon",
        "iso3": "tlh",
        "iso2b": "tlh",
        "iso2t": "tlh",
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Tlingit",
        "iso3": "tli",
        "iso2b": "tli",
        "iso2t": "tli",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talinga-Bwisi",
        "iso3": "tlj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taloki",
        "iso3": "tlk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tetela",
        "iso3": "tll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tolomako",
        "iso3": "tlm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talondo'",
        "iso3": "tln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talodi",
        "iso3": "tlo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Filomena Mata-Coahuitlán Totonac",
        "iso3": "tlp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Loi",
        "iso3": "tlq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talise",
        "iso3": "tlr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tambotalo",
        "iso3": "tls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sou Nama",
        "iso3": "tlt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tulehu",
        "iso3": "tlu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taliabu",
        "iso3": "tlv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khehek",
        "iso3": "tlx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talysh",
        "iso3": "tly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tama (Chad)",
        "iso3": "tma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Katbol",
        "iso3": "tmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumak",
        "iso3": "tmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Haruai",
        "iso3": "tmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tremembé",
        "iso3": "tme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Toba-Maskoy",
        "iso3": "tmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ternateño",
        "iso3": "tmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tamashek",
        "iso3": "tmh",
        "iso2b": "tmh",
        "iso2t": "tmh",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Tutuba",
        "iso3": "tmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Samarokena",
        "iso3": "tmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tamnim Citak",
        "iso3": "tml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Thanh",
        "iso3": "tmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taman (Indonesia)",
        "iso3": "tmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Temoq",
        "iso3": "tmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumleo",
        "iso3": "tmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jewish Babylonian Aramaic (ca. 200-1200 CE)",
        "iso3": "tmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tima",
        "iso3": "tms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tasmate",
        "iso3": "tmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iau",
        "iso3": "tmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tembo (Motembo)",
        "iso3": "tmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Temuan",
        "iso3": "tmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tami",
        "iso3": "tmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tamanaku",
        "iso3": "tmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tacana",
        "iso3": "tna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Tunebo",
        "iso3": "tnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanimuca-Retuarã",
        "iso3": "tnc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angosturas Tunebo",
        "iso3": "tnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tobanga",
        "iso3": "tng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maiani",
        "iso3": "tnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tandia",
        "iso3": "tni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwamera",
        "iso3": "tnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lenakel",
        "iso3": "tnl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabla",
        "iso3": "tnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Tanna",
        "iso3": "tnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toromono",
        "iso3": "tno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Whitesands",
        "iso3": "tnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taino",
        "iso3": "tnq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ménik",
        "iso3": "tnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tenis",
        "iso3": "tns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tontemboan",
        "iso3": "tnt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tay Khang",
        "iso3": "tnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tangchangya",
        "iso3": "tnv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tonsawang",
        "iso3": "tnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanema",
        "iso3": "tnx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tongwe",
        "iso3": "tny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ten'edn",
        "iso3": "tnz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toba",
        "iso3": "tob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coyutla Totonac",
        "iso3": "toc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toma",
        "iso3": "tod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gizrra",
        "iso3": "tof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tonga (Nyasa)",
        "iso3": "tog",
        "iso2b": "tog",
        "iso2t": "tog",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gitonga",
        "iso3": "toh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tonga (Zambia)",
        "iso3": "toi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tojolabal",
        "iso3": "toj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toki Pona",
        "iso3": "tok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Tolowa",
        "iso3": "tol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tombulu",
        "iso3": "tom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tonga (Tonga Islands)",
        "iso3": "ton",
        "iso2b": "ton",
        "iso2t": "ton",
        "iso1": "to",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xicotepec De Juárez Totonac",
        "iso3": "too",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Papantla Totonac",
        "iso3": "top",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toposa",
        "iso3": "toq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Togbo-Vara Banda",
        "iso3": "tor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Highland Totonac",
        "iso3": "tos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tho",
        "iso3": "tou",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Taromi",
        "iso3": "tov",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jemez",
        "iso3": "tow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tobian",
        "iso3": "tox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Topoiyo",
        "iso3": "toy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "To",
        "iso3": "toz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taupota",
        "iso3": "tpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Azoyú Me'phaa",
        "iso3": "tpc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tippera",
        "iso3": "tpe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tarpia",
        "iso3": "tpf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kula",
        "iso3": "tpg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tok Pisin",
        "iso3": "tpi",
        "iso2b": "tpi",
        "iso2t": "tpi",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tapieté",
        "iso3": "tpj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tupinikin",
        "iso3": "tpk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tlacoapa Me'phaa",
        "iso3": "tpl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tampulma",
        "iso3": "tpm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tupinambá",
        "iso3": "tpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tai Pao",
        "iso3": "tpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pisaflores Tepehua",
        "iso3": "tpp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tukpa",
        "iso3": "tpq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuparí",
        "iso3": "tpr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tlachichilco Tepehua",
        "iso3": "tpt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tampuan",
        "iso3": "tpu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanapag",
        "iso3": "tpv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Acatepec Me'phaa",
        "iso3": "tpx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Trumai",
        "iso3": "tpy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tinputz",
        "iso3": "tpz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tembé",
        "iso3": "tqb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lehali",
        "iso3": "tql",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turumsa",
        "iso3": "tqm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tenino",
        "iso3": "tqn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toaripi",
        "iso3": "tqo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tomoip",
        "iso3": "tqp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tunni",
        "iso3": "tqq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Torona",
        "iso3": "tqr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Western Totonac",
        "iso3": "tqt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Touo",
        "iso3": "tqu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tonkawa",
        "iso3": "tqw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tirahi",
        "iso3": "tra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Terebu",
        "iso3": "trb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Copala Triqui",
        "iso3": "trc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turi",
        "iso3": "trd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Tarangan",
        "iso3": "tre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Trinidadian Creole English",
        "iso3": "trf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lishán Didán",
        "iso3": "trg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turaka",
        "iso3": "trh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Trió",
        "iso3": "tri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toram",
        "iso3": "trj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Traveller Scottish",
        "iso3": "trl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tregami",
        "iso3": "trm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Trinitario",
        "iso3": "trn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tarao Naga",
        "iso3": "tro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kok Borok",
        "iso3": "trp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Martín Itunyoso Triqui",
        "iso3": "trq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taushiro",
        "iso3": "trr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chicahuaxtla Triqui",
        "iso3": "trs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tunggare",
        "iso3": "trt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turoyo",
        "iso3": "tru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sediq",
        "iso3": "trv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Torwali",
        "iso3": "trw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tringgus-Sembaan Bidayuh",
        "iso3": "trx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turung",
        "iso3": "try",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Torá",
        "iso3": "trz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tsaangi",
        "iso3": "tsa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsamai",
        "iso3": "tsb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tswa",
        "iso3": "tsc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsakonian",
        "iso3": "tsd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tunisian Sign Language",
        "iso3": "tse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tausug",
        "iso3": "tsg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsuvan",
        "iso3": "tsh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsimshian",
        "iso3": "tsi",
        "iso2b": "tsi",
        "iso2t": "tsi",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tshangla",
        "iso3": "tsj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tseku",
        "iso3": "tsk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ts'ün-Lao",
        "iso3": "tsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turkish Sign Language",
        "iso3": "tsm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tswana",
        "iso3": "tsn",
        "iso2b": "tsn",
        "iso2t": "tsn",
        "iso1": "tn",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsonga",
        "iso3": "tso",
        "iso2b": "tso",
        "iso2t": "tso",
        "iso1": "ts",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Toussian",
        "iso3": "tsp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thai Sign Language",
        "iso3": "tsq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Akei",
        "iso3": "tsr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taiwan Sign Language",
        "iso3": "tss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tondi Songway Kiini",
        "iso3": "tst",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsou",
        "iso3": "tsu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsogo",
        "iso3": "tsv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsishingini",
        "iso3": "tsw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mubami",
        "iso3": "tsx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tebul Sign Language",
        "iso3": "tsy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Purepecha",
        "iso3": "tsz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tutelo",
        "iso3": "tta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gaa",
        "iso3": "ttb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tektiteko",
        "iso3": "ttc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tauade",
        "iso3": "ttd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bwanabwana",
        "iso3": "tte",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuotomb",
        "iso3": "ttf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tutong",
        "iso3": "ttg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Ta'oih",
        "iso3": "tth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tobati",
        "iso3": "tti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tooro",
        "iso3": "ttj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Totoro",
        "iso3": "ttk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Totela",
        "iso3": "ttl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Tutchone",
        "iso3": "ttm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Towei",
        "iso3": "ttn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Ta'oih",
        "iso3": "tto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tombelala",
        "iso3": "ttp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tawallammat Tamajaq",
        "iso3": "ttq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tera",
        "iso3": "ttr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northeastern Thai",
        "iso3": "tts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muslim Tat",
        "iso3": "ttt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Torau",
        "iso3": "ttu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Titan",
        "iso3": "ttv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Long Wat",
        "iso3": "ttw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sikaritai",
        "iso3": "tty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsum",
        "iso3": "ttz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wiarumus",
        "iso3": "tua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tübatulabal",
        "iso3": "tub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mutu",
        "iso3": "tuc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuxá",
        "iso3": "tud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tuyuca",
        "iso3": "tue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Tunebo",
        "iso3": "tuf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tunia",
        "iso3": "tug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taulil",
        "iso3": "tuh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tupuri",
        "iso3": "tui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tugutil",
        "iso3": "tuj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turkmen",
        "iso3": "tuk",
        "iso2b": "tuk",
        "iso2t": "tuk",
        "iso1": "tk",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tula",
        "iso3": "tul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumbuka",
        "iso3": "tum",
        "iso2b": "tum",
        "iso2t": "tum",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tunica",
        "iso3": "tun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tucano",
        "iso3": "tuo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tedaga",
        "iso3": "tuq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turkish",
        "iso3": "tur",
        "iso2b": "tur",
        "iso2t": "tur",
        "iso1": "tr",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuscarora",
        "iso3": "tus",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tututni",
        "iso3": "tuu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turkana",
        "iso3": "tuv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuxináwa",
        "iso3": "tux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tugen",
        "iso3": "tuy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turka",
        "iso3": "tuz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vaghua",
        "iso3": "tva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsuvadi",
        "iso3": "tvd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Te'un",
        "iso3": "tve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tulai",
        "iso3": "tvi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeast Ambrym",
        "iso3": "tvk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuvalu",
        "iso3": "tvl",
        "iso2b": "tvl",
        "iso2t": "tvl",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tela-Masbuar",
        "iso3": "tvm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tavoyan",
        "iso3": "tvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tidore",
        "iso3": "tvo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taveta",
        "iso3": "tvs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tutsa Naga",
        "iso3": "tvt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tunen",
        "iso3": "tvu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sedoa",
        "iso3": "tvw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Taivoan",
        "iso3": "tvx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Timor Pidgin",
        "iso3": "tvy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Twana",
        "iso3": "twa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Western Tawbuid",
        "iso3": "twb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teshenawa",
        "iso3": "twc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Twents",
        "iso3": "twd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tewa (Indonesia)",
        "iso3": "twe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Tiwa",
        "iso3": "twf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tereweng",
        "iso3": "twg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Dón",
        "iso3": "twh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Twi",
        "iso3": "twi",
        "iso2b": "twi",
        "iso2t": "twi",
        "iso1": "tw",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tawara",
        "iso3": "twl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tawang Monpa",
        "iso3": "twm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Twendi",
        "iso3": "twn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tswapong",
        "iso3": "two",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ere",
        "iso3": "twp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tasawaq",
        "iso3": "twq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Tarahumara",
        "iso3": "twr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Turiwára",
        "iso3": "twt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Termanu",
        "iso3": "twu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuwari",
        "iso3": "tww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tewe",
        "iso3": "twx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tawoyan",
        "iso3": "twy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tombonuo",
        "iso3": "txa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tokharian B",
        "iso3": "txb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Tsetsaut",
        "iso3": "txc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Totoli",
        "iso3": "txe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tangut",
        "iso3": "txg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Thracian",
        "iso3": "txh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ikpeng",
        "iso3": "txi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tarjumo",
        "iso3": "txj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tomini",
        "iso3": "txm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Tarangan",
        "iso3": "txn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Toto",
        "iso3": "txo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tii",
        "iso3": "txq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tartessian",
        "iso3": "txr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Tonsea",
        "iso3": "txs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Citak",
        "iso3": "txt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayapó",
        "iso3": "txu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tatana",
        "iso3": "txx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanosy Malagasy",
        "iso3": "txy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tauya",
        "iso3": "tya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kyanga",
        "iso3": "tye",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "O'du",
        "iso3": "tyh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teke-Tsaayi",
        "iso3": "tyi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tai Do",
        "iso3": "tyj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thu Lao",
        "iso3": "tyl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kombai",
        "iso3": "tyn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thaypan",
        "iso3": "typ",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tai Daeng",
        "iso3": "tyr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tày Sa Pa",
        "iso3": "tys",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tày Tac",
        "iso3": "tyt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kua",
        "iso3": "tyu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tuvinian",
        "iso3": "tyv",
        "iso2b": "tyv",
        "iso2t": "tyv",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Teke-Tyee",
        "iso3": "tyx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tiyaa",
        "iso3": "tyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tày",
        "iso3": "tyz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanzanian Sign Language",
        "iso3": "tza",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tzeltal",
        "iso3": "tzh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tz'utujil",
        "iso3": "tzj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talossan",
        "iso3": "tzl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Central Atlas Tamazight",
        "iso3": "tzm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tugun",
        "iso3": "tzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tzotzil",
        "iso3": "tzo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabriak",
        "iso3": "tzx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uamué",
        "iso3": "uam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kuan",
        "iso3": "uan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tairuma",
        "iso3": "uar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ubang",
        "iso3": "uba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ubi",
        "iso3": "ubi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buhi'non Bikol",
        "iso3": "ubl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ubir",
        "iso3": "ubr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umbu-Ungu",
        "iso3": "ubu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ubykh",
        "iso3": "uby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Uda",
        "iso3": "uda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Udihe",
        "iso3": "ude",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muduga",
        "iso3": "udg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Udi",
        "iso3": "udi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ujir",
        "iso3": "udj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wuzlam",
        "iso3": "udl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Udmurt",
        "iso3": "udm",
        "iso2b": "udm",
        "iso2t": "udm",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uduk",
        "iso3": "udu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kioko",
        "iso3": "ues",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ufim",
        "iso3": "ufi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ugaritic",
        "iso3": "uga",
        "iso2b": "uga",
        "iso2t": "uga",
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kuku-Ugbanh",
        "iso3": "ugb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ughele",
        "iso3": "uge",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kubachi",
        "iso3": "ugh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ugandan Sign Language",
        "iso3": "ugn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ugong",
        "iso3": "ugo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uruguayan Sign Language",
        "iso3": "ugy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uhami",
        "iso3": "uha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Damal",
        "iso3": "uhn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uighur",
        "iso3": "uig",
        "iso2b": "uig",
        "iso2t": "uig",
        "iso1": "ug",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uisai",
        "iso3": "uis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iyive",
        "iso3": "uiv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanjijili",
        "iso3": "uji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaburi",
        "iso3": "uka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukuriguma",
        "iso3": "ukg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukhwejo",
        "iso3": "ukh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kui (India)",
        "iso3": "uki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muak Sa-aak",
        "iso3": "ukk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukrainian Sign Language",
        "iso3": "ukl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukpe-Bayobiri",
        "iso3": "ukp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukwa",
        "iso3": "ukq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukrainian",
        "iso3": "ukr",
        "iso2b": "ukr",
        "iso2t": "ukr",
        "iso1": "uk",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urubú-Kaapor Sign Language",
        "iso3": "uks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukue",
        "iso3": "uku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuku",
        "iso3": "ukv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ukwuani-Aboh-Ndoni",
        "iso3": "ukw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuuk-Yak",
        "iso3": "uky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Fungwa",
        "iso3": "ula",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ulukwumi",
        "iso3": "ulb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ulch",
        "iso3": "ulc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lule",
        "iso3": "ule",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Usku",
        "iso3": "ulf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ulithian",
        "iso3": "uli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Meriam Mir",
        "iso3": "ulk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ullatan",
        "iso3": "ull",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ulumanda'",
        "iso3": "ulm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Unserdeutsch",
        "iso3": "uln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uma' Lung",
        "iso3": "ulu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ulwa",
        "iso3": "ulw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Buli",
        "iso3": "uly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umatilla",
        "iso3": "uma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umbundu",
        "iso3": "umb",
        "iso2b": "umb",
        "iso2t": "umb",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marrucinian",
        "iso3": "umc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Umbindhamu",
        "iso3": "umd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Morrobalama",
        "iso3": "umg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ukit",
        "iso3": "umi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umon",
        "iso3": "umm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makyan Naga",
        "iso3": "umn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umotína",
        "iso3": "umo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Umpila",
        "iso3": "ump",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umbugarla",
        "iso3": "umr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pendau",
        "iso3": "ums",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Munsee",
        "iso3": "umu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Watut",
        "iso3": "una",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Undetermined",
        "iso3": "und",
        "iso2b": "und",
        "iso2t": "und",
        "iso1": None,
        "scope": "Special",
        "type": "Special",
    },
    {
        "name": "Uneme",
        "iso3": "une",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngarinyin",
        "iso3": "ung",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uni",
        "iso3": "uni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Enawené-Nawé",
        "iso3": "unk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Unami",
        "iso3": "unm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kurnai",
        "iso3": "unn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mundari",
        "iso3": "unr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Unubahe",
        "iso3": "unu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Munda",
        "iso3": "unx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Unde Kaili",
        "iso3": "unz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kulon",
        "iso3": "uon",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Umeda",
        "iso3": "upi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uripiv-Wala-Rano-Atchin",
        "iso3": "upv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urarina",
        "iso3": "ura",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urubú-Kaapor",
        "iso3": "urb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urningangg",
        "iso3": "urc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Urdu",
        "iso3": "urd",
        "iso2b": "urd",
        "iso2t": "urd",
        "iso1": "ur",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uru",
        "iso3": "ure",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uradhi",
        "iso3": "urf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Urigina",
        "iso3": "urg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urhobo",
        "iso3": "urh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urim",
        "iso3": "uri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urak Lawoi'",
        "iso3": "urk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urali",
        "iso3": "url",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urapmin",
        "iso3": "urm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uruangnirin",
        "iso3": "urn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ura (Papua New Guinea)",
        "iso3": "uro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uru-Pa-In",
        "iso3": "urp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lehalurup",
        "iso3": "urr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urat",
        "iso3": "urt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urumi",
        "iso3": "uru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Uruava",
        "iso3": "urv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sop",
        "iso3": "urw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urimo",
        "iso3": "urx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Orya",
        "iso3": "ury",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uru-Eu-Wau-Wau",
        "iso3": "urz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Usarufa",
        "iso3": "usa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ushojo",
        "iso3": "ush",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Usui",
        "iso3": "usi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Usaghade",
        "iso3": "usk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uspanteco",
        "iso3": "usp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "us-Saare",
        "iso3": "uss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uya",
        "iso3": "usu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Otank",
        "iso3": "uta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ute-Southern Paiute",
        "iso3": "ute",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ut-Hun",
        "iso3": "uth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amba (Solomon Islands)",
        "iso3": "utp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Etulo",
        "iso3": "utr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Utu",
        "iso3": "utu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Urum",
        "iso3": "uum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ura (Vanuatu)",
        "iso3": "uur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "U",
        "iso3": "uuu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Uvean",
        "iso3": "uve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uri",
        "iso3": "uvh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lote",
        "iso3": "uvl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuku-Uwanh",
        "iso3": "uwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Doko-Uyanga",
        "iso3": "uya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uzbek",
        "iso3": "uzb",
        "iso2b": "uzb",
        "iso2t": "uzb",
        "iso1": "uz",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Northern Uzbek",
        "iso3": "uzn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Uzbek",
        "iso3": "uzs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vaagri Booli",
        "iso3": "vaa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vale",
        "iso3": "vae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vafsi",
        "iso3": "vaf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vagla",
        "iso3": "vag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Varhadi-Nagpuri",
        "iso3": "vah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vai",
        "iso3": "vai",
        "iso2b": "vai",
        "iso2t": "vai",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sekele",
        "iso3": "vaj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vehes",
        "iso3": "val",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vanimo",
        "iso3": "vam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Valman",
        "iso3": "van",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vao",
        "iso3": "vao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vaiphei",
        "iso3": "vap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Huarijio",
        "iso3": "var",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vasavi",
        "iso3": "vas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vanuma",
        "iso3": "vau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Varli",
        "iso3": "vav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wayu",
        "iso3": "vay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeast Babar",
        "iso3": "vbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southwestern Bontok",
        "iso3": "vbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Venetian",
        "iso3": "vec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Veddah",
        "iso3": "ved",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Veluws",
        "iso3": "vel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vemgo-Mabas",
        "iso3": "vem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Venda",
        "iso3": "ven",
        "iso2b": "ven",
        "iso2t": "ven",
        "iso1": "ve",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ventureño",
        "iso3": "veo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Veps",
        "iso3": "vep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mom Jango",
        "iso3": "ver",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vaghri",
        "iso3": "vgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vlaamse Gebarentaal",
        "iso3": "vgt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Virgin Islands Creole English",
        "iso3": "vic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vidunda",
        "iso3": "vid",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vietnamese",
        "iso3": "vie",
        "iso2b": "vie",
        "iso2t": "vie",
        "iso1": "vi",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vili",
        "iso3": "vif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Viemo",
        "iso3": "vig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vilela",
        "iso3": "vil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vinza",
        "iso3": "vin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vishavan",
        "iso3": "vis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Viti",
        "iso3": "vit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iduna",
        "iso3": "viv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bajjika",
        "iso3": "vjk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kariyarra",
        "iso3": "vka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kujarge",
        "iso3": "vkj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaur",
        "iso3": "vkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kulisusu",
        "iso3": "vkl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamakan",
        "iso3": "vkm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Koro Nulu",
        "iso3": "vkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kodeoha",
        "iso3": "vko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korlai Creole Portuguese",
        "iso3": "vkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tenggarong Kutai Malay",
        "iso3": "vkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurrama",
        "iso3": "vku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koro Zuba",
        "iso3": "vkz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Valpei",
        "iso3": "vlp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vlaams",
        "iso3": "vls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Martuyhunira",
        "iso3": "vma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Barbaram",
        "iso3": "vmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Juxtlahuaca Mixtec",
        "iso3": "vmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mudu Koraga",
        "iso3": "vmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Masela",
        "iso3": "vme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mainfränkisch",
        "iso3": "vmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lungalunga",
        "iso3": "vmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maraghei",
        "iso3": "vmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miwa",
        "iso3": "vmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ixtayutla Mixtec",
        "iso3": "vmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makhuwa-Shirima",
        "iso3": "vmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malgana",
        "iso3": "vml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mitlatongo Mixtec",
        "iso3": "vmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Soyaltepec Mazatec",
        "iso3": "vmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Soyaltepec Mixtec",
        "iso3": "vmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marenje",
        "iso3": "vmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moksela",
        "iso3": "vms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Muluridyi",
        "iso3": "vmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Valley Maidu",
        "iso3": "vmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Makhuwa",
        "iso3": "vmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tamazola Mixtec",
        "iso3": "vmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayautla Mazatec",
        "iso3": "vmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mazatlán Mazatec",
        "iso3": "vmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vano",
        "iso3": "vnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vinmavis",
        "iso3": "vnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vunapu",
        "iso3": "vnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Volapük",
        "iso3": "vol",
        "iso2b": "vol",
        "iso2t": "vol",
        "iso1": "vo",
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Voro",
        "iso3": "vor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Votic",
        "iso3": "vot",
        "iso2b": "vot",
        "iso2t": "vot",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vera'a",
        "iso3": "vra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Võro",
        "iso3": "vro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Varisi",
        "iso3": "vrs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Burmbar",
        "iso3": "vrt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moldova Sign Language",
        "iso3": "vsi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Venezuelan Sign Language",
        "iso3": "vsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vedic Sanskrit",
        "iso3": "vsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Valencian Sign Language",
        "iso3": "vsv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vitou",
        "iso3": "vto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vumbu",
        "iso3": "vum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vunjo",
        "iso3": "vun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vute",
        "iso3": "vut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awa (China)",
        "iso3": "vwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Walla Walla",
        "iso3": "waa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wab",
        "iso3": "wab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wasco-Wishram",
        "iso3": "wac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wamesa",
        "iso3": "wad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Walser",
        "iso3": "wae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wakoná",
        "iso3": "waf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wa'ema",
        "iso3": "wag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Watubela",
        "iso3": "wah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wares",
        "iso3": "wai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waffa",
        "iso3": "waj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wolaytta",
        "iso3": "wal",
        "iso2b": "wal",
        "iso2t": "wal",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wampanoag",
        "iso3": "wam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wan",
        "iso3": "wan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wappo",
        "iso3": "wao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wapishana",
        "iso3": "wap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wagiman",
        "iso3": "waq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waray (Philippines)",
        "iso3": "war",
        "iso2b": "war",
        "iso2t": "war",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Washo",
        "iso3": "was",
        "iso2b": "was",
        "iso2t": "was",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaninuwa",
        "iso3": "wat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waurá",
        "iso3": "wau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waka",
        "iso3": "wav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waiwai",
        "iso3": "waw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Watam",
        "iso3": "wax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wayana",
        "iso3": "way",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wampur",
        "iso3": "waz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warao",
        "iso3": "wba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wabo",
        "iso3": "wbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waritai",
        "iso3": "wbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wara",
        "iso3": "wbf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wanda",
        "iso3": "wbh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vwanji",
        "iso3": "wbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alagwa",
        "iso3": "wbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waigali",
        "iso3": "wbk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wakhi",
        "iso3": "wbl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wa",
        "iso3": "wbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warlpiri",
        "iso3": "wbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waddar",
        "iso3": "wbq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wagdi",
        "iso3": "wbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Bengal Sign Language",
        "iso3": "wbs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warnman",
        "iso3": "wbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wajarri",
        "iso3": "wbv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Woi",
        "iso3": "wbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yanomámi",
        "iso3": "wca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waci Gbe",
        "iso3": "wci",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wandji",
        "iso3": "wdd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wadaginam",
        "iso3": "wdg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wadjiginy",
        "iso3": "wdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wadikali",
        "iso3": "wdk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wendat",
        "iso3": "wdt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wadjigu",
        "iso3": "wdu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wadjabangayi",
        "iso3": "wdy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wewaw",
        "iso3": "wea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wè Western",
        "iso3": "wec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wedau",
        "iso3": "wed",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wergaia",
        "iso3": "weg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Weh",
        "iso3": "weh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kiunum",
        "iso3": "wei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Weme Gbe",
        "iso3": "wem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wemale",
        "iso3": "weo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Westphalien",
        "iso3": "wep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Weri",
        "iso3": "wer",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cameroon Pidgin",
        "iso3": "wes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Perai",
        "iso3": "wet",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rawngtu Chin",
        "iso3": "weu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wejewa",
        "iso3": "wew",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yafi",
        "iso3": "wfg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wagaya",
        "iso3": "wga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wagawaga",
        "iso3": "wgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wangkangurru",
        "iso3": "wgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wahgi",
        "iso3": "wgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waigeo",
        "iso3": "wgo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wirangu",
        "iso3": "wgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Warrgamay",
        "iso3": "wgy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sou Upaa",
        "iso3": "wha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Wahgi",
        "iso3": "whg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wahau Kenyah",
        "iso3": "whk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wahau Kayan",
        "iso3": "whu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Toussian",
        "iso3": "wib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wichita",
        "iso3": "wic",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wik-Epa",
        "iso3": "wie",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wik-Keyangan",
        "iso3": "wif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wik Ngathan",
        "iso3": "wig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wik-Me'anha",
        "iso3": "wih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minidien",
        "iso3": "wii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wik-Iiyanh",
        "iso3": "wij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wikalkan",
        "iso3": "wik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wilawila",
        "iso3": "wil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wik-Mungkan",
        "iso3": "wim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ho-Chunk",
        "iso3": "win",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wiraféd",
        "iso3": "wir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wiru",
        "iso3": "wiu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vitu",
        "iso3": "wiv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wiyot",
        "iso3": "wiy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Waja",
        "iso3": "wja",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warji",
        "iso3": "wji",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kw'adza",
        "iso3": "wka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kumbaran",
        "iso3": "wkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wakde",
        "iso3": "wkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kalanadi",
        "iso3": "wkl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keerray-Woorroong",
        "iso3": "wkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunduvadi",
        "iso3": "wku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wakawaka",
        "iso3": "wkw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wangkayutyuru",
        "iso3": "wky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Walio",
        "iso3": "wla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mwali Comorian",
        "iso3": "wlc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wolane",
        "iso3": "wle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kunbarlang",
        "iso3": "wlg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Welaun",
        "iso3": "wlh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waioli",
        "iso3": "wli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wailaki",
        "iso3": "wlk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wali (Sudan)",
        "iso3": "wll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Welsh",
        "iso3": "wlm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Walloon",
        "iso3": "wln",
        "iso2b": "wln",
        "iso2t": "wln",
        "iso1": "wa",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wolio",
        "iso3": "wlo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wailapa",
        "iso3": "wlr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wallisian",
        "iso3": "wls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wuliwuli",
        "iso3": "wlu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wichí Lhamtés Vejoz",
        "iso3": "wlv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Walak",
        "iso3": "wlw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wali (Ghana)",
        "iso3": "wlx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waling",
        "iso3": "wly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mawa (Nigeria)",
        "iso3": "wma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wambaya",
        "iso3": "wmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wamas",
        "iso3": "wmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mamaindé",
        "iso3": "wmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wambule",
        "iso3": "wme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Minyag",
        "iso3": "wmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waima'a",
        "iso3": "wmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wamin",
        "iso3": "wmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Maiwa (Indonesia)",
        "iso3": "wmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waamwang",
        "iso3": "wmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wom (Papua New Guinea)",
        "iso3": "wmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wambon",
        "iso3": "wms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Walmajarri",
        "iso3": "wmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mwani",
        "iso3": "wmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Womo",
        "iso3": "wmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mokati",
        "iso3": "wnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wantoat",
        "iso3": "wnc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wandarang",
        "iso3": "wnd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Waneci",
        "iso3": "wne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wanggom",
        "iso3": "wng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ndzwani Comorian",
        "iso3": "wni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wanukaka",
        "iso3": "wnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wanggamala",
        "iso3": "wnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wunumara",
        "iso3": "wnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wano",
        "iso3": "wno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wanap",
        "iso3": "wnp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Usan",
        "iso3": "wnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wintu",
        "iso3": "wnw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wanyi",
        "iso3": "wny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuwema",
        "iso3": "woa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wè Northern",
        "iso3": "wob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wogeo",
        "iso3": "woc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wolani",
        "iso3": "wod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Woleaian",
        "iso3": "woe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gambian Wolof",
        "iso3": "wof",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wogamusin",
        "iso3": "wog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamang",
        "iso3": "woi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Longto",
        "iso3": "wok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wolof",
        "iso3": "wol",
        "iso2b": "wol",
        "iso2t": "wol",
        "iso1": "wo",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wom (Nigeria)",
        "iso3": "wom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wongo",
        "iso3": "won",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manombai",
        "iso3": "woo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Woria",
        "iso3": "wor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hanga Hundi",
        "iso3": "wos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wawonii",
        "iso3": "wow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Weyto",
        "iso3": "woy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Maco",
        "iso3": "wpc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waluwarra",
        "iso3": "wrb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Warungu",
        "iso3": "wrg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wiradjuri",
        "iso3": "wrh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wariyangga",
        "iso3": "wri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Garrwa",
        "iso3": "wrk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warlmanpa",
        "iso3": "wrl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warumungu",
        "iso3": "wrm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warnang",
        "iso3": "wrn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Worrorra",
        "iso3": "wro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Waropen",
        "iso3": "wrp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wardaman",
        "iso3": "wrr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waris",
        "iso3": "wrs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waru",
        "iso3": "wru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waruna",
        "iso3": "wrv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gugu Warra",
        "iso3": "wrw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wae Rana",
        "iso3": "wrx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Merwari",
        "iso3": "wry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waray (Australia)",
        "iso3": "wrz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Warembori",
        "iso3": "wsa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adilabad Gondi",
        "iso3": "wsg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wusi",
        "iso3": "wsi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waskia",
        "iso3": "wsk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Owenia",
        "iso3": "wsr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wasa",
        "iso3": "wss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wasu",
        "iso3": "wsu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wotapuri-Katarqalai",
        "iso3": "wsv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Matambwe",
        "iso3": "wtb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Watiwa",
        "iso3": "wtf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wathawurrung",
        "iso3": "wth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Berta",
        "iso3": "wti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Watakataui",
        "iso3": "wtk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mewati",
        "iso3": "wtm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wotu",
        "iso3": "wtw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wikngenchera",
        "iso3": "wua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wunambal",
        "iso3": "wub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wudu",
        "iso3": "wud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wutunhua",
        "iso3": "wuh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Silimo",
        "iso3": "wul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wumbvu",
        "iso3": "wum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bungu",
        "iso3": "wun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wurrugu",
        "iso3": "wur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wutung",
        "iso3": "wut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wu Chinese",
        "iso3": "wuu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wuvulu-Aua",
        "iso3": "wuv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wulna",
        "iso3": "wux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wauyai",
        "iso3": "wuy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waama",
        "iso3": "wwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wakabunga",
        "iso3": "wwb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wetamut",
        "iso3": "wwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Warrwa",
        "iso3": "wwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wawa",
        "iso3": "www",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Waxianghua",
        "iso3": "wxa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wardandi",
        "iso3": "wxw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wangaaybuwan-Ngiyambaa",
        "iso3": "wyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Woiwurrung",
        "iso3": "wyi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wymysorys",
        "iso3": "wym",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wyandot",
        "iso3": "wyn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wayoró",
        "iso3": "wyr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Fijian",
        "iso3": "wyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Andalusian Arabic",
        "iso3": "xaa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Sambe",
        "iso3": "xab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kachari",
        "iso3": "xac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Adai",
        "iso3": "xad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Aequian",
        "iso3": "xae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Aghwan",
        "iso3": "xag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kaimbé",
        "iso3": "xai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ararandewára",
        "iso3": "xaj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Máku",
        "iso3": "xak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kalmyk",
        "iso3": "xal",
        "iso2b": "xal",
        "iso2t": "xal",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ǀXam",
        "iso3": "xam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Xamtanga",
        "iso3": "xan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khao",
        "iso3": "xao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Apalachee",
        "iso3": "xap",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Aquitanian",
        "iso3": "xaq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Karami",
        "iso3": "xar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kamas",
        "iso3": "xas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Katawixi",
        "iso3": "xat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kauwera",
        "iso3": "xau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xavánte",
        "iso3": "xav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kawaiisu",
        "iso3": "xaw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayan Mahakam",
        "iso3": "xay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lower Burdekin",
        "iso3": "xbb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bactrian",
        "iso3": "xbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Bindal",
        "iso3": "xbd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bigambal",
        "iso3": "xbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bunganditj",
        "iso3": "xbg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kombio",
        "iso3": "xbi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Birrpayi",
        "iso3": "xbj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Middle Breton",
        "iso3": "xbm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kenaboi",
        "iso3": "xbn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Bolgarian",
        "iso3": "xbo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Bibbulman",
        "iso3": "xbp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kambera",
        "iso3": "xbr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kambiwá",
        "iso3": "xbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Batjala",
        "iso3": "xby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cumbric",
        "iso3": "xcb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Camunic",
        "iso3": "xcc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Celtiberian",
        "iso3": "xce",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Cisalpine Gaulish",
        "iso3": "xcg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Chemakum",
        "iso3": "xch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Classical Armenian",
        "iso3": "xcl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Comecrudo",
        "iso3": "xcm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cotoname",
        "iso3": "xcn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Chorasmian",
        "iso3": "xco",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Carian",
        "iso3": "xcr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Classical Tibetan",
        "iso3": "xct",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Curonian",
        "iso3": "xcu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Chuvantsy",
        "iso3": "xcv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Coahuilteco",
        "iso3": "xcw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Cayuse",
        "iso3": "xcy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Darkinyung",
        "iso3": "xda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dacian",
        "iso3": "xdc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Dharuk",
        "iso3": "xdk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Edomite",
        "iso3": "xdm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kwandu",
        "iso3": "xdo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaitag",
        "iso3": "xdq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malayic Dayak",
        "iso3": "xdy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eblan",
        "iso3": "xeb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Hdi",
        "iso3": "xed",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "ǁXegwi",
        "iso3": "xeg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kelo",
        "iso3": "xel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kembayan",
        "iso3": "xem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Epi-Olmec",
        "iso3": "xep",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Xerénte",
        "iso3": "xer",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kesawai",
        "iso3": "xes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xetá",
        "iso3": "xet",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Keoru-Ahia",
        "iso3": "xeu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Faliscan",
        "iso3": "xfa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Galatian",
        "iso3": "xga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Gbin",
        "iso3": "xgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gudang",
        "iso3": "xgd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Gabrielino-Fernandeño",
        "iso3": "xgf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Goreng",
        "iso3": "xgg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Garingbal",
        "iso3": "xgi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Galindan",
        "iso3": "xgl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Dharumbal",
        "iso3": "xgm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Garza",
        "iso3": "xgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Unggumi",
        "iso3": "xgu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guwa",
        "iso3": "xgw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Harami",
        "iso3": "xha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Hunnic",
        "iso3": "xhc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Hadrami",
        "iso3": "xhd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Khetrani",
        "iso3": "xhe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Khmer (1400 to 1850 CE)",
        "iso3": "xhm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Xhosa",
        "iso3": "xho",
        "iso2b": "xho",
        "iso2t": "xho",
        "iso1": "xh",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hernican",
        "iso3": "xhr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Hattic",
        "iso3": "xht",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Hurrian",
        "iso3": "xhu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Khua",
        "iso3": "xhv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iberian",
        "iso3": "xib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Xiri",
        "iso3": "xii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Illyrian",
        "iso3": "xil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Xinca",
        "iso3": "xin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Xiriâna",
        "iso3": "xir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kisan",
        "iso3": "xis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Indus Valley Language",
        "iso3": "xiv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Xipaya",
        "iso3": "xiy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minjungbal",
        "iso3": "xjb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Jaitmatang",
        "iso3": "xjt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kalkoti",
        "iso3": "xka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Nago",
        "iso3": "xkb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kho'ini",
        "iso3": "xkc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mendalam Kayan",
        "iso3": "xkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kereho",
        "iso3": "xke",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khengkha",
        "iso3": "xkf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kagoro",
        "iso3": "xkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kenyan Sign Language",
        "iso3": "xki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kajali",
        "iso3": "xkj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kachok",
        "iso3": "xkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mainstream Kenyah",
        "iso3": "xkl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kayan River Kayan",
        "iso3": "xkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kiorr",
        "iso3": "xko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kabatei",
        "iso3": "xkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koroni",
        "iso3": "xkq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xakriabá",
        "iso3": "xkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kumbewaha",
        "iso3": "xks",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kantosi",
        "iso3": "xkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaamba",
        "iso3": "xku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kgalagadi",
        "iso3": "xkv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kembra",
        "iso3": "xkw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karore",
        "iso3": "xkx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Uma' Lasan",
        "iso3": "xky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kurtokha",
        "iso3": "xkz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamula",
        "iso3": "xla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loup B",
        "iso3": "xlb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lycian",
        "iso3": "xlc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Lydian",
        "iso3": "xld",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Lemnian",
        "iso3": "xle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ligurian (Ancient)",
        "iso3": "xlg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Liburnian",
        "iso3": "xli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Alanic",
        "iso3": "xln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Loup A",
        "iso3": "xlo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lepontic",
        "iso3": "xlp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Lusitanian",
        "iso3": "xls",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Cuneiform Luwian",
        "iso3": "xlu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Elymian",
        "iso3": "xly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mushungulu",
        "iso3": "xma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbonga",
        "iso3": "xmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makhuwa-Marrevone",
        "iso3": "xmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbudum",
        "iso3": "xmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Median",
        "iso3": "xme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mingrelian",
        "iso3": "xmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mengaka",
        "iso3": "xmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kugu-Muminh",
        "iso3": "xmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Majera",
        "iso3": "xmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ancient Macedonian",
        "iso3": "xmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Malaysian Sign Language",
        "iso3": "xml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manado Malay",
        "iso3": "xmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manichaean Middle Persian",
        "iso3": "xmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Morerebi",
        "iso3": "xmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuku-Mu'inh",
        "iso3": "xmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kuku-Mangk",
        "iso3": "xmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Meroitic",
        "iso3": "xmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Moroccan Sign Language",
        "iso3": "xms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Matbat",
        "iso3": "xmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kamu",
        "iso3": "xmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Antankarana Malagasy",
        "iso3": "xmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tsimihety Malagasy",
        "iso3": "xmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Salawati",
        "iso3": "xmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mayaguduna",
        "iso3": "xmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mori Bawah",
        "iso3": "xmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ancient North Arabian",
        "iso3": "xna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kanakanabu",
        "iso3": "xnb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Middle Mongolian",
        "iso3": "xng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kuanhua",
        "iso3": "xnh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngarigu",
        "iso3": "xni",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ngoni (Tanzania)",
        "iso3": "xnj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nganakarti",
        "iso3": "xnk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ngumbarl",
        "iso3": "xnm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Northern Kankanay",
        "iso3": "xnn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Anglo-Norman",
        "iso3": "xno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Ngoni (Mozambique)",
        "iso3": "xnq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kangri",
        "iso3": "xnr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kanashi",
        "iso3": "xns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Narragansett",
        "iso3": "xnt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nukunul",
        "iso3": "xnu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Nyiyaparli",
        "iso3": "xny",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kenzi",
        "iso3": "xnz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "O'chi'chi'",
        "iso3": "xoc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kokoda",
        "iso3": "xod",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Soga",
        "iso3": "xog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kominimung",
        "iso3": "xoi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xokleng",
        "iso3": "xok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Komo (Sudan)",
        "iso3": "xom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Konkomba",
        "iso3": "xon",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xukurú",
        "iso3": "xoo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kopar",
        "iso3": "xop",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Korubo",
        "iso3": "xor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kowaki",
        "iso3": "xow",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pirriya",
        "iso3": "xpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Northeastern Tasmanian",
        "iso3": "xpb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pecheneg",
        "iso3": "xpc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Oyster Bay Tasmanian",
        "iso3": "xpd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Liberia Kpelle",
        "iso3": "xpe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeast Tasmanian",
        "iso3": "xpf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Phrygian",
        "iso3": "xpg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "North Midlands Tasmanian",
        "iso3": "xph",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pictish",
        "iso3": "xpi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mpalitjanh",
        "iso3": "xpj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kulina Pano",
        "iso3": "xpk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Port Sorell Tasmanian",
        "iso3": "xpl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pumpokol",
        "iso3": "xpm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kapinawá",
        "iso3": "xpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Pochutec",
        "iso3": "xpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Puyo-Paekche",
        "iso3": "xpp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mohegan-Pequot",
        "iso3": "xpq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Parthian",
        "iso3": "xpr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Pisidian",
        "iso3": "xps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Punthamara",
        "iso3": "xpt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Punic",
        "iso3": "xpu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Northern Tasmanian",
        "iso3": "xpv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Northwestern Tasmanian",
        "iso3": "xpw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Southwestern Tasmanian",
        "iso3": "xpx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Puyo",
        "iso3": "xpy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Bruny Island Tasmanian",
        "iso3": "xpz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Karakhanid",
        "iso3": "xqa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Qatabanian",
        "iso3": "xqt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Krahô",
        "iso3": "xra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Karaboro",
        "iso3": "xrb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gundungurra",
        "iso3": "xrd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kreye",
        "iso3": "xre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minang",
        "iso3": "xrg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Krikati-Timbira",
        "iso3": "xri",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Armazic",
        "iso3": "xrm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Arin",
        "iso3": "xrn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Raetic",
        "iso3": "xrr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Aranama-Tamique",
        "iso3": "xrt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Marriammu",
        "iso3": "xru",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karawa",
        "iso3": "xrw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sabaean",
        "iso3": "xsa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Sambal",
        "iso3": "xsb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Scythian",
        "iso3": "xsc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Sidetic",
        "iso3": "xsd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Sempan",
        "iso3": "xse",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Shamang",
        "iso3": "xsh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sio",
        "iso3": "xsi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Subi",
        "iso3": "xsj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "South Slavey",
        "iso3": "xsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kasem",
        "iso3": "xsm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sanga (Nigeria)",
        "iso3": "xsn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Solano",
        "iso3": "xso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Silopi",
        "iso3": "xsp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makhuwa-Saka",
        "iso3": "xsq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sherpa",
        "iso3": "xsr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sanumá",
        "iso3": "xsu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sudovian",
        "iso3": "xsv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Saisiyat",
        "iso3": "xsy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alcozauca Mixtec",
        "iso3": "xta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chazumba Mixtec",
        "iso3": "xtb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Katcha-Kadugli-Miri",
        "iso3": "xtc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Diuxi-Tilantongo Mixtec",
        "iso3": "xtd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ketengban",
        "iso3": "xte",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Transalpine Gaulish",
        "iso3": "xtg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Yitha Yitha",
        "iso3": "xth",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Sinicahua Mixtec",
        "iso3": "xti",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Juan Teita Mixtec",
        "iso3": "xtj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tijaltepec Mixtec",
        "iso3": "xtl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Magdalena Peñasco Mixtec",
        "iso3": "xtm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Tlaxiaco Mixtec",
        "iso3": "xtn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tokharian A",
        "iso3": "xto",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "San Miguel Piedras Mixtec",
        "iso3": "xtp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tumshuqese",
        "iso3": "xtq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Early Tripuri",
        "iso3": "xtr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Sindihui Mixtec",
        "iso3": "xts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tacahua Mixtec",
        "iso3": "xtt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cuyamecalco Mixtec",
        "iso3": "xtu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thawa",
        "iso3": "xtv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tawandê",
        "iso3": "xtw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yoloxochitl Mixtec",
        "iso3": "xty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alu Kurumba",
        "iso3": "xua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Betta Kurumba",
        "iso3": "xub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Umiida",
        "iso3": "xud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kunigami",
        "iso3": "xug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Jennu Kurumba",
        "iso3": "xuj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngunawal",
        "iso3": "xul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Umbrian",
        "iso3": "xum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Unggaranggu",
        "iso3": "xun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kuo",
        "iso3": "xuo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Upper Umpqua",
        "iso3": "xup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Urartian",
        "iso3": "xur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kuthant",
        "iso3": "xut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kxoe",
        "iso3": "xuu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Venetic",
        "iso3": "xve",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kamviri",
        "iso3": "xvi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Vandalic",
        "iso3": "xvn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Volscian",
        "iso3": "xvo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Vestinian",
        "iso3": "xvs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kwaza",
        "iso3": "xwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Woccon",
        "iso3": "xwc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wadi Wadi",
        "iso3": "xwd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Xwela Gbe",
        "iso3": "xwe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kwegu",
        "iso3": "xwg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wajuk",
        "iso3": "xwj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wangkumara",
        "iso3": "xwk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Western Xwla Gbe",
        "iso3": "xwl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Written Oirat",
        "iso3": "xwo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kwerba Mamberamo",
        "iso3": "xwr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wotjobaluk",
        "iso3": "xwt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Wemba Wemba",
        "iso3": "xww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Boro (Ghana)",
        "iso3": "xxb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ke'o",
        "iso3": "xxk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minkin",
        "iso3": "xxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Koropó",
        "iso3": "xxr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Tambora",
        "iso3": "xxt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yaygir",
        "iso3": "xya",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yandjibara",
        "iso3": "xyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mayi-Yapi",
        "iso3": "xyj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mayi-Kulan",
        "iso3": "xyk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yalakalore",
        "iso3": "xyl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mayi-Thakurti",
        "iso3": "xyt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yorta Yorta",
        "iso3": "xyy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zhang-Zhung",
        "iso3": "xzh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Zemgalian",
        "iso3": "xzm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Ancient Zapotec",
        "iso3": "xzp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Yaminahua",
        "iso3": "yaa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yuhup",
        "iso3": "yab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pass Valley Yali",
        "iso3": "yac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yagua",
        "iso3": "yad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pumé",
        "iso3": "yae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaka (Democratic Republic of Congo)",
        "iso3": "yaf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yámana",
        "iso3": "yag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yazgulyam",
        "iso3": "yah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yagnobi",
        "iso3": "yai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Banda-Yangere",
        "iso3": "yaj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yakama",
        "iso3": "yak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yalunka",
        "iso3": "yal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yamba",
        "iso3": "yam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mayangna",
        "iso3": "yan",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yao",
        "iso3": "yao",
        "iso2b": "yao",
        "iso2t": "yao",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yapese",
        "iso3": "yap",
        "iso2b": "yap",
        "iso2t": "yap",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaqui",
        "iso3": "yaq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yabarana",
        "iso3": "yar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nugunu (Cameroon)",
        "iso3": "yas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yambeta",
        "iso3": "yat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yuwana",
        "iso3": "yau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yangben",
        "iso3": "yav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yawalapití",
        "iso3": "yaw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yauma",
        "iso3": "yax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Agwagwune",
        "iso3": "yay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lokaa",
        "iso3": "yaz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yala",
        "iso3": "yba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yemba",
        "iso3": "ybb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Yugur",
        "iso3": "ybe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yakha",
        "iso3": "ybh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yamphu",
        "iso3": "ybi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hasha",
        "iso3": "ybj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bokha",
        "iso3": "ybk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yukuben",
        "iso3": "ybl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaben",
        "iso3": "ybm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yabaâna",
        "iso3": "ybn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yabong",
        "iso3": "ybo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yawiyo",
        "iso3": "ybx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaweyuha",
        "iso3": "yby",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chesu",
        "iso3": "ych",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lolopo",
        "iso3": "ycl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yucuna",
        "iso3": "ycn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chepya",
        "iso3": "ycp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yilan Creole",
        "iso3": "ycr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yanda",
        "iso3": "yda",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Eastern Yiddish",
        "iso3": "ydd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yangum Dey",
        "iso3": "yde",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yidgha",
        "iso3": "ydg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yoidik",
        "iso3": "ydk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ravula",
        "iso3": "yea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yeniche",
        "iso3": "yec",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yimas",
        "iso3": "yee",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yeni",
        "iso3": "yei",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yevanic",
        "iso3": "yej",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yela",
        "iso3": "yel",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tarok",
        "iso3": "yer",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyankpa",
        "iso3": "yes",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yetfa",
        "iso3": "yet",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yerukula",
        "iso3": "yeu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yapunda",
        "iso3": "yev",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yeyi",
        "iso3": "yey",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malyangapa",
        "iso3": "yga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yiningayi",
        "iso3": "ygi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yangum Gel",
        "iso3": "ygl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yagomi",
        "iso3": "ygm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Gepo",
        "iso3": "ygp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yagaria",
        "iso3": "ygr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yolŋu Sign Language",
        "iso3": "ygs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yugul",
        "iso3": "ygu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yagwoia",
        "iso3": "ygw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Baha Buyang",
        "iso3": "yha",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Iraqi Arabic",
        "iso3": "yhd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Hlepho Phowa",
        "iso3": "yhl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yan-nhaŋu Sign Language",
        "iso3": "yhs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yinggarda",
        "iso3": "yia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yiddish",
        "iso3": "yid",
        "iso2b": "yid",
        "iso2t": "yid",
        "iso1": "yi",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Ache",
        "iso3": "yif",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wusa Nasu",
        "iso3": "yig",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Yiddish",
        "iso3": "yih",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yidiny",
        "iso3": "yii",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yindjibarndi",
        "iso3": "yij",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dongshanba Lalo",
        "iso3": "yik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yindjilandji",
        "iso3": "yil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yimchungru Naga",
        "iso3": "yim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Riang Lai",
        "iso3": "yin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Pholo",
        "iso3": "yip",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miqie",
        "iso3": "yiq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "North Awyu",
        "iso3": "yir",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yis",
        "iso3": "yis",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Lalu",
        "iso3": "yit",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Awu",
        "iso3": "yiu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Nisu",
        "iso3": "yiv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Axi Yi",
        "iso3": "yix",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Azhe",
        "iso3": "yiz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yakan",
        "iso3": "yka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Northern Yukaghir",
        "iso3": "ykg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khamnigan Mongol",
        "iso3": "ykh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yoke",
        "iso3": "yki",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yakaikeke",
        "iso3": "ykk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Khlula",
        "iso3": "ykl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kap",
        "iso3": "ykm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kua-nsi",
        "iso3": "ykn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yasa",
        "iso3": "yko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yekora",
        "iso3": "ykr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kathu",
        "iso3": "ykt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kuamasi",
        "iso3": "yku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yakoma",
        "iso3": "yky",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaul",
        "iso3": "yla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaleba",
        "iso3": "ylb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yele",
        "iso3": "yle",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yelogu",
        "iso3": "ylg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Angguruk Yali",
        "iso3": "yli",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yil",
        "iso3": "yll",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Limi",
        "iso3": "ylm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Langnian Buyang",
        "iso3": "yln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naluo Yi",
        "iso3": "ylo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yalarnnga",
        "iso3": "ylr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Aribwaung",
        "iso3": "ylu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nyâlayu",
        "iso3": "yly",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yambes",
        "iso3": "ymb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Muji",
        "iso3": "ymc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muda",
        "iso3": "ymd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yameo",
        "iso3": "yme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yamongeri",
        "iso3": "ymg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mili",
        "iso3": "ymh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Moji",
        "iso3": "ymi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makwe",
        "iso3": "ymk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Iamalele",
        "iso3": "yml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maay",
        "iso3": "ymm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yamna",
        "iso3": "ymn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yangum Mon",
        "iso3": "ymo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yamap",
        "iso3": "ymp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Qila Muji",
        "iso3": "ymq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malasar",
        "iso3": "ymr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mysian",
        "iso3": "yms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Northern Muji",
        "iso3": "ymx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muzi",
        "iso3": "ymz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Aluo",
        "iso3": "yna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yamben",
        "iso3": "ynb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yandruwandha",
        "iso3": "ynd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Lang'e",
        "iso3": "yne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yango",
        "iso3": "yng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Naukan Yupik",
        "iso3": "ynk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yangulam",
        "iso3": "ynl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yana",
        "iso3": "ynn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yong",
        "iso3": "yno",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yendang",
        "iso3": "ynq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yansi",
        "iso3": "yns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yahuna",
        "iso3": "ynu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yoba",
        "iso3": "yob",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yogad",
        "iso3": "yog",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yonaguni",
        "iso3": "yoi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yokuts",
        "iso3": "yok",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yola",
        "iso3": "yol",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yombe",
        "iso3": "yom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yongkom",
        "iso3": "yon",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yoruba",
        "iso3": "yor",
        "iso2b": "yor",
        "iso2t": "yor",
        "iso1": "yo",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yotti",
        "iso3": "yot",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yoron",
        "iso3": "yox",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yoy",
        "iso3": "yoy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phala",
        "iso3": "ypa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Labo Phowa",
        "iso3": "ypb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phola",
        "iso3": "ypg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phupha",
        "iso3": "yph",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phuma",
        "iso3": "ypm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ani Phowa",
        "iso3": "ypn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Alo Phola",
        "iso3": "ypo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phupa",
        "iso3": "ypp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Phuza",
        "iso3": "ypz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yerakai",
        "iso3": "yra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yareba",
        "iso3": "yrb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaouré",
        "iso3": "yre",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nenets",
        "iso3": "yrk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nhengatu",
        "iso3": "yrl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yirrk-Mel",
        "iso3": "yrm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yerong",
        "iso3": "yrn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yaroamë",
        "iso3": "yro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yarsun",
        "iso3": "yrs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yarawata",
        "iso3": "yrw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yarluyandi",
        "iso3": "yry",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yassic",
        "iso3": "ysc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Samatao",
        "iso3": "ysd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sonaga",
        "iso3": "ysg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yugoslavian Sign Language",
        "iso3": "ysl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Myanmar Sign Language",
        "iso3": "ysm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sani",
        "iso3": "ysn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nisi (China)",
        "iso3": "yso",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Lolopo",
        "iso3": "ysp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sirenik Yupik",
        "iso3": "ysr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yessan-Mayo",
        "iso3": "yss",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sanie",
        "iso3": "ysy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Talu",
        "iso3": "yta",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tanglang",
        "iso3": "ytl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Thopho",
        "iso3": "ytp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yout Wam",
        "iso3": "ytw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yatay",
        "iso3": "yty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yucateco",
        "iso3": "yua",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yugambal",
        "iso3": "yub",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yuchi",
        "iso3": "yuc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Judeo-Tripolitanian Arabic",
        "iso3": "yud",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yue Chinese",
        "iso3": "yue",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Havasupai-Walapai-Yavapai",
        "iso3": "yuf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yug",
        "iso3": "yug",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yurutí",
        "iso3": "yui",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Karkar-Yuri",
        "iso3": "yuj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yuki",
        "iso3": "yuk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yulu",
        "iso3": "yul",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quechan",
        "iso3": "yum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bena (Nigeria)",
        "iso3": "yun",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yukpa",
        "iso3": "yup",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yuqui",
        "iso3": "yuq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yurok",
        "iso3": "yur",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yopno",
        "iso3": "yut",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yau (Morobe Province)",
        "iso3": "yuw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Yukaghir",
        "iso3": "yux",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Yugur",
        "iso3": "yuy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yuracare",
        "iso3": "yuz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yawa",
        "iso3": "yva",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yavitero",
        "iso3": "yvt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kalou",
        "iso3": "ywa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yinhawangka",
        "iso3": "ywg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Lalu",
        "iso3": "ywl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yawanawa",
        "iso3": "ywn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wuding-Luquan Yi",
        "iso3": "ywq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yawuru",
        "iso3": "ywr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xishanba Lalo",
        "iso3": "ywt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Wumeng Nasu",
        "iso3": "ywu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yawarawarga",
        "iso3": "yww",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mayawali",
        "iso3": "yxa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yagara",
        "iso3": "yxg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yardliyawarra",
        "iso3": "yxl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yinwum",
        "iso3": "yxm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yuyu",
        "iso3": "yxu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yabula Yabula",
        "iso3": "yxy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yir Yoront",
        "iso3": "yyr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Yau (Sandaun Province)",
        "iso3": "yyu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayizi",
        "iso3": "yyz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "E'ma Buyang",
        "iso3": "yzg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zokhuo",
        "iso3": "yzk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sierra de Juárez Zapotec",
        "iso3": "zaa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Western Tlacolula Valley Zapotec",
        "iso3": "zab",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ocotlán Zapotec",
        "iso3": "zac",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Cajonos Zapotec",
        "iso3": "zad",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yareni Zapotec",
        "iso3": "zae",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ayoquesco Zapotec",
        "iso3": "zaf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zaghawa",
        "iso3": "zag",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zangwal",
        "iso3": "zah",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Isthmus Zapotec",
        "iso3": "zai",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zaramo",
        "iso3": "zaj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zanaki",
        "iso3": "zak",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zauzou",
        "iso3": "zal",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Miahuatlán Zapotec",
        "iso3": "zam",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ozolotepec Zapotec",
        "iso3": "zao",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zapotec",
        "iso3": "zap",
        "iso2b": "zap",
        "iso2t": "zap",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Aloápam Zapotec",
        "iso3": "zaq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rincón Zapotec",
        "iso3": "zar",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santo Domingo Albarradas Zapotec",
        "iso3": "zas",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabaa Zapotec",
        "iso3": "zat",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zangskari",
        "iso3": "zau",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yatzachi Zapotec",
        "iso3": "zav",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mitla Zapotec",
        "iso3": "zaw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xadani Zapotec",
        "iso3": "zax",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zayse-Zergulla",
        "iso3": "zay",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zari",
        "iso3": "zaz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Balaibalan",
        "iso3": "zba",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Central Berawan",
        "iso3": "zbc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "East Berawan",
        "iso3": "zbe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Blissymbols",
        "iso3": "zbl",
        "iso2b": "zbl",
        "iso2t": "zbl",
        "iso1": None,
        "scope": "Individual",
        "type": "Constructed",
    },
    {
        "name": "Batui",
        "iso3": "zbt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bu (Bauchi State)",
        "iso3": "zbu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "West Berawan",
        "iso3": "zbw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coatecas Altas Zapotec",
        "iso3": "zca",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Las Delicias Zapotec",
        "iso3": "zcd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Central Hongshuihe Zhuang",
        "iso3": "zch",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Ngazidja Comorian",
        "iso3": "zdj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zeeuws",
        "iso3": "zea",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zenag",
        "iso3": "zeg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Eastern Hongshuihe Zhuang",
        "iso3": "zeh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zeem",
        "iso3": "zem",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zenaga",
        "iso3": "zen",
        "iso2b": "zen",
        "iso2t": "zen",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kinga",
        "iso3": "zga",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guibei Zhuang",
        "iso3": "zgb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Standard Moroccan Tamazight",
        "iso3": "zgh",
        "iso2b": "zgh",
        "iso2t": "zgh",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Minz Zhuang",
        "iso3": "zgm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guibian Zhuang",
        "iso3": "zgn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Magori",
        "iso3": "zgr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zhuang",
        "iso3": "zha",
        "iso2b": "zha",
        "iso2t": "zha",
        "iso1": "za",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Zhaba",
        "iso3": "zhb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Dai Zhuang",
        "iso3": "zhd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zhire",
        "iso3": "zhi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Nong Zhuang",
        "iso3": "zhn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chinese",
        "iso3": "zho",
        "iso2b": "chi",
        "iso2t": "zho",
        "iso1": "zh",
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Zhoa",
        "iso3": "zhw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zia",
        "iso3": "zia",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zimbabwe Sign Language",
        "iso3": "zib",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zimakani",
        "iso3": "zik",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zialo",
        "iso3": "zil",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mesme",
        "iso3": "zim",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zinza",
        "iso3": "zin",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zigula",
        "iso3": "ziw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zizilivakan",
        "iso3": "ziz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaimbulawa",
        "iso3": "zka",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kadu",
        "iso3": "zkd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Koguryo",
        "iso3": "zkg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Khorezmian",
        "iso3": "zkh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Karankawa",
        "iso3": "zkk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Kanan",
        "iso3": "zkn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kott",
        "iso3": "zko",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "São Paulo Kaingáng",
        "iso3": "zkp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Zakhring",
        "iso3": "zkr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kitan",
        "iso3": "zkt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Kaurna",
        "iso3": "zku",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Krevinian",
        "iso3": "zkv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Khazar",
        "iso3": "zkz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Zula",
        "iso3": "zla",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Liujiang Zhuang",
        "iso3": "zlj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Malay (individual language)",
        "iso3": "zlm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lianshan Zhuang",
        "iso3": "zln",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Liuqian Zhuang",
        "iso3": "zlq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zul",
        "iso3": "zlu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manda (Australia)",
        "iso3": "zma",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zimba",
        "iso3": "zmb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Margany",
        "iso3": "zmc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Maridan",
        "iso3": "zmd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mangerr",
        "iso3": "zme",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mfinu",
        "iso3": "zmf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Marti Ke",
        "iso3": "zmg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Makolkol",
        "iso3": "zmh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Negeri Sembilan Malay",
        "iso3": "zmi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maridjabin",
        "iso3": "zmj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mandandanyi",
        "iso3": "zmk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Matngala",
        "iso3": "zml",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Marimanindji",
        "iso3": "zmm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbangwe",
        "iso3": "zmn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Molo",
        "iso3": "zmo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mpuono",
        "iso3": "zmp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mituku",
        "iso3": "zmq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maranunggu",
        "iso3": "zmr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbesa",
        "iso3": "zms",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Maringarr",
        "iso3": "zmt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Muruwari",
        "iso3": "zmu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mbariman-Gudhinma",
        "iso3": "zmv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mbo (Democratic Republic of Congo)",
        "iso3": "zmw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Bomitaba",
        "iso3": "zmx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mariyedi",
        "iso3": "zmy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mbandja",
        "iso3": "zmz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zan Gula",
        "iso3": "zna",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zande (individual language)",
        "iso3": "zne",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mang",
        "iso3": "zng",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Manangkari",
        "iso3": "znk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mangas",
        "iso3": "zns",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Copainalá Zoque",
        "iso3": "zoc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chimalapa Zoque",
        "iso3": "zoh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zou",
        "iso3": "zom",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Asunción Mixtepec Zapotec",
        "iso3": "zoo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tabasco Zoque",
        "iso3": "zoq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Rayón Zoque",
        "iso3": "zor",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Francisco León Zoque",
        "iso3": "zos",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lachiguiri Zapotec",
        "iso3": "zpa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yautepec Zapotec",
        "iso3": "zpb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Choapan Zapotec",
        "iso3": "zpc",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southeastern Ixtlán Zapotec",
        "iso3": "zpd",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Petapa Zapotec",
        "iso3": "zpe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Pedro Quiatoni Zapotec",
        "iso3": "zpf",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Guevea De Humboldt Zapotec",
        "iso3": "zpg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Totomachapan Zapotec",
        "iso3": "zph",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santa María Quiegolani Zapotec",
        "iso3": "zpi",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quiavicuzas Zapotec",
        "iso3": "zpj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tlacolulita Zapotec",
        "iso3": "zpk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lachixío Zapotec",
        "iso3": "zpl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mixtepec Zapotec",
        "iso3": "zpm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santa Inés Yatzechi Zapotec",
        "iso3": "zpn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Amatlán Zapotec",
        "iso3": "zpo",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "El Alto Zapotec",
        "iso3": "zpp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zoogocho Zapotec",
        "iso3": "zpq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santiago Xanica Zapotec",
        "iso3": "zpr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Coatlán Zapotec",
        "iso3": "zps",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Vicente Coatlán Zapotec",
        "iso3": "zpt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yalálag Zapotec",
        "iso3": "zpu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Chichicapan Zapotec",
        "iso3": "zpv",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zaniza Zapotec",
        "iso3": "zpw",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Baltazar Loxicha Zapotec",
        "iso3": "zpx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Mazaltepec Zapotec",
        "iso3": "zpy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Texmelucan Zapotec",
        "iso3": "zpz",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Qiubei Zhuang",
        "iso3": "zqe",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kara (Korea)",
        "iso3": "zra",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Mirgan",
        "iso3": "zrg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zerenkel",
        "iso3": "zrn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Záparo",
        "iso3": "zro",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zarphatic",
        "iso3": "zrp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Extinct",
    },
    {
        "name": "Mairasi",
        "iso3": "zrs",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sarasira",
        "iso3": "zsa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kaskean",
        "iso3": "zsk",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Historical",
    },
    {
        "name": "Zambian Sign Language",
        "iso3": "zsl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Standard Malay",
        "iso3": "zsm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Southern Rincon Zapotec",
        "iso3": "zsr",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Sukurum",
        "iso3": "zsu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Elotepec Zapotec",
        "iso3": "zte",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Xanaguía Zapotec",
        "iso3": "ztg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Lapaguía-Guivini Zapotec",
        "iso3": "ztl",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "San Agustín Mixtepec Zapotec",
        "iso3": "ztm",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Santa Catarina Albarradas Zapotec",
        "iso3": "ztn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Loxicha Zapotec",
        "iso3": "ztp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Quioquitani-Quierí Zapotec",
        "iso3": "ztq",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tilquiapan Zapotec",
        "iso3": "zts",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tejalapan Zapotec",
        "iso3": "ztt",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Güilá Zapotec",
        "iso3": "ztu",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zaachila Zapotec",
        "iso3": "ztx",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yatee Zapotec",
        "iso3": "zty",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Tokano",
        "iso3": "zuh",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zulu",
        "iso3": "zul",
        "iso2b": "zul",
        "iso2t": "zul",
        "iso1": "zu",
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Kumzari",
        "iso3": "zum",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zuni",
        "iso3": "zun",
        "iso2b": "zun",
        "iso2t": "zun",
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zumaya",
        "iso3": "zuy",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zay",
        "iso3": "zwa",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "No linguistic content",
        "iso3": "zxx",
        "iso2b": "zxx",
        "iso2t": "zxx",
        "iso1": None,
        "scope": "Special",
        "type": "Special",
    },
    {
        "name": "Yongbei Zhuang",
        "iso3": "zyb",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yang Zhuang",
        "iso3": "zyg",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Youjiang Zhuang",
        "iso3": "zyj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Yongnan Zhuang",
        "iso3": "zyn",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zyphe Chin",
        "iso3": "zyp",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
    {
        "name": "Zaza",
        "iso3": "zza",
        "iso2b": "zza",
        "iso2t": "zza",
        "iso1": None,
        "scope": "Macrolanguage",
        "type": "Living",
    },
    {
        "name": "Zuojiang Zhuang",
        "iso3": "zzj",
        "iso2b": None,
        "iso2t": None,
        "iso1": None,
        "scope": "Individual",
        "type": "Living",
    },
]
